<?php

namespace App\Http\Controllers\Webservices;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Validator;

use App\Saloons;
use App\SaloonServices;
use App\Services;
use App\Cities;
use App\Barbers;
use App\BarbersServices;
use App\Bookings;
use App\BookingItems;
use App\BarberSchedule;
use App\BarberBreak;

class BarbersController extends Controller
{
    public function __construct()
    {
        header('Access-Control-Allow-Origin: *');
        header('Access-Control-Allow-Methods: GET, PUT, POST, DELETE, OPTIONS');
        header("Content-Type: application/json");
    }

    public function loginAsBarber(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'mobile' => 'required'
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $response['login'] = false;
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $mobile = $request->input("mobile");
            $user = Barbers::select('id','name','email','mobile','profile_image')->where("mobile",$mobile)->first();
            if($user->profile_image !=''){
                $user->profile_image = asset('public/uploads/profile_images/'.$user->profile_image);
            }else{
                $user->profile_image = '';
            }
            if(empty($user)){
                $response['status'] = 'error';
                $response['login'] = false;
                $response['message'] = 'Invalid mobile no';
                return response()->json($response);
            }else{
               
                $response['status'] = 'success';
                $response['login'] = true;
                $response['message'] = 'Login success';
                $response['user'] = $user;
            }
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function bookingList(Request $request){
        try{
            $barber_id = $request->input("barber_id");
            $bookings = Bookings::where("barber_id",$barber_id)->orderBy("book_date","desc")->get();
            $bookingList = array();
            foreach($bookings as $booking){
                $temp = array();
                $temp['id'] = $booking->id;
                $temp['book_date'] = dateFormat($booking->book_date,"d-m-Y");
                $temp['customer_name'] = $booking->Customer->name;
                $temp['customer_id'] = $booking->customer_id;
                $temp['saloon_name'] = $booking->Saloon->saloon_name;
                $temp['saloon_id'] = $booking->saloon_id;
                $temp['barber_name'] = $booking->Barber->name;
                $temp['barber_id'] = $booking->barber_id;
                $temp['book_number'] = $booking->book_number;
                $temp['from_time'] = $booking->from_time;
                $temp['to_time'] = $booking->to_time;
                $temp['total_price'] = $booking->total;
                $temp['transaction_id'] = $booking->transaction_id;
                $temp['billing_name'] = $booking->billing_name;
                $temp['billing_mobile'] = $booking->billing_mobile;
                $temp['billing_email'] = $booking->billing_email;
                $date = $booking->book_date." ".$booking->to_time;
                $current_date = date("Y-m-d H:i:s");
                if($date > $current_date){
                    $temp['status'] = 'Upcoming';
                }else{
                    $temp['status'] = 'Completed';
                }
                $booking_services = BookingItems::with('Service')->where("booking_id",$booking->id)->get();
                $services = array();
                foreach($booking_services as $serv){
                    $temp['service_name'] = $serv->Service->name;
                    $temp['service_price'] = $serv->price;
                    $services[] = $temp;
                }
                $temp['services'] = $services;

                $bookingList[] = $temp;
            }
            $response['status'] = 'success';
            $response['booking_list'] = $bookingList;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
    
    public function barberIncome(Request $request){
        try{
            $barber_id = $request->input("barber_id");
            if($request->input("date")){
                $date = date("Y-m-d",strtotime($request->input("date")));    
            }else{
                $date = date("Y-m-d");
            }
            
            $today_earning = Bookings::where("barber_id",$barber_id)
                        ->whereDate("book_date",$date)
                        ->orderBy("book_date","desc")
                        ->sum("total");
            $week_start = date( 'Y-m-d', strtotime( 'monday this week' ) );
            $week_end = date( 'Y-m-d', strtotime( 'sunday this week' ) );

            $week_earning = Bookings::where("barber_id",$barber_id)
                        ->whereDate("book_date",">=",$week_start)
                        ->whereDate("book_date","<=",$week_end)
                        ->orderBy("book_date","desc")
                        ->sum("total");

            $month_start = date('Y-m-d',strtotime('first day of this month'));
            $month_end = date('Y-m-d',strtotime('last day of this month'));

            $month_earning = Bookings::where("barber_id",$barber_id)
                        ->whereDate("book_date",">=",$month_start)
                        ->whereDate("book_date","<=",$month_end)
                        ->orderBy("book_date","desc")
                        ->sum("total");

            $year_start = date('Y-m-d',strtotime('first day of January '));
            $year_end = date('Y-m-d',strtotime('last day of December'));

            $year_earning = Bookings::where("barber_id",$barber_id)
                        ->whereDate("book_date",">=",$year_start)
                        ->whereDate("book_date","<=",$year_end)
                        ->orderBy("book_date","desc")
                        ->sum("total");

            $earnings = array("today_earning"=>$today_earning,"week_earning"=>$week_earning,"month_earning"=>$month_earning,"year_earning"=>$year_earning);

            $barber = Barbers::select('id','name','mobile','profile_image')->where('id',$barber_id)->first();
            $barber->profile_image = asset('public/uploads/profile_images/'.$barber->profile_image);

            $bookings = Bookings::where("barber_id",$barber_id)
                                ->where("book_date",$date)
                                ->orderBy("from_time","asc")
                                ->get();
            $today_slots = array();
            foreach($bookings as $booking){
                $temp = array();
                $temp['id'] = $booking->id;
                $temp['book_date'] = dateFormat($booking->book_date,"d-m-Y");
                // $temp['customer_name'] = $booking->Customer->name;
                // $temp['customer_id'] = $booking->customer_id;
                // $temp['saloon_name'] = $booking->Saloon->saloon_name;
                // $temp['saloon_id'] = $booking->saloon_id;
                $temp['barber_name'] = $booking->Barber->name;
                // $temp['barber_id'] = $booking->barber_id;
                // $temp['book_number'] = $booking->book_number;
                $temp['from_time'] = $booking->from_time;
                $temp['to_time'] = $booking->to_time;
                $temp['total_price'] = $booking->total;
                // $temp['transaction_id'] = $booking->transaction_id;
                // $temp['billing_name'] = $booking->billing_name;
                // $temp['billing_mobile'] = $booking->billing_mobile;
                // $temp['billing_email'] = $booking->billing_email;

                $booking_services = BookingItems::with('Service')->where("booking_id",$booking->id)->get();
                $services = array();
                foreach($booking_services as $serv){
                    $temp2 = array();
                    $temp2['service_name'] = $serv->Service->name;
                    $temp2['service_price'] = $serv->price;
                    $services[] = $temp2;
                }
                $temp['services'] = $services;

                $today_slots[] = $temp;
            }
            $response['barber'] = $barber;
            $response['earnings'] = $earnings;
            $response['today_slots'] = $today_slots;
            $response['status'] = 'success';
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function scheduleList(Request $request){
        try{
            $barber_id = $request->input("barber_id");
            $schedules = BarberSchedule::select('id','schedule_date','from_time','to_time')->where("barber_id",$barber_id)
                                        ->orderBy("schedule_date","desc")
                                        ->get();
            foreach($schedules as $schedule){
                $schedule->schedule_date = dateFormat($schedule->schedule_date,"d-m-Y");
            }
            $response['status'] = 'success';
            $response['schedule'] = $schedules;

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
    public function addSchedule(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'barber_id' => 'required',
                'schedule_date' => 'required',
                'from_time'=>"required",
                'to_time'=>"required",
            ]);

            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
           
            $object = new BarberSchedule();
            $object->barber_id = $request->input("barber_id");
            $object->schedule_date = dateFormat($request->input("schedule_date"),"Y-m-d");
            $object->from_time = $request->input("from_time");
            $object->to_time = $request->input("to_time");
            $object->save();
            
            $response['status'] = 'success';
            $response['message'] = 'Barber schedule added successfully';
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function updateSchedule(Request $request){
        try{
            
            $validator = Validator::make($request->all(), [
                'id' => 'required',
                'barber_id' => 'required',
                'schedule_date' => 'required',
                'from_time'=>"required",
                'to_time'=>"required",
            ]);

            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $id = $request->input("id");
            $object = BarberSchedule::find($id);
            $object->barber_id = $request->input("barber_id");
            $object->schedule_date = dateFormat($request->input("schedule_date"),"Y-m-d");
            $object->from_time = $request->input("from_time");
            $object->to_time = $request->input("to_time");
            $object->save();
            
            $response['status'] = 'success';
            $response['message'] = 'Barber schedule updated successfully';
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function deleteSchedule(Request $request){
        try{
            $schedule_id = $request->input("schedule_id");
            BarberSchedule::where("id",$schedule_id)->delete();
            $response['status'] = 'success';
            $response['message'] = "Barber schedule deleted successfully";
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function breakList(Request $request){
        try{
            $barber_id = $request->input("barber_id");
            $breaks = BarberBreak::select('id','break_date','from_time','to_time')
                                ->where("barber_id",$barber_id)
                                ->orderBy("break_date","desc")
                                ->get();
            foreach($breaks as $break){
                $break->break_date = dateFormat($break->break_date,"d-m-Y");
            }
            $response['status'] = 'success';
            $response['breaks'] = $breaks;

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
    public function addBreak(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'barber_id' => 'required',
                'break_date' => 'required',
                'from_time'=>"required",
                'to_time'=>"required",
            ]);

            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
           
            $object = new BarberBreak();
            $object->barber_id = $request->input("barber_id");
            $object->break_date = dateFormat($request->input("break_date"),"Y-m-d");
            $object->from_time = $request->input("from_time");
            $object->to_time = $request->input("to_time");
            $object->save();
            
            $response['status'] = 'success';
            $response['message'] = 'Barber break added successfully';
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function updateBreak(Request $request){
        try{
            
            $validator = Validator::make($request->all(), [
                'id' => 'required',
                'barber_id' => 'required',
                'break_date' => 'required',
                'from_time'=>"required",
                'to_time'=>"required",
            ]);

            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $id = $request->input("id");
            $object = BarberBreak::find($id);
            $object->barber_id = $request->input("barber_id");
            $object->break_date = dateFormat($request->input("break_date"),"Y-m-d");
            $object->from_time = $request->input("from_time");
            $object->to_time = $request->input("to_time");
            $object->save();
            
            $response['status'] = 'success';
            $response['message'] = 'Barber break updated successfully';
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function deleteBreak(Request $request){
        try{
            $break_id = $request->input("break_id");
            BarberBreak::where("id",$break_id)->delete();
            $response['status'] = 'success';
            $response['message'] = "Barber break deleted successfully";
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
}
