<?php

namespace App\Http\Controllers\Webservices;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Validator;

use App\Customers;
use App\Saloons;
use App\SaloonServices;
use App\Services;
use App\Barbers;
use App\Bookings;
use App\BookingItems;
use App\Ratings;
use App\BarberSchedule;
use App\BarberBreak;

class CustomersController extends Controller
{
    public function __construct()
    {
        header('Access-Control-Allow-Origin: *');
        header('Access-Control-Allow-Methods: GET, PUT, POST, DELETE, OPTIONS');
        header("Content-Type: application/json");
    }

    public function loginAsCustomer(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'mobile' => 'required'
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $response['login'] = false;
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $mobile = $request->input("mobile");
            $user = Customers::select('id','name','email','mobile')->where("mobile",$mobile)->first();
            if(empty($user)){
                $response['status'] = 'error';
                $response['login'] = false;
                $response['message'] = 'Invalid mobile no';
                return response()->json($response);
            }else{                
                $response['status'] = 'success';
                $response['login'] = true;
                $response['message'] = 'Login success';
                $response['user'] = $user;
            }
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function customerRegister(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'name' => 'required',
                'email' => 'required|email|unique:customers',
                'mobile' => 'required|unique:customers'
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }

            $object = new Customers();
            $object->name = $request->input("name");
            $object->email = $request->input("email");
            $object->mobile = $request->input("mobile");
            $object->status = 1;
            $object->save();
            $id = $object->id;
            $user = Customers::select('id','name','email','mobile')->where("id",$id)
                            ->first();
            $response['status'] = 'success';
            $response['message'] = 'Register success';
            $response['user'] = $user;

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function getTimeSlot(Request $request){
        try{
            
            $saloon_id = $request->input("saloon_id");
            $barber_id = $request->input("barber_id");
            $date = $request->input("book_date");
            $service_ids = $request->input("services");
            $service_time = SaloonServices::whereIn("id",$service_ids)->sum(\DB::raw("TIME_TO_SEC(duration)"));
            $service_time = (int)$service_time;
            $saloon = Saloons::where("id",$saloon_id)->first();
            
            // $sl_start_time = $saloon->open_time;
            // $sl_close_time = $saloon->close_time;

            $barber_schedule = BarberSchedule::where("schedule_date",$date)->first();
            if(empty($barber_schedule)){
                $response['status'] = 'error';
                $response['message'] = "Barber not available for the day";
                return response()->json($response);
            }
            $barber_break = BarberBreak::where("break_date",$date)->get();

            $sl_start_time = $barber_schedule->from_time;
            $sl_close_time = $barber_schedule->to_time;

            $minutes = $service_time/60;
            $starttime = date("Y-m-d H:i",strtotime($date." ".$sl_start_time));
            $endtime = date("Y-m-d H:i",strtotime($date." ".$sl_close_time));

            $array_of_time = array ();
            $start_time    = strtotime ($starttime); //change to strtotime
            $end_time      = strtotime ($endtime); //change to strtotime

            $add_mins  = $minutes * 60;
            // echo $add_mins;
            $bookings = Bookings::where("book_date",$date)
                                   ->where("saloon_id",$saloon_id)
                                   ->where("barber_id",$barber_id)
                                   ->orderBy("from_time","asc")
                                   ->get(); 
            // pre($booked_slot->toArray());
            $available_time = array();
            $times = array();
            $prev_endtime = array();
            // pre($sl_start_time);
            // pre($sl_close_time);
            // echo "<hr>";
            $booked_slot = array();
            foreach($bookings as $slot){
                $temp = new object();
                $temp->from_time = $slot->from_time;
                $temp->to_time = $slot->to_time;
                $booked_slot[] = $temp;
            }
            foreach($barber_break as $slot){
                $temp = new \stdClass();
                $temp->from_time = $slot->from_time;
                $temp->to_time = $slot->to_time;
                $booked_slot[] = $temp;
            }
            foreach($booked_slot as $key => $slot){
                if($key == 0){

                    $start_time = date("Y-m-d H:i",strtotime($date." ".$sl_start_time));
                    $end_time = date("Y-m-d H:i",strtotime($date." ".$slot->from_time));
                    $prev_endtime[$key] = $slot->to_time;
                    $starttime = strtotime($start_time);
                    $endtime = strtotime($end_time);
                    $valid = 1;
                    
                    $time_slots = $this->timeSlot($starttime,$endtime,$add_mins);
                    $array_of_time = array_merge($array_of_time,$time_slots);
                    
                    
                }else{
                    
                    $start_time = date("Y-m-d H:i",strtotime($date." ".$prev_endtime[$key-1]));
                    $end_time = date("Y-m-d H:i",strtotime($date." ".$slot->from_time));

                    $prev_endtime[$key] = $slot->to_time;

                    $starttime = strtotime($start_time);
                    $endtime = strtotime($end_time);

                    $time_slots = $this->timeSlot($starttime,$endtime,$add_mins);
                    $array_of_time = array_merge($array_of_time,$time_slots);
                    
                }
            }

            $start_time = date("Y-m-d H:i",strtotime($date." ".end($prev_endtime)));
            $end_time = date("Y-m-d H:i",strtotime($date." ".$sl_close_time));

            $starttime = strtotime($start_time);
            $endtime = strtotime($end_time);

            $time_slots = $this->timeSlot($starttime,$endtime,$add_mins);
            $array_of_time = array_merge($array_of_time,$time_slots);
            
            $array_of_time = array_values(array_unique($array_of_time));
           

            $available_time = array();
            for($i=0;$i < count($array_of_time);$i++){
                if(isset($array_of_time[$i+1])){
                    $to_time=strtotime($array_of_time[$i+1]);
                    // echo $array_of_time[$i]." to ".$array_of_time[$i+1]."<Br>";
                    $from_time=strtotime($array_of_time[$i]); 
                    $time = array("start_time"=>$array_of_time[$i],"end_time"=>$array_of_time[$i+1]);
                  
                    $checkTime = Bookings::where("saloon_id",$saloon_id)
                                   ->where("barber_id",$barber_id)
                                   ->whereDate("book_date",$date)
                                   ->get(); 
                    // echo "<Br>".$checkTime;
                    $is_valid = 1;
                    foreach($checkTime as $ctime){
                         $f_time =strtotime($ctime->from_time);
                         $t_time =strtotime($ctime->to_time);
                         if($to_time >= $f_time && $to_time <= $t_time){
                            $is_valid = 0;
                         }
                    }
                    // if($checkTime > 0){
                    //     $is_valid = 0;
                    // }

                    $checkTime = BarberBreak::where("barber_id",$barber_id)
                                   ->whereDate("break_date",$date)
                                   ->get(); 
                    foreach($checkTime as $ctime){
                         $f_time =strtotime($ctime->from_time);
                         $t_time =strtotime($ctime->to_time);
                         if($to_time >= $f_time && $to_time <= $t_time){
                            $is_valid = 0;
                         }
                    }
                    // if($checkTime > 0){
                    //     $is_valid = 0;
                    // }
                    if($is_valid == 1){
                        $diff = round(abs($to_time - $from_time) / 60,2);
                        if($diff == $minutes){
                            $available_time[] = array("start_time"=>$array_of_time[$i],"end_time"=>$array_of_time[$i+1]);
                        }
                    }
                    
                }
            }
            $response['status'] = 'success';
            $response['minutes'] = $minutes;
            $response['available_time'] = $available_time;

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function timeSlot($start_time,$end_time,$add_mins){
        $array_of_time = array();
        while ($start_time <= $end_time) // loop between time
        {
           $array_of_time[] = date("H:i", $start_time);
           $start_time += $add_mins; // to check endtie=me
        }
        return $array_of_time;

    }

    public function bookService(Request $request){
        try{
            $saloon_id = $request->input("saloon_id");
            $barber_id = $request->input("barber_id");
            $customer_id = $request->input("customer_id");
            $date = $request->input("book_date");
            $service_ids = $request->input("services");
            $booked_time = $request->input("booked_time");

            $customer = Customers::where("id",$customer_id)->first();

            $total_price = SaloonServices::whereIn("id",$service_ids)->sum("price");
            $services = SaloonServices::whereIn("id",$service_ids)->get();

            $object = new Bookings();
            $object->saloon_id = $saloon_id;
            $object->barber_id = $barber_id;
            $object->customer_id = $customer_id;
            $object->book_date = $date;
            $object->total = $total_price;
            $object->from_time = $booked_time['start_time'];
            $object->to_time = $booked_time['end_time'];
            $object->book_number = mt_rand(100000,999999);
            $object->transaction_id = mt_rand(100000,999999);
            $object->billing_name = $customer->name;
            $object->billing_mobile = $customer->mobile;
            $object->billing_email = $customer->email;
            $object->created_by = $customer_id;
            $object->save();
            $book_id  = $object->id;
            foreach($services as $service){
                $newobj = new BookingItems();
                $newobj->booking_id = $book_id;
                $newobj->service_id = $service->service_id;
                $newobj->main_service_id = $service->id;
                $newobj->price = $service->price;
                $newobj->save();
            }   
            $booking = Bookings::select("id","book_number","book_date","from_time","to_time","total","billing_name","billing_email","billing_mobile")
                            ->where("id",$book_id)
                            ->first();
            $booking_services = BookingItems::with('Service')->where("booking_id",$book_id)->get();
            $services = array();
            foreach($booking_services as $serv){
                $temp['service_name'] = $serv->Service->name;
                $temp['service_price'] = $serv->price;
                $services[] = $temp;
            }
            $response['status'] = "success";
            $response['booking'] = $booking;
            $response['services'] = $services;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function customerBookings(Request $request){
        try{
            $customer_id = $request->input("customer_id");
            $bookings = Bookings::where("customer_id",$customer_id)
                                ->whereHas("Saloon")
                                ->whereHas("Barber")
                                ->orderBy("book_date","desc")->get();
            $bookingList = array();
            foreach($bookings as $booking){
                $temp = array();
                $temp['id'] = $booking->id;
                $temp['book_date'] = dateFormat($booking->book_date,"d-m-Y");
                $temp['saloon_name'] = $booking->Saloon->saloon_name;
                $temp['saloon_id'] = $booking->saloon_id;
                $temp['barber_name'] = $booking->Barber->name;
                $temp['barber_id'] = $booking->barber_id;
                $temp['book_number'] = $booking->book_number;
                $temp['from_time'] = $booking->from_time;
                $temp['to_time'] = $booking->to_time;
                $temp['total_price'] = $booking->total;
                $temp['transaction_id'] = $booking->transaction_id;
                $temp['billing_name'] = $booking->billing_name;
                $temp['billing_mobile'] = $booking->billing_mobile;
                $temp['billing_email'] = $booking->billing_email;
                $date = $booking->book_date." ".$booking->to_time;
                $current_date = date("Y-m-d H:i:s");
                if($date > $current_date){
                    $temp['status'] = 'Upcoming';
                }else{
                    $temp['status'] = 'Completed';
                }

                $booking_services = BookingItems::with('Service')->where("booking_id",$booking->id)->get();
                $services = array();
                foreach($booking_services as $serv){
                    $temp['service_name'] = $serv->SaloonService->service_name;
                    $temp['service_price'] = $serv->price;
                    $services[] = $temp;
                }
                $temp['services'] = $services;

                $bookingList[] = $temp;
            }
            $response['status'] = 'success';
            $response['booking_list'] = $bookingList;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
    
    public function barberRating(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'barber_id' => 'required',
                'rating' => 'required'
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $barber_id = $request->input("barber_id");
            $barber = Barbers::where("id",$barber_id)->first();
            $object = new Ratings();
            $object->barber_id = $barber_id;
            $object->saloon_id = $barber->saloon_id;
            $object->rating = $request->input("rating");
            $object->customer_id = $request->input("customer_id");
            $object->save();

            $response['status'] = 'success';
            $response['message'] = 'Barber rated successfully';

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
}
