<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Validator;
use View;

use App\Saloons;
use App\Barbers;
use App\BarbersServices;
use App\Services;
use App\SaloonServices;
use App\BarberBreak;
use App\BarberSchedule;
use App\Bookings;

class BarbersController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }
    public function list(){
    	$viewData['pageTitle'] = 'Barbers';
        // $viewData['records'] = Barbers::whereHas('Saloon')->orderBy('id','desc')->paginate();
        $viewData['records'] = Barbers::where("is_deleted", 0)->whereHas('Saloon')->orderBy('id','desc')->paginate();
        return view('barbers.list',$viewData);
    }
    
    public function addNew(){
        $viewData['pageTitle'] = 'Add Barber';
        $viewData['timestamp'] = time();
        $viewData['saloons'] = Saloons::where('status',1)->get();
        return view('barbers.add',$viewData);
    }

    public function save(Request $request){
        $validator = Validator::make($request->all(), [
            'saloon_id' => 'required',
            'name' => 'required',
            'email' => 'required|email|unique:barbers',
            'mobile' => 'required',
            'profile_image' => 'required|mimes:jpeg,bmp,png,jpg',
            'password' => 'required',
            // 'services'=>'required'
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        
        $object = new Barbers();
        $object->name = $request->input("name");
        $object->email = $request->input("email");
        $object->mobile = $request->input("mobile");
        $object->saloon_id = $request->input("saloon_id");
        $object->password = bcrypt($request->input("password"));
        
        if($request->file("profile_image")){
        	$file = $request->file("profile_image");
        	$fileName  = $file->getClientOriginalName();
            $extension = $file->getClientOriginalExtension() ?: 'png';
            $newName   = mt_rand(1,99999)."-".$fileName;

            $source_url = $file->getPathName();
            
            $destinationPath = 'uploads/profile_images/';
            if($file->move($destinationPath, $newName)){
               $object->profile_image = $newName;
            }
        }
        if($request->input("status")){
        	$object->status = 1;	
        }else{
        	$object->status = 0;	
        }
        $object->created_by = \Auth::user()->id;
        $object->save();
        $barber_id = $object->id;

        $saloonServices = SaloonServices::select('saloon_services.service_id','saloon_services.id','saloon_services.service_description','saloon_services.price','saloon_services.duration','saloon_services.service_name')->where('saloon_id',$request->input("saloon_id"))->where('is_deleted',0)->groupBy('service_id')->get();
        if(count($saloonServices) > 0)
        {
            foreach($saloonServices as $saloonservice)
            {
                $object = new BarbersServices();
                $object->saloon_id = $request->input("saloon_id");
                $object->barber_id = $barber_id;
                $object->service_id = $saloonservice->service_id;
                $object->saloon_service_id = $saloonservice->id;
                $object->service_name = $saloonservice->service_name;
                $object->service_description = $saloonservice->service_description;
                $object->price = $saloonservice->price;
                $object->duration = $saloonservice->duration;
                $object->created_by = \Auth::user()->id;
                $object->save();
            }
        }
        // if($request->input("services_ids")){
        //     $services_ids = $request->input("services_ids");
        //     BarbersServices::where("barber_id",$barber_id)->whereNotIn("service_id",$services_ids)->delete();
        //     $services = $request->input("services");
        //     foreach($services as $service){
                
        //         $object = new BarbersServices();
        //         $object->saloon_id = $request->input("saloon_id");
        //         $object->barber_id = $barber_id;
        //         $object->service_id = $service['service_id'];
        //         $object->duration = $service['duration'];
        //         $object->created_by = \Auth::user()->id;
        //         $object->save();
        //     }
        // }

        return redirect('/admin/barbers')->with("success","Record added successfully");
    }

    public function edit($id){
        $viewData['pageTitle'] = 'Edit Barber';
        $record = Barbers::with('Services')->find($id);
        $viewData['record'] = $record;
        $viewData['saloons'] = Saloons::where('status',1)->get();
        $barber_services = array();
        if(count($record->Services) > 0){
            $barber_services = $record->Services->pluck("service_id");
            if(count($barber_services) > 0){
                $barber_services = $barber_services->toArray();
            }
        }
        $viewData['bs_ids'] = $barber_services;
        $viewData['barber_services'] = $record->Services;
        $services = SaloonServices::where("saloon_id",$record->saloon_id)->get();
        $viewData['services'] = $services;
        //
        $queryBarberServices = BarbersServices::where("barber_id",$id)->get();
        $serviceCount = (string)count($queryBarberServices);
        $isService = "N";
        if($serviceCount > 0)
        {
            $isService = "Y";
        }
        $viewData['is_barber_service'] = $isService;
        return view('barbers.edit',$viewData);
    }

    public function update($id,Request $request){
    	$user = Barbers::find($id);
        $validator = Validator::make($request->all(), [
            'saloon_id' => 'required',
            'name' => 'required',
            'email' => 'required|email|unique:barbers,email,'.$user->id,
            'mobile' => 'required',
            'profile_image' => 'mimes:jpeg,bmp,png,jpg',
        ]);
        
        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $object = Barbers::find($id);
        $object->name = $request->input("name");
        $object->email = $request->input("email");
        $object->mobile = $request->input("mobile");
        $object->saloon_id = $request->input("saloon_id");
        $object->password = bcrypt($request->input("password"));
        
        if($request->file("profile_image")){
            $file = $request->file("profile_image");
            $fileName  = $file->getClientOriginalName();
            $extension = $file->getClientOriginalExtension() ?: 'png';
            $newName   = mt_rand(1,99999)."-".$fileName;

            $source_url = $file->getPathName();
            
            $destinationPath = 'uploads/profile_images/';
            if($user->profile_image != '' && file_exists($destinationPath.$user->profile_image)){
                unlink($destinationPath.$user->profile_image);
            }
            if($file->move($destinationPath, $newName)){
               $object->profile_image = $newName;
            }
        }
        if($request->input("status")){
            $object->status = 1;    
        }else{
            $object->status = 0;    
        }
        $object->updated_by = \Auth::user()->id;
        $object->save();
        $barber_id = $id;
        // if($request->input("services_ids")){
        //     $services_ids = $request->input("services_ids");
        //     BarbersServices::where("barber_id",$barber_id)->whereNotIn("service_id",$services_ids)->delete();
        //     $services = $request->input("services");
        //     foreach($services as $service){
                
        //         $checkSevice = BarbersServices::where("barber_id",$barber_id)
        //                     ->where("service_id",$service['service_id'])
        //                     ->first();
        //         if(empty($checkSevice)){
        //             $object = new BarbersServices();
        //             $object->created_by = \Auth::user()->id;
        //         }else{
        //             $object = BarbersServices::find($checkSevice->id);
        //             $object->updated_by = \Auth::user()->id;
        //         }
        //         $object->saloon_id = $request->input("saloon_id");
        //         $object->barber_id = $barber_id;
        //         $object->service_id = $service['service_id'];
        //         $object->duration = $service['duration'];
        //         $object->save();
        //     }
        // }

        return redirect('/admin/barbers')->with("success","Record updated successfully");
    }

    public function deleteRecord($id){
        Barbers::where("id",$id)->update(['deleted_by'=>\Auth::user()->id]);
        BarbersServices::where("barber_id",$id)->update(['deleted_by'=>\Auth::user()->id]);
        
        BarbersServices::where("barber_id",$id)->delete();
    	Barbers::where("id",$id)->delete();
    	return redirect('/admin/barbers')->with("success","Record deleted successfully");
    }

    public function getSaloonService(Request $request){
        $id = $request->input("saloon_id");
        $services = SaloonServices::where("saloon_id",$id)->get();
        if($request->input("barber_id")){
            $barber_id = $request->input("barber_id");
            $bs = BarbersServices::where("saloon_id",$id)
                                ->where("barber_id",$barber_id)
                                ->get();
            $barber_services = array();
            foreach($bs as $serv){
                $barber_services[$serv->service_id] = $serv->duration;
            }
            $viewData['barber_services'] = $barber_services;
        }
        $viewData['services'] = $services;
        $view = View::make('barbers.services-list',$viewData);
        $contents = $view->render();
        // $options = '<option value=""></option>';
        // foreach($services as $service){
        //     $options .= '<option value="'.$service->id.'">'.$service->name.'</option>';
        // }
        $response['services'] = $contents;
        return response()->json($response);
    }

    public function deleteAllRecord(Request $request)
    {
        // dd($request->all());
        /*BarberSchedule::whereIn("barber_id",$request->id)->delete();
        BarberBreak::whereIn("barber_id",$request->id)->delete();
        BarbersServices::whereIn("barber_id",$request->id)->delete();
        Barbers::whereIn("id",$request->id)->delete();*/
        $arr_update_barber = array(
            "is_deleted" => 1,
            "deleted_by" => \Auth::user()->id,
            "deleted_at" => date("Y-m-d H:i:s")
        );
        $arr_update_barberschedulebreak = array(
            "is_deleted" => 1,
            "deleted_at" => date("Y-m-d H:i:s")
        );
        BarberSchedule::whereIn("barber_id",$request->id)->update($arr_update_barberschedulebreak);
        BarberBreak::whereIn("barber_id",$request->id)->update($arr_update_barberschedulebreak);
        BarbersServices::whereIn("barber_id",$request->id)->update($arr_update_barber);
        Barbers::whereIn("id",$request->id)->update($arr_update_barber);
        echo 1;
        exit;
    }

    public function downloadimage($file="")
    {
        $file_name1=$file;
        header("Content-type: application/octet-stream");
        header("Content-Disposition: attachment; filename=\"$file_name1\"");
        $filename = 'uploads/profile_images/' . $file_name1;
        $handle = fopen($filename, "r");
        $data = fread($handle, filesize($filename));
        fclose($handle);
        echo $data;
        // $common = new commonfunction();
        // $common->unlinkfiles($filename);
        //$pathdelete = $_SERVER['DOCUMENT_ROOT'].$filename;
        if(file_exists($filename))
        {
            // @unlink($filename);
        }
    }

    public function scheduleList(Request $request)
    {
        $barber_id = $request->input("barber_id");
        $viewData['schedule'] = BarberSchedule::where("barber_id",$barber_id)->get();

        $view = View::make('barbers.schedule',$viewData);
        $contents = $view->render();
        $response['status'] = true;
        $response['contents'] = $contents;
        return response()->json($response);
    }

    public function addSchedule($barber_id){
        $viewData['barber_id'] = $barber_id;
        $viewData['pageTitle'] = "Add Schedule";
        $view = View::make('barbers.add-schedule',$viewData);
        $contents = $view->render();
        $response['status'] = true;
        $response['contents'] = $contents;
        return response()->json($response);
    }
    

    public function saveSchedule($barber_id,Request $request){
        // echo "<pre>";
        // print_r($request->all());
        // echo "</pre>";
        // exit;
        $validator = Validator::make($request->all(), [
            'schedule_date' => 'required',
            'from_time' => 'required',
            'to_time' => 'required',
        ]);

        if ($validator->fails()) {
            $response['status'] =false;
            $error = $validator->errors()->toArray();
            $errMsg = '';
            foreach($error as $key => $err){
                $errMsg .= $err[0];
            }
            $response['message'] = $errMsg;
            return response()->json($response);
        }

        $schedule_date = date("Y-m-d", strtotime($request->input('schedule_date')));
        $barber_schedule = BarberSchedule::where("schedule_date",$schedule_date)
        ->where('barber_id',$barber_id)
        ->get();
        if(count($barber_schedule) > 0)
        {
            $response['status'] = 'error';
            $response['message'] = "Invalid time schedule!";
            return response()->json($response);
        }

        $start_time = date("H:i",strtotime($request->input("from_time")));
        $end_time = date("H:i",strtotime($request->input("to_time")));
        if($start_time >= $end_time)
        {
            $response['status'] = 'error';
            $response['message'] = "Invalid time schedule!";
            return response()->json($response);
        }
        
        $object = new BarberSchedule();
        $object->schedule_date = date("Y-m-d", strtotime($request->input('schedule_date')));
        $object->from_time = date("H:i:s", strtotime($request->input('from_time')));
        $object->to_time = date("H:i:s", strtotime($request->input('to_time')));
        $object->barber_id = $barber_id;
        $object->created_at = date("Y-m-d H:i:s");
        $object->updated_at = date("Y-m-d H:i:s");
        $object->save();

        $response['status'] = true;
        $response['message'] = 'Schedule added successfully';
        return response()->json($response);
    }

    public function editSchedule($id){
        $record = BarberSchedule::where("id",$id)->first();
        $break = BarberBreak::where("barber_id",$record->barber_id)->where("break_date", $record->schedule_date)->get();
        $viewData['record'] = $record;
        $viewData['barber_break'] = $break;
        $viewData['pageTitle'] = "Edit Schedule";
        $view = View::make('barbers.edit-schedule',$viewData);
        $contents = $view->render();
        $response['status'] = true;
        $response['contents'] = $contents;
        return response()->json($response);
    }
    

    public function updateSchedule($id,Request $request){
        // echo "<pre>";
        // print_r($request->all());
        // echo "</pre>";
        // exit;
        $validator = Validator::make($request->all(), [
            // 'schedule_id' => 'required',
            'schedule_date' => 'required',
            'from_time' => 'required',
            'to_time' => 'required'
        ]);

        if ($validator->fails()) {
            $response['status'] =false;
            $error = $validator->errors()->toArray();
            $errMsg = '';
            foreach($error as $key => $err){
                $errMsg .= $err[0];
            }
            $response['message'] = $errMsg;
            return response()->json($response);
        }
        $object = BarberSchedule::find($id);
        $barber_id = $object->barber_id;
        $schedule_date = date("Y-m-d", strtotime($request->input('schedule_date')));
        $barber_schedule = BarberSchedule::where("schedule_date",$schedule_date)
        ->where('barber_id',$object->barber_id)
        ->where('id', '!=', $id)
        ->get();
        if(count($barber_schedule) > 0)
        {
            $response['status'] = 'error';
            $response['message'] = "Invalid time schedule!";
            return response()->json($response);
        }
        $start_time = date("H:i",strtotime($request->input("from_time")));
        $end_time = date("H:i",strtotime($request->input("to_time")));
        if($start_time >= $end_time)
        {
            $response['status'] = 'error';
            $response['message'] = "Invalid time schedule!";
            return response()->json($response);
        }
        //
        $object->schedule_date = date("Y-m-d", strtotime($request->input("schedule_date")));
        $object->from_time = date("H:i:s", strtotime($request->input("from_time")));
        $object->to_time = date("H:i:s", strtotime($request->input("to_time")));
        $object->updated_at = date("Y-m-d H:i:s");
        $object->save();

        if(isset($request->input()['break_from_time']) && isset($request->input()['break_to_time']))
        {
            for($i = 0; $i < count($request->input('break_from_time')); $i++)
            {
                $break_from = date("H:i:s", strtotime($request->input('break_from_time')[$i]));
                $break_to = date("H:i:s", strtotime($request->input('break_to_time')[$i]));
                //
                $barber_schedule = BarberSchedule::where("schedule_date",dateFormat($request->input("schedule_date"),"Y-m-d"))->where('barber_id',$barber_id)->first();
                if(empty($barber_schedule))
                {
                    $response['status'] = 'error';
                    $response['message'] = "Barber not available for the day";
                    return response()->json($response);
                    break;
                }
                
                $from_time = $break_from;
                $to_time = $break_to;
                $sl_start_time = $barber_schedule->from_time;
                $sl_close_time = $barber_schedule->to_time;
                //
                $barber_break = BarberBreak::where("break_date",dateFormat($request->input("schedule_date"),"Y-m-d"))
                ->where("from_time", date("H:i", strtotime($request->input("break_from_time")[$i])))
                ->where("to_time",date("H:i", strtotime($request->input("break_to_time")[$i])))
                ->where('barber_id',$barber_id)
                ->first();
                if(!(empty($barber_break)))
                {
                    $response['status'] = 'error';
                    $response['message'] = "Invalid break time!";
                    return response()->json($response);
                    break;
                }
                if($from_time > $sl_start_time && $to_time < $sl_close_time)
                {
                    $object = new BarberBreak();
                    $object->barber_id = $barber_id;
                    $object->break_date = dateFormat($request->input("schedule_date"),"Y-m-d");
                    $object->from_time = $break_from;
                    $object->to_time = $break_to;
                    $object->save();
                    
                    // $response['status'] = 'success';
                    // $response['message'] = 'Barber break added successfully';
                }else{
                    // echo $from_time."From & ".$sl_start_time."& To ".$to_time." = ".$sl_close_time;
                    $response['status'] = 'error';
                    $response['message'] = "Invalid break time!";
                    return response()->json($response);
                    break;
                }
            }
        }

        $response['status'] = true;
        $response['message'] = 'Schedule updated successfully';
        return response()->json($response);
    }

    public function deleteSchedule($id){
        $schedule = BarberSchedule::find($id);
        BarberSchedule::where("id",$id)->delete();
        BarberBreak::where("id",$schedule->barber_id)->delete();
        return redirect()->back()->with("success","Record deleted successfully");
    }
}
