<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Validator;
use View;

use App\Saloons;
use App\Barbers;
use App\BarbersServices;
use App\Services;
use App\SaloonServices;
use App\Bookings;
use App\BookingItems;
use App\Customers;

class BookingsController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }
    public function list(Request $request){
    	$viewData['pageTitle'] = 'Bookings';
        $selected_saloon = '';
        $selected_customer = '';
        $saloon_name = '';
        if($request->get("saloon")){
            $selected_saloon = $request->get("saloon");
        }

        if($request->get("customer")){
            $selected_customer = $request->get("customer");
        }
        
        if($selected_saloon != ''){
            $saloon = Saloons::where("id",$selected_saloon)->first();
            $saloon_name = $saloon->saloon_name;
        }
        
        $viewData['saloon_name'] = $saloon_name;
        $viewData['selected_saloon'] = $selected_saloon;
        $viewData['selected_customer'] = $selected_customer;
        $saloons = Saloons::where("status","1")->whereHas("Bookings")->get();
        $customers = Customers::where("status","1")->whereHas("Bookings")->get();
        $viewData['customers'] = $customers;
        $viewData['saloons'] = $saloons;
        /*$viewData['records'] = Bookings::with('BookingItems')
                                        ->whereHas("Saloon")
                                        ->whereHas("Barber")
                                        ->whereHas("Customer")
                                        ->where("payment_status", "=", "C")
                                        ->whereRaw("(action_type != 'R' OR action_type IS NULL)")
                                        ->where(function($query) use($selected_saloon,$selected_customer){
                                            if($selected_saloon != ''){
                                                $query->where("saloon_id",$selected_saloon);
                                            }
                                            if($selected_customer != ''){
                                                $query->where("customer_id",$selected_customer);
                                            }
                                        })
                                        ->orderBy('book_date','desc')
                                        ->orderBy('from_time','asc')
                                        ->paginate();*/
        $viewData['records'] = Bookings::where("is_deleted", 0)->with('BookingItems')
                                        ->whereHas("Saloon")
                                        ->whereHas("Barber")
                                        // ->whereHas("Customer")
                                        ->where("payment_status", "=", "C")
                                        ->whereRaw("(action_type != 'R' OR action_type IS NULL)")
                                        ->where(function($query) use($selected_saloon,$selected_customer){
                                            if($selected_saloon != ''){
                                                $query->where("saloon_id",$selected_saloon);
                                            }
                                            if($selected_customer != ''){
                                                $query->where("customer_id",$selected_customer);
                                            }
                                        })
                                        ->orderBy('book_date','desc')
                                        ->orderBy('from_time','asc')
                                        ->paginate();
        return view('bookings.bookings',$viewData);
    }
    
    public function viewBooking($id){
        $viewData['pageTitle'] = 'Booking Detail';
        $viewData['record'] = Bookings::where('id',$id)->first();
        return view('bookings.view-booking',$viewData);
    }

    public function reports(Request $request){
        $viewData['pageTitle'] = 'Reports';
        $selected_saloon = '';
        $start_date = '';
        $end_date = '';
        $records = array();
        if($request->get("filter")){
            if($request->get("saloon")){
                $selected_saloon = $request->get("saloon");
            }

            if($request->get("start_date")){
                $start_date = $request->get("start_date");
            }
            if($request->get("end_date")){
                $end_date = $request->get("end_date");
            }
            $records = Bookings::with('BookingItems')
                                ->whereHas("Saloon")
                                ->whereHas("Barber")
                                ->whereHas("Customer")
                                ->where("status", "!=", "cancelled")
                                ->where("status", "!=", "emergency cancellation")
                                ->where("payment_status", "=", "C")
                                ->whereRaw("(action_type != 'R' OR action_type IS NULL)")
                                ->where(function($query) use($selected_saloon,$start_date,$end_date){
                                    if($selected_saloon != ''){
                                        $query->where("saloon_id",$selected_saloon);
                                    }
                                    if($start_date != ''){
                                        $query->where("book_date",">=",dateFormat($start_date,"Y-m-d"));
                                    }
                                    if($end_date != ''){
                                        $query->where("book_date","<=",dateFormat($end_date,"Y-m-d"));
                                    }
                                })
                                ->orderBy('book_date','desc')
                                ->orderBy('from_time','asc')
                                ->groupBy("saloon_id")
                                ->paginate();

        }foreach($records as $record){
            $total_booking = Bookings::where("saloon_id",$record->saloon_id)
                                    ->where("book_date",$record->book_date)
                                    ->where("status", "!=", "cancelled")
                                    ->where("status", "!=", "emergency cancellation")
                                    ->where("payment_status", "=", "C")
                                    ->whereRaw("(action_type != 'R' OR action_type IS NULL)")
                                    ->count();
            $record->total_booking = $total_booking;
        }
        
        $viewData['selected_saloon'] = $selected_saloon;
        $viewData['start_date'] = $start_date;
        $viewData['end_date'] = $end_date;
        $saloons = Saloons::where("status","1")->whereHas("Bookings")->get();
        
        $viewData['saloons'] = $saloons;
        $viewData['records'] = $records;
        return view('bookings.reports',$viewData);
    }

    public function deleteAllRecord(Request $request)
    {
        // dd($request->all());
        $arr_update = array(
            "is_deleted" => 1,
            "deleted_at" => date("Y-m-d H:i:s")
        );
        Bookings::whereIn("id",$request->id)->update($arr_update);
        echo 1;
        exit;
    }
}
