<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Validator;
use App\Customers;
use App\Countries;
use App\States;
use App\Cities;
use Session;

class CustomersController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }
    public function list(){
    	$viewData['pageTitle'] = 'Customers';
        // $viewData['records'] = Customers::orderBy('id','desc')->paginate();
        $viewData['records'] = Customers::where("is_deleted", 0)->orderBy('id','desc')->paginate();
        return view('customers.list',$viewData);
    }
    
    public function addNew(){
        $viewData['pageTitle'] = 'Add Customer';
        $viewData['timestamp'] = time();
        $viewData['countries'] = Countries::get();
        
        return view('customers.add',$viewData);
    }

    public function save(Request $request){
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'email' => 'required|email|unique:customers',
            'mobile' => 'required',
            'address' => 'required',
            // 'country_id' => 'required',
            // 'state_id' => 'required',
            // 'city_id' => 'required',
            'password' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        
        $object = new Customers();
        $object->name = $request->input("name");
        $object->email = $request->input("email");
        $object->mobile = $request->input("mobile");
        $object->address = $request->input("address");
        if($request->input("country_id")){
            $object->country_id = $request->input("country_id");
        }
        if($request->input("state_id")){
            $object->state_id = $request->input("state_id");
        }
        if($request->input("city_id")){
            $object->city_id = $request->input("city_id");
        }
        $object->created_by = \Auth::user()->id;
        $object->password = bcrypt($request->input("password"));
        if($request->input("status")){
        	$object->status = 1;	
        }else{
        	$object->status = 0;	
        }
        $object->save();


        return redirect('/admin/customers')->with("success","Record added successfully");
    }

    public function edit($id){
        $viewData['pageTitle'] = 'Edit Customers';
        $record = Customers::find($id);
        $viewData['record'] = $record;
        $viewData['countries'] = Countries::get();
        $viewData['states'] = States::where('country_id',$record->country_id)->get();
        $viewData['cities'] = Cities::where('state_id',$record->state_id)->get();

        return view('customers.edit',$viewData);
    }

    public function update($id,Request $request){
    	$user = Customers::find($id);
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'email' => 'required|email|unique:customers,email,'.$user->id,
            'mobile' => 'required',
            'address' => 'required',
            // 'country_id' => 'required',
            // 'state_id' => 'required',
            // 'city_id' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $object = Customers::find($id);
        $object->name = $request->input("name");
        $object->email = $request->input("email");
        $object->mobile = $request->input("mobile");
        $object->address = $request->input("address");
        if($request->input("country_id")){
            $object->country_id = $request->input("country_id");
        }
        if($request->input("state_id")){
            $object->state_id = $request->input("state_id");
        }
        if($request->input("city_id")){
            $object->city_id = $request->input("city_id");
        }
        $object->updated_by = \Auth::user()->id;
        if($request->input("password")){
        	$object->password = bcrypt($request->input("password"));
    	}
        if($request->input("status")){
        	$object->status = 1;	
        }else{
        	$object->status = 0;	
        }
        $object->save();

        return redirect('/admin/customers')->with("success","Record updated successfully");
    }

    public function deleteRecord($id){
        Customers::where("id",$id)->update(['deleted_by'=>\Auth::user()->id]);
        Customers::where("id",$id)->delete();
    	return redirect('/admin/customers')->with("success","Record deleted successfully");
    }

    public function deleteAllRecord(Request $request)
    {
        // dd($request->all());
        $arr_update = array(
            "is_deleted" => 1,
            "deleted_by" => \Auth::user()->id,
            "deleted_at" => date("Y-m-d H:i:s")
        );
        Customers::whereIn("id",$request->id)->update($arr_update);
        // Customers::whereIn("id",$request->id)->delete();
        echo 1;
        exit;
    }
}
