<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Validator;

use App\Saloons;
use App\Barbers;
use App\Customers;
use App\User;
use App\Bookings;

class DashboardController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
    	$saloons = Saloons::where("is_deleted", 0)->count();
    	$barbers = Barbers::whereHas('Saloon')->count();
    	$customers = Customers::count();
        $bookings = Bookings::with('BookingItems')->whereHas("Saloon")->where('book_date','>=',date("Y-m-d"))->count();
    	$viewData['saloons'] = $saloons;
        $viewData['bookings'] = $bookings;
    	$viewData['barbers'] = $barbers;
    	$viewData['customers'] = $customers;

        return view('dashboard',$viewData);
    }

    public function editProfile(){
        $viewData['pageTitle'] = 'Edit Profile';
        $id = \Auth::user()->id;
        $viewData['record'] = User::find($id);
        return view('edit-profile',$viewData);
    }

    public function updateProfile(Request $request){
        $id = \Auth::user()->id;
        $user = User::find($id);
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'email' => 'required|email|unique:users,email,'.$user->id,
            'phone_no' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        
        $object = User::find($id);
        $object->name = $request->input("name");
        $object->email = $request->input("email");
        $object->phone_no = $request->input("phone_no");
        if($request->input("password")){
            $object->password = bcrypt($request->input("password"));
        }
        // if($request->file("profile_image")){
        //     $file = $request->file("profile_image");
        //     $fileName  = $file->getClientOriginalName();
        //     $extension = $file->getClientOriginalExtension() ?: 'png';
        //     $newName   = mt_rand(1,99999)."-".$fileName;

        //     $source_url = $file->getPathName();
            
        //     $destinationPath = public_path('/uploads/profile_images/');
        //     if($file->move($destinationPath, $newName)){
        //        $object->profile_image = $newName;
        //     }
        // }
        $object->updated_by = \Auth::user()->id;
        $object->save();

        return redirect()->back()->with("success","Profile updated successfully");
    }
}
