<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Validator;
use App\Customers;
use App\Countries;
use App\States;
use App\Cities;
use App\SaloonPayments;
use App\Saloons;

class PaymentsController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }
    public function list(){
    	$viewData['pageTitle'] = 'Payments';
        $viewData['records'] = SaloonPayments::where("is_deleted",0)->orderBy('id','desc')->with("Saloon")->paginate();
        return view('saloonpayments.list',$viewData);
    }
    
    public function addNew(){
        $viewData['pageTitle'] = 'Add Payment';
        $viewData['timestamp'] = time();
        $viewData['saloons'] = Saloons::where("status",1)->get();
        
        return view('saloonpayments.add',$viewData);
    }

    public function save(Request $request){
        $validator = Validator::make($request->all(), [
            'saloon_id' => 'required',
            'amount' => 'required',
            'date' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        
        $object = new SaloonPayments();
        $object->saloon_id = $request->input("saloon_id");
        $object->payment_date = date("Y-m-d", strtotime($request->input("date")));
        $object->amount = $request->input("amount");
        $object->admin_id = \Auth::user()->id;
        $object->ipaddress = $_SERVER['REMOTE_ADDR'];
        $object->created_at = date("Y-m-d H:i:s");
        $object->updated_at = date("Y-m-d H:i:s");
        $object->save();


        return redirect('/admin/payments')->with("success","Record added successfully");
    }

    public function edit($id){
        $viewData['pageTitle'] = 'Edit Payments';
        $record = SaloonPayments::find($id);
        $viewData['record'] = $record;
        $viewData['saloons'] = Saloons::where("status",1)->get();
        return view('saloonpayments.edit',$viewData);
    }

    public function update($id,Request $request){
    	$user = SaloonPayments::find($id);
        $validator = Validator::make($request->all(), [
            'amount' => 'required',
        ]);
        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $object = SaloonPayments::find($id);
        $object->amount = $request->input("amount");
        $object->updated_at = date("Y-m-d H:i:s");
        $object->updated_by = \Auth::user()->id;
        $object->save();

        return redirect('/admin/payments')->with("success","Record updated successfully");
    }

    public function deleteRecord($id){
        SaloonPayments::where("id",$id)->update(
            [
                'is_deleted' => 1,
                'updated_at' => date("Y-m-d H:i:s"),
                'updated_by'=>\Auth::user()->id
            ]
        );
    	return redirect('/admin/payments')->with("success","Record deleted successfully");
    }

    public function checkpayment(Request $request)
    {
        if(!(empty($request->all())))
        {
            $oSaloonPayments = SaloonPayments::where("saloon_id", $request->input('saloon_id'))
            ->where("payment_date", date("Y-m-d", strtotime($request->input('date'))))
            ->where("is_deleted", 0)
            ->get();
            if(count($oSaloonPayments) > 0)
            {
                echo 0;
            }
            else
            {
                echo 1;
            }
            exit;
        }
        echo 0;
        exit;
    }
}
