<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Validator;
use View;

use App\Saloons;
use App\Barbers;
use App\SaloonServices;
use App\Services;
use App\Countries;
use App\States;
use App\Cities;
use App\SaloonGallery;
use App\SaloonFavourites;
use App\Rules\RazorpayLinkAccount;

class SaloonsController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }
    public function list(){
    	$viewData['pageTitle'] = 'Salons';
        // $viewData['records'] = Saloons::orderBy('id','desc')->paginate();
        $viewData['records'] = Saloons::where("is_deleted", 0)->orderBy('id','desc')->paginate();
        return view('saloons.list',$viewData);
    }
    
    public function addNew(){
        $viewData['pageTitle'] = 'Add Salon';
        $viewData['timestamp'] = time();
        $viewData['services'] = Services::where("status","1")->get();
        $viewData['countries'] = Countries::get();
        return view('saloons.add',$viewData);
    }

    public function save(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'saloon_name' => 'required',
            'contact_person' => 'required',
            'email' => 'required|email|unique:saloons',
            'mobile' => 'required',
            'street_address' => 'required',
            // 'country_id' => 'required',
            // 'state_id' => 'required',
            // 'city_id' => 'required',
            'open_time' => 'required',
            'close_time' => 'required',
            'password' => 'required',
            'bank_name' => 'required',
            'account_number' => 'required',
            'ifsc_code' => 'required',
            'upi_id' => 'required',
            'razorpay_account_id'=>['required', new RazorpayLinkAccount]
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $open_time = $request->input("open_time");
        $close_time = $request->input("close_time");
        if(strtotime($close_time) < strtotime($open_time)){
            return redirect()->back()->withInput()->with("time_error","Close time should be greater then open time");   
        }
        $object = new Saloons();
        $object->saloon_name = $request->input("saloon_name");
        $object->contact_person = $request->input("contact_person");
        $object->email = $request->input("email");
        $object->mobile = $request->input("mobile");
        $object->street_address = $request->input("street_address");
        $object->country_id = $request->input("country_id");
        $object->state_id = $request->input("state_id");
        $object->city_id = $request->input("city_id");
        $object->open_time = $request->input("open_time");
        $object->close_time = $request->input("close_time");
        $object->bank_name = $request->input("bank_name");
        $object->account_number = $request->input("account_number");
        $object->ifsc_code = $request->input("ifsc_code");
        $object->upi_id = $request->input("upi_id");
        $object->razorpay_account_id = $request->input("razorpay_account_id");
        $object->password = bcrypt($request->input("password"));
        if($request->input("latitude")){
        	$object->latitude = $request->input("latitude");
        }
        if($request->input("logitude")){
        	$object->logitude = $request->input("logitude");
        }
        if($request->input("instagram")){
        	$object->instagram = $request->input("instagram");
        }
        if($request->input("facebook")){
        	$object->facebook = $request->input("facebook");
        }
        if($request->input("twitter")){
        	$object->twitter = $request->input("twitter");
        }
        if($request->input("status")){
        	$object->status = 1;	
        }else{
        	$object->status = 0;	
        }
        if($request->input("address_line_2")){
            $object->address_line_2 = $request->input("address_line_2");    
        }else{
            $object->address_line_2 = "";
        }
        if($request->input("zipcode")){
            $object->zipcode = $request->input("zipcode");    
        }else{
            $object->zipcode = "";
        }
        if($request->input("youtube_url")){
            $object->youtube_url = $request->input("youtube_url");    
        }else{
            $object->youtube_url = "";
        }

        if($request->file("owner_image")){
            $file = $request->file("owner_image");
            $fileName  = $file->getClientOriginalName();
            $extension = $file->getClientOriginalExtension() ?: 'png';
            $newName   = mt_rand(1,99999)."-".$fileName;
            $source_url = $file->getPathName();            
            $destinationPath = 'uploads/profile_images/';
            if($file->move($destinationPath, $newName)){
               $object->owner_image = $newName;
            }
        }
        $object->created_by = \Auth::user()->id;
        $object->save();

        if($request->file("gallery_image_1"))
        {
            $file = $request->file("gallery_image_1");
            $fileName  = $file->getClientOriginalName();
            $extension = $file->getClientOriginalExtension() ?: 'png';
            $newName   = mt_rand(1,99999)."-".$fileName;
            $source_url = $file->getPathName();            
            $destinationPath = 'uploads/saloon_gallery/';
            if($file->move($destinationPath, $newName))
            {
                $newImage = new SaloonGallery();
                $newImage->saloon_id = $object->id;
                $newImage->image = $newName;
                $newImage->created_by = \Auth::user()->id;
                $newImage->updated_by = \Auth::user()->id;
                $newImage->created_at = date("Y-m-d H:i:s");
                $newImage->updated_at = date("Y-m-d H:i:s");
                $newImage->save();
            }
        }
        if($request->file("gallery_image_2"))
        {
            $file = $request->file("gallery_image_2");
            $fileName  = $file->getClientOriginalName();
            $extension = $file->getClientOriginalExtension() ?: 'png';
            $newName   = mt_rand(1,99999)."-".$fileName;
            $source_url = $file->getPathName();            
            $destinationPath = 'uploads/saloon_gallery/';
            if($file->move($destinationPath, $newName))
            {
                $newImage = new SaloonGallery();
                $newImage->saloon_id = $object->id;
                $newImage->image = $newName;
                $newImage->created_by = \Auth::user()->id;
                $newImage->updated_by = \Auth::user()->id;
                $newImage->created_at = date("Y-m-d H:i:s");
                $newImage->updated_at = date("Y-m-d H:i:s");
                $newImage->save();
            }
        }
        if($request->file("gallery_image_3"))
        {
            $file = $request->file("gallery_image_3");
            $fileName  = $file->getClientOriginalName();
            $extension = $file->getClientOriginalExtension() ?: 'png';
            $newName   = mt_rand(1,99999)."-".$fileName;
            $source_url = $file->getPathName();            
            $destinationPath = 'uploads/saloon_gallery/';
            if($file->move($destinationPath, $newName))
            {
                $newImage = new SaloonGallery();
                $newImage->saloon_id = $object->id;
                $newImage->image = $newName;
                $newImage->created_by = \Auth::user()->id;
                $newImage->updated_by = \Auth::user()->id;
                $newImage->created_at = date("Y-m-d H:i:s");
                $newImage->updated_at = date("Y-m-d H:i:s");
                $newImage->save();
            }
        }

        // $saloon_id = $object->id;
        // if($request->input("services_ids")){
        //     $services_ids = $request->input("services_ids");
        //     $services = $request->input("services");
        //     foreach($services as $service){
                
        //         $object = new SaloonServices();
        //         $object->saloon_id = $saloon_id;
        //         $object->service_id = $service['service_id'];
        //         $object->service_name = $service['service_name'];
        //         $object->service_description = $service['service_description'];
        //         $object->duration = $service['duration'];
        //         $object->price = $service['price'];
        //         $object->created_by = \Auth::user()->id;
        //         $object->save();
        //     }
        // }

        return redirect('/admin/salons')->with("success","Record added successfully");
    }

    public function edit($id){
        $viewData['pageTitle'] = 'Edit Salon';
        $record = Saloons::find($id);
        $viewData['record'] = $record;
        $viewData['services'] = Services::where("status","1")->get();
        $viewData['countries'] = Countries::get();
        $viewData['states'] = States::where('country_id',$record->country_id)->get();
        $viewData['cities'] = Cities::where('state_id',$record->state_id)->get();
        $viewData['gallery'] = SaloonGallery::where('saloon_id', $id)->get();
        $ss = $record->Services;
        $saloon_services = array();
        foreach($ss as $serv){
            $saloon_services[$serv->service_id] = $serv->toArray();
        }

        $viewData['saloon_services'] = $saloon_services;
        return view('saloons.edit',$viewData);
    }

    public function update($id,Request $request){
        // dd($request->all());
    	$user = Saloons::find($id);
        $validator = Validator::make($request->all(), [
            'saloon_name' => 'required',
            'contact_person' => 'required',
            'email' => 'nullable|email|unique:saloons,email,'.$user->id,
            'mobile' => 'required',
            // 'street_address' => 'required',
            // 'country_id' => 'required',
            // 'state_id' => 'required',
            // 'city_id' => 'required',
            // 'open_time' => 'required',
            // 'close_time' => 'required',
            // 'bank_name' => 'required',
            // 'account_number' => 'required',
            // 'ifsc_code' => 'required',
            // 'upi_id' => 'required',
            // 'razorpay_account_id'=>['required', new RazorpayLinkAccount]
        ]);
        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $open_time = $request->input("open_time");
        $close_time = $request->input("close_time");
        if(strtotime($close_time) < strtotime($open_time)){
            return redirect()->back()->withInput()->with("time_error","Close time should be greater then open time");   
        }
        $object = Saloons::find($id);
        $object->saloon_name = $request->input("saloon_name");
        $object->contact_person = $request->input("contact_person");
        $object->email = $request->input("email");
        $object->mobile = $request->input("mobile");
        $object->street_address = $request->input("street_address");
        $object->country_id = $request->input("country_id");
        $object->state_id = $request->input("state_id");
        $object->city_id = $request->input("city_id");
        $object->open_time = $request->input("open_time");
        $object->close_time = $request->input("close_time");
        $object->bank_name = $request->input("bank_name");
        $object->account_number = $request->input("account_number");
        $object->ifsc_code = $request->input("ifsc_code");
        $object->upi_id = $request->input("upi_id");
         $object->razorpay_account_id = $request->input("razorpay_account_id");
        $object->password = bcrypt($request->input("password"));
        if($request->input("latitude")){
            $object->latitude = $request->input("latitude");
        }
        if($request->input("logitude")){
            $object->logitude = $request->input("logitude");
        }
        if($request->input("instagram")){
            $object->instagram = $request->input("instagram");
        }
        if($request->input("facebook")){
            $object->facebook = $request->input("facebook");
        }
        if($request->input("twitter")){
            $object->twitter = $request->input("twitter");
        }
        if($request->input("status")){
            $object->status = 1;    
        }else{
            $object->status = 0;    
        }
        if($request->input("address_line_2")){
            $object->address_line_2 = $request->input("address_line_2");    
        }else{
            $object->address_line_2 = "";
        }
        if($request->input("zipcode")){
            $object->zipcode = $request->input("zipcode");    
        }else{
            $object->zipcode = "";
        }
        if($request->input("youtube_url")){
            $object->youtube_url = $request->input("youtube_url");    
        }else{
            $object->youtube_url = "";
        }

        if($request->file("owner_image"))
        {
            $file = $request->file("owner_image");
            $fileName  = $file->getClientOriginalName();
            $extension = $file->getClientOriginalExtension() ?: 'png';
            $newName   = mt_rand(1,99999)."-".$fileName;
            $source_url = $file->getPathName();            
            $destinationPath = 'uploads/profile_images/';
            if($user->owner_image != '' && file_exists($destinationPath.$user->owner_image)){
                unlink($destinationPath.$user->owner_image);
            }
            if($file->move($destinationPath, $newName)){
               $object->owner_image = $newName;
            }
        }
        if($request->file("gallery_image_1"))
        {
            $file = $request->file("gallery_image_1");
            $fileName  = $file->getClientOriginalName();
            $extension = $file->getClientOriginalExtension() ?: 'png';
            $newName   = mt_rand(1,99999)."-".$fileName;
            $source_url = $file->getPathName();            
            $destinationPath = 'uploads/saloon_gallery/';
            if($file->move($destinationPath, $newName))
            {
                if(isset($request->gallery_image_1_id) && $request->gallery_image_1_id > 0)
                {
                    $queryGalleryImage1 = SaloonGallery::where("saloon_id", $id)
                    ->where("id", $request->gallery_image_1_id)
                    ->get();
                    if($queryGalleryImage1[0]->image != '' && file_exists($destinationPath.$queryGalleryImage1[0]->image))
                    {
                        unlink($destinationPath.$queryGalleryImage1[0]->image);
                    }
                    $arr_update = array(
                        "image" => $newName,
                        "updated_by" => \Auth::user()->id,
                        "updated_at" => date("Y-m-d H:i:s")
                    );
                    SaloonGallery::where("id", $request->gallery_image_1_id)
                    ->update($arr_update);
                }
                else
                {
                    $newImage = new SaloonGallery();
                    $newImage->saloon_id = $id;
                    $newImage->image = $newName;
                    $newImage->created_by = \Auth::user()->id;
                    $newImage->updated_by = \Auth::user()->id;
                    $newImage->created_at = date("Y-m-d H:i:s");
                    $newImage->updated_at = date("Y-m-d H:i:s");
                    $newImage->save();
                }
            }
        }
        if($request->file("gallery_image_2"))
        {
            $file = $request->file("gallery_image_2");
            $fileName  = $file->getClientOriginalName();
            $extension = $file->getClientOriginalExtension() ?: 'png';
            $newName   = mt_rand(1,99999)."-".$fileName;
            $source_url = $file->getPathName();            
            $destinationPath = 'uploads/saloon_gallery/';
            if($file->move($destinationPath, $newName))
            {
                if(isset($request->gallery_image_2_id) && $request->gallery_image_2_id > 0)
                {
                    $queryGalleryImage1 = SaloonGallery::where("saloon_id", $id)
                    ->where("id", $request->gallery_image_2_id)
                    ->get();
                    if($queryGalleryImage1[0]->image != '' && file_exists($destinationPath.$queryGalleryImage1[0]->image))
                    {
                        unlink($destinationPath.$queryGalleryImage1[0]->image);
                    }
                    $arr_update = array(
                        "image" => $newName,
                        "updated_by" => \Auth::user()->id,
                        "updated_at" => date("Y-m-d H:i:s")
                    );
                    SaloonGallery::where("id", $request->gallery_image_2_id)
                    ->update($arr_update);
                }
                else
                {
                    $newImage = new SaloonGallery();
                    $newImage->saloon_id = $id;
                    $newImage->image = $newName;
                    $newImage->created_by = \Auth::user()->id;
                    $newImage->updated_by = \Auth::user()->id;
                    $newImage->created_at = date("Y-m-d H:i:s");
                    $newImage->updated_at = date("Y-m-d H:i:s");
                    $newImage->save();
                }
            }
        }
        if($request->file("gallery_image_3"))
        {
            $file = $request->file("gallery_image_3");
            $fileName  = $file->getClientOriginalName();
            $extension = $file->getClientOriginalExtension() ?: 'png';
            $newName   = mt_rand(1,99999)."-".$fileName;
            $source_url = $file->getPathName();            
            $destinationPath = 'uploads/saloon_gallery/';
            if($file->move($destinationPath, $newName))
            {
                if(isset($request->gallery_image_3_id) && $request->gallery_image_3_id > 0)
                {
                    $queryGalleryImage1 = SaloonGallery::where("saloon_id", $id)
                    ->where("id", $request->gallery_image_3_id)
                    ->get();
                    if($queryGalleryImage1[0]->image != '' && file_exists($destinationPath.$queryGalleryImage1[0]->image))
                    {
                        unlink($destinationPath.$queryGalleryImage1[0]->image);
                    }
                    $arr_update = array(
                        "image" => $newName,
                        "updated_by" => \Auth::user()->id,
                        "updated_at" => date("Y-m-d H:i:s")
                    );
                    SaloonGallery::where("id", $request->gallery_image_3_id)
                    ->update($arr_update);
                }
                else
                {
                    $newImage = new SaloonGallery();
                    $newImage->saloon_id = $id;
                    $newImage->image = $newName;
                    $newImage->created_by = \Auth::user()->id;
                    $newImage->updated_by = \Auth::user()->id;
                    $newImage->created_at = date("Y-m-d H:i:s");
                    $newImage->updated_at = date("Y-m-d H:i:s");
                    $newImage->save();
                }
            }
        }
        $object->updated_by = \Auth::user()->id;
        $object->save();

        // $saloon_id = $id;
        // if($request->input("services_ids")){
        //     $services_ids = $request->input("services_ids");
        //     $services = $request->input("services");
        //     SaloonServices::where("saloon_id",$saloon_id)
        //                   ->whereNotIn("service_id",$services_ids)
        //                   ->update(['deleted_by'=>\Auth::user()->id]);

        //     SaloonServices::where("saloon_id",$saloon_id)
        //                   ->whereNotIn("service_id",$services_ids)
        //                   ->delete();
        //     foreach($services as $service){
        //         $checkSevice = SaloonServices::where("saloon_id",$saloon_id)
        //                     ->where("service_id",$service['service_id'])
        //                     ->first();
        //         if(empty($checkSevice)){
        //             $object = new SaloonServices();
        //             $object->created_by = \Auth::user()->id;
        //         }else{
        //             $object = SaloonServices::find($checkSevice->id);
        //             $object->updated_by = \Auth::user()->id;
        //         }
        //         $object->saloon_id = $saloon_id;
        //         $object->service_id = $service['service_id'];
        //         $object->service_name = $service['service_name'];
        //         $object->service_description = $service['service_description'];
        //         $object->duration = $service['duration'];
        //         $object->price = $service['price'];
        //         $object->updated_by = \Auth::user()->id;
        //         $object->save();
        //     }
        // }

        return redirect('/admin/salons')->with("success","Record updated successfully");
    }

    public function deleteRecord($id){
        Saloons::where("id",$id)->update(['deleted_by'=>\Auth::user()->id]);
        SaloonServices::where("saloon_id",$id)->update(['deleted_by'=>\Auth::user()->id]);

        SaloonServices::where("saloon_id",$id)->delete();
        Saloons::where("id",$id)->delete();
    	Barbers::where("saloon_id",$id)->delete();
    	return redirect('/admin/salons')->with("success","Record deleted successfully");
    }

    public function servicesList(Request $request){
        $saloon_id = $request->input("saloon_id");
        $viewData['services'] = SaloonServices::with('service')->where("saloon_id",$saloon_id)->get();

        $view = View::make('saloons.services',$viewData);
        $contents = $view->render();
        $response['status'] = true;
        $response['contents'] = $contents;
        return response()->json($response);
    }

    public function addService($saloon_id){
        $viewData['services'] = Services::where("status","1")->get();
        $viewData['saloon_id'] = $saloon_id;
        $viewData['pageTitle'] = "Add Service";
        $view = View::make('saloons.add-service',$viewData);
        $contents = $view->render();
        $response['status'] = true;
        $response['contents'] = $contents;
        return response()->json($response);
    }
    

    public function saveService($saloon_id,Request $request){
        $validator = Validator::make($request->all(), [
            'service_id' => 'required',
            'service_name' => 'required',
            'service_description' => 'required',
            'duration' => 'required',
            'price' => 'required',
        ]);

        if ($validator->fails()) {
            $response['status'] =false;
            $error = $validator->errors()->toArray();
            $errMsg = '';
            foreach($error as $key => $err){
                $errMsg .= $err[0];
            }
            $response['message'] = $errMsg;
            return response()->json($response);
        }   
        
        $object = new SaloonServices();
        $object->service_id = $request->input("service_id");
        $object->saloon_id = $saloon_id;
        $object->service_name = $request->input("service_name");
        $object->service_description = $request->input("service_description");
        $object->duration = $request->input("duration");
        $object->price = $request->input("price");
        $object->created_by = \Auth::user()->id;
        $object->save();

        $response['status'] = true;
        $response['message'] = 'Service added successfully';
        return response()->json($response);
    }

    public function editService($id){
        $viewData['services'] = Services::where("status","1")->get();
        $record = SaloonServices::where("id",$id)->first();
        $viewData['record'] = $record;
        $viewData['pageTitle'] = "Edit Service";
        $view = View::make('saloons.edit-service',$viewData);
        $contents = $view->render();
        $response['status'] = true;
        $response['contents'] = $contents;
        return response()->json($response);
    }
    

    public function updateService($id,Request $request){
        $validator = Validator::make($request->all(), [
            'service_id' => 'required',
            'service_name' => 'required',
            'service_description' => 'required',
            'duration' => 'required',
            'price' => 'required',
        ]);

        if ($validator->fails()) {
            $response['status'] =false;
            $error = $validator->errors()->toArray();
            $errMsg = '';
            foreach($error as $key => $err){
                $errMsg .= $err[0];
            }
            $response['message'] = $errMsg;
            return response()->json($response);
        }   
        
        $object = SaloonServices::find($id);
        $object->service_id = $request->input("service_id");
        $object->service_name = $request->input("service_name");
        $object->service_description = $request->input("service_description");
        $object->duration = $request->input("duration");
        $object->price = $request->input("price");
        $object->created_by = \Auth::user()->id;
        $object->save();

        $response['status'] = true;
        $response['message'] = 'Service updated successfully';
        return response()->json($response);
    }

    public function deleteService($id){
        SaloonServices::where("id",$id)->update(['deleted_by'=>\Auth::user()->id]);

        SaloonServices::where("id",$id)->delete();
        return redirect()->back()->with("success","Record deleted successfully");
    }

    public function view($id){
        $viewData['pageTitle'] = 'Salon Detail';
        $record = Saloons::find($id);
        $viewData['record'] = $record;
        $viewData['services'] = Services::where("status","1")->get();
        $saloon_id = $id;
        $viewData['services'] = SaloonServices::with('service')->where("saloon_id",$saloon_id)->get();
        return view('saloons.view',$viewData);
    }

    public function deleteAllRecord(Request $request)
    {
        // dd($request->all());
        /*Saloons::whereIn("id",$request->id)->delete();
        SaloonServices::whereIn("saloon_id",$request->id)->delete();
        Barbers::whereIn("saloon_id",$request->id)->delete();
        SaloonGallery::whereIn("saloon_id",$request->id)->delete();
        SaloonFavourites::whereIn("saloon_id",$request->id)->delete();*/
        $arr_update = array(
            "is_deleted" => 1,
            "deleted_by" => \Auth::user()->id,
            "deleted_at" => date("Y-m-d H:i:s")
        );
        SaloonServices::whereIn("saloon_id",$request->id)->update($arr_update);
        SaloonGallery::whereIn("saloon_id",$request->id)->update($arr_update);
        // SaloonFavourites::whereIn("saloon_id",$request->id)->delete();
        Barbers::whereIn("saloon_id",$request->id)->update($arr_update);
        Saloons::whereIn("id",$request->id)->update($arr_update);
        echo 1;
        exit;
    }

    public function downloadimage($file="")
    {
        $file_name1=$file;
        header("Content-type: application/octet-stream");
        header("Content-Disposition: attachment; filename=\"$file_name1\"");
        $filename = 'uploads/saloon_gallery/' . $file_name1;
        $handle = fopen($filename, "r");
        $data = fread($handle, filesize($filename));
        fclose($handle);
        echo $data;
        // $common = new commonfunction();
        // $common->unlinkfiles($filename);
        //$pathdelete = $_SERVER['DOCUMENT_ROOT'].$filename;
        if(file_exists($filename))
        {
            // @unlink($filename);
        }
    }
    public function downloadownerimage($file="")
    {
        $file_name1=$file;
        header("Content-type: application/octet-stream");
        header("Content-Disposition: attachment; filename=\"$file_name1\"");
        $filename = 'uploads/profile_images/' . $file_name1;
        $handle = fopen($filename, "r");
        $data = fread($handle, filesize($filename));
        fclose($handle);
        echo $data;
        // $common = new commonfunction();
        // $common->unlinkfiles($filename);
        //$pathdelete = $_SERVER['DOCUMENT_ROOT'].$filename;
        if(file_exists($filename))
        {
            // @unlink($filename);
        }
    }
}
