<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Validator;
use App\User;
class UsersController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }
    public function list(){
    	$viewData['pageTitle'] = 'User';
        $viewData['records'] = User::orderBy('id','desc')->paginate();
        return view('users.list',$viewData);
    }
    
    public function addNew(){
        $viewData['pageTitle'] = 'Add User';
        $viewData['timestamp'] = time();
        return view('users.add',$viewData);
    }

    public function save(Request $request){
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'email' => 'required|email|unique:users',
            'phone_no' => 'required',
            'password' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        
        $object = new User();
        $object->name = $request->input("name");
        $object->email = $request->input("email");
        $object->phone_no = $request->input("phone_no");
        $object->password = bcrypt($request->input("password"));
        if($request->input("status")){
        	$object->status = 1;	
        }else{
        	$object->status = 0;	
        }
        $object->created_by = \Auth::user()->id;
        $object->save();


        return redirect('/admin/users')->with("success","Record added successfully");
    }

    public function edit($id){
        $viewData['pageTitle'] = 'Edit User';
        $viewData['record'] = User::find($id);
        return view('users.edit',$viewData);
    }

    public function update($id,Request $request){
    	$user = User::find($id);
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'email' => 'required|email|unique:users,email,'.$user->id,
            'phone_no' => 'required',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $object = User::find($id);
        $object->name = $request->input("name");
        $object->email = $request->input("email");
        $object->phone_no = $request->input("phone_no");
        if($request->input("password")){
        	$object->password = bcrypt($request->input("password"));
    	}
        if($request->input("status")){
        	$object->status = 1;	
        }else{
        	$object->status = 0;	
        }
        $object->updated_by = \Auth::user()->id;
        $object->save();

        return redirect('/admin/users')->with("success","Record updated successfully");
    }

    public function deleteRecord($id){
        User::where("id",$id)->update(['deleted_by'=>\Auth::user()->id]);
    	User::where("id",$id)->delete();
    	return redirect('/admin/users')->with("success","Record deleted successfully");
    }
}
