<?php
namespace App\Http\Controllers\Webservices;
ini_set('max_execution_time', 600); 

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Validator;
use Illuminate\Support\Facades\Hash;

use App\Saloons;
use App\SaloonServices;
use App\SaloonGallery;
use App\Services;
use App\Cities;
use App\Barbers;
use App\BarbersServices;
use App\Bookings;
use App\BookingItems;
use App\BarberSchedule;
use App\BarberBreak;
use App\Notification;
use App\Settings;
use App\Ratings;
use Carbon\Carbon;

class BarbersController extends Controller
{
    public function __construct()
    {
        header('Access-Control-Allow-Origin: *');
        header('Access-Control-Allow-Methods: GET, PUT, POST, DELETE, OPTIONS');
        header("Content-Type: application/json");
    }

    public function loginAsBarber(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'mobile' => 'required'
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $response['login'] = false;
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $mobile = $request->input("mobile");
            $user = Barbers::select('id','saloon_id','name','email','mobile','profile_image','exp_month','exp_year', 'login_pin','created_at','manage_barber')->whereHas("Saloon")->where("mobile",$mobile)->first();

            if(empty($user)){
                $response['status'] = 'error';
                $response['login'] = false;
                $response['message'] = 'Invalid mobile no';
                return response()->json($response);
            }else{
                // Update devicetype and devicetoken
                $barber_update = Barbers::find($user->id);
                if(!empty($request->input("devicetoken")))
                {
                    $barber_update->devicetype = $request->input("devicetype");
                    $barber_update->devicetoken = $request->input("devicetoken");
                }
                
                $barber_update->updated_at = date("Y-m-d H:i:s");
                $barber_update->save();
                //
                if(empty($user->login_pin))
                {
                    $user->is_loginpin = "N";
                }
                else
                {
                    $user->is_loginpin = "Y";
                }
                if($user->profile_image !=''){
                    $user->profile_image = url('/uploads/profile_images/'.$user->profile_image);
                }else{
                    $user->profile_image = '';
                }
                $toDate = Carbon::parse(date('Y-m-d',strtotime($user->created_at)));
                $fromDate = Carbon::parse(date('Y-m-d'));
        
                $months = $toDate->diffInMonths($fromDate);

                $totalExpMonth = $months+(int)$user->exp_month;

                $rem_year = $user->exp_year;
                $rem_month = $totalExpMonth;

                if($totalExpMonth >= 12)
                {
                    $rryear = (int)($totalExpMonth/12);
                    $rem_month = $totalExpMonth-($rryear*12);
                    $rem_year = $rem_year+$rryear;
                }

                $user->exp_year = $rem_year;
                $user->exp_month = $rem_month;

                $saloon = Saloons::where("id",$user->saloon_id)->first();
                $salon_id = $saloon->id;
                unset($user->saloon_id);
                $saloon = $saloon->toArray();
                $temp = array();
                
                unset($saloon['last_login']);
                unset($saloon['api_token']);
                unset($saloon['created_by']);
                unset($saloon['updated_by']);
                unset($saloon['deleted_by']);
                unset($saloon['created_at']);
                unset($saloon['updated_at']);
                unset($saloon['deleted_at']);
                unset($saloon['country_id']);
                unset($saloon['city_id']);
                unset($saloon['state_id']);
                unset($saloon['password']);
                $temp = $saloon;
                if(!empty($saloon['owner_image'])){
                    $temp['owner_image'] = url('/uploads/profile_images/'.$saloon['owner_image']);                
                }else{
                    $temp['owner_image'] = '';
                }
                $temp['salon_name'] = $saloon['saloon_name'];
                unset($temp['saloon_name']);
                unset($temp['id']);
                $temp['salon_id'] = $saloon['id'];
                $temp['open_time'] = ($saloon['open_time'] != NULL)?date("H:i",strtotime($saloon['open_time'])):'';
                $temp['close_time'] = ($saloon['close_time'] != NULL)?date("H:i",strtotime($saloon['close_time'])):'';
                $temp['salon_type'] = ($saloon['saloon_type'] != NULL)?$saloon['saloon_type']:'';
                $temp['contact_no'] =  ($saloon['mobile'] != NULL)?$saloon['mobile']:'';
                $street_address = '';
                if($saloon['street_address'] != ''){
                    $street_address = $saloon['street_address'];
                }                
                $temp['street_address'] =  $street_address;
                if(!empty($saloon['owner_image'])){
                    $temp['owner_image'] = url('/uploads/profile_images/'.$saloon['owner_image']);                
                }else{
                    $temp['owner_image'] = '';
                }
                
                if($saloon['instagram'] != ''){
                    $temp['instagram'] = $saloon['instagram'];
                }else{
                    $temp['instagram'] = '';
                }
                if($saloon['facebook'] != ''){
                    $temp['facebook'] = $saloon['facebook'];
                }else{
                    $temp['facebook'] = '';
                }
                if($saloon['twitter'] != ''){
                    $temp['twitter'] = $saloon['twitter'];
                }else{
                    $temp['twitter'] = '';
                }
                if($saloon['latitude'] != ''){
                    $temp['latitude'] = $saloon['latitude'];
                }else{
                    $temp['latitude'] = '';
                }
                if($saloon['logitude'] != ''){
                    $temp['logitude'] = $saloon['logitude'];
                }else{
                    $temp['logitude'] = '';
                }
                $saloon_detail = $temp;
                $saloon_gallery = SaloonGallery::where("saloon_id",$salon_id)->get();
                $images = array();
                foreach($saloon_gallery as $gallery){
                    $images[] = url('/uploads/saloon_gallery/'.$gallery->image);
                }
                $response['status'] = 'success';
                $response['login'] = true;
                $response['message'] = 'Login success';
                $response['user'] = $user;
                $response['salon_gallery'] = $images;
                $response['salon_detail'] = $saloon_detail;
            }
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
    public function editProfile(Request $request){
        try{
            $object = Barbers::find($request->input("barber_id"));
            $object->name = $request->input('name');
            $object->email = $request->input('email');
            $object->mobile = $request->input('mobile');
            $object->exp_year = $request->input('exp_year');
            $object->exp_month = $request->input('exp_month');
            if($request->input('barber_profile')){
                if($object->profile_image != '' && file_exists('uploads/profile_images/'.$object->profile_image)){
                    unlink('uploads/profile_images/'.$object->profile_image);                    
                } 
                $image_64 = base64_decode($request->input('barber_profile'));
                $f = finfo_open();
                $mime_type = finfo_buffer($f, $image_64, FILEINFO_MIME_TYPE);  
                $extensions = explode("/",$mime_type);
                $ext = end($extensions);
               
                $ci_fileName= time().'-'.rand(00000,99999).'.'.$ext;
                file_put_contents('uploads/profile_images/'.$ci_fileName,$image_64);    
                $object->profile_image = $ci_fileName;
            }
            $object->save();
            //
            $barber = Barbers::where('id', $request->input("barber_id"))
            ->with("Saloon")
            ->get();
            // echo "<pre>";
            // print_r($barber);
            // echo "</pre>";
            // exit;
            $temp = array();
            if(!(empty($barber)) && count($barber) > 0)
            {
                // echo "<pre>";
                // print_r($barber[0]->Saloon->saloon_name);
                // echo "</pre>";
                // exit;
                $temp["id"] = $barber[0]->id;
                $temp["saloon_id"] = $barber[0]->saloon_id;
                $temp["name"] = $barber[0]->name;
                $temp["email"] = $barber[0]->email;
                $temp["mobile"] = $barber[0]->mobile;
                $temp["profile_image"] = "";
                if(file_exists('uploads/profile_images/'.$barber[0]->profile_image))
                {
                    $temp["profile_image"] = url('/uploads/profile_images/'.$barber[0]->profile_image);
                }
                $temp["exp_year"] = $barber[0]->exp_year;
                $temp["exp_month"] = $barber[0]->exp_month;
                $temp["status"] = $barber[0]->status;
                $temp["saloon_name"] = $barber[0]->Saloon->saloon_name;
            }
            $response['status'] = 'success';
            $response['message'] = 'Profile edited successfully';
            $response['user'] = $temp;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
    public function bookingList(Request $request){
        try{
            $barber_id = $request->input("barber_id");
            $filter_date = $request->input("filter_date");
            // $bookings = Bookings::where("barber_id",$barber_id)
            //                     ->where("status","!=",'cancelled')  
            //                     ->where("book_date","=",date("Y-m-d", strtotime($filter_date)))  
            //                     ->whereHas("Saloon")
            //                     ->whereHas("Barber")
            //                     ->whereHas("Customer")
            //                     ->orderBy("book_date","desc")
            //                     ->get();
            $bookings = Bookings::where("barber_id",$barber_id)
            // ->where("status","!=",'cancelled')  
            // ->where("status","!=",'emergency cancellation')
            ->where("payment_status","=",'C')
            ->where(function($query) use ($filter_date){
                if(!(empty($filter_date)))
                {
                    $query->where("book_date","=",date("Y-m-d", strtotime($filter_date)));
                }
            })
            ->with("BookingItems")
            ->with("Saloon")
            ->with("Barber")
            ->with("Customer")
            ->orderBy("book_date","desc")
            ->orderBy("from_time","asc")
            ->get();
            // echo "<pre>";
            // print_r($bookings);
            // echo "</pre>";     
            // exit;                           
            $bookingList = array();
            foreach($bookings as $booking)
            {
                $temp = array();
                $temp['id'] = $booking->id;
                $temp['book_date'] = dateFormat($booking->book_date,"d-m-Y");
                $temp['customer_profile_image'] = "";
                $temp['customer_name'] = $booking->customer_name;
                if(!empty($booking->Customer))
                {
                    if(!(empty($booking->Customer->profileimage)))
                    {
                        $temp['customer_profile_image'] = $booking->Customer->profileimage;
                    }
                    $temp['customer_name'] = $booking->Customer->name;
                }
                
                $temp['customer_id'] = $booking->customer_id;
                
                
                $temp['salon_name'] = $booking->Saloon->saloon_name;
                $temp['salon_id'] = $booking->saloon_id;
                $temp['barber_name'] = $booking->Barber->name;
                $temp['barber_id'] = $booking->barber_id;
                $temp['book_number'] = $booking->book_number;
                $temp['from_time'] = $booking->from_time;
                $temp['to_time'] = $booking->to_time;
                $temp['total_price'] = $booking->total;
                $temp['transaction_id'] = $booking->transaction_id;
                $temp['billing_name'] = $booking->billing_name;
                $temp['billing_mobile'] = $booking->billing_mobile;
                $temp['billing_email'] = $booking->billing_email;
                $temp['booked_by'] = $booking->booked_by;
                $temp['profile_image'] = url('/uploads/profile_images/'.$booking->Barber->profile_image);
                $temp['cancel_user_type'] = $booking->cancel_user_type == ""?"":$booking->cancel_user_type;
                $temp['cancel_user_id'] = $booking->cancel_user_id == ""?"":(string)$booking->cancel_user_id;
                $date = $booking->book_date." ".$booking->to_time;
                $current_date = date("Y-m-d H:i:s");
                /*if($date > $current_date){
                    $temp['status'] = 'Upcoming';
                }else{
                    $temp['status'] = 'Completed';
                }*/
                if($booking->status == "active")
                {
                    $temp['status'] = 'Active';
                }
                if($date >= $current_date && ($booking->status != "cancelled" && $booking->status != "emergency cancellation") && $booking->payment_status == "P")
                {
                    $temp['status'] = 'Payment Pending';
                }
                if($date < $current_date && ($booking->status != "cancelled" && $booking->status != "emergency cancellation") && $booking->payment_status == "P")
                {
                    $temp['status'] = 'Expired';
                }
                if($date > $current_date)
                {
                    $temp['status'] = 'Upcoming';
                }
                if($date < $current_date && ($booking->status != "cancelled" && $booking->status != "emergency cancellation") && $booking->payment_status == "C")
                {
                    $temp['status'] = 'Completed';
                }
                if($booking->status == "cancelled")
                {
                    $temp['status'] = 'Cancelled';
                }
                if($booking->status == 'emergency cancellation')
                {
                    $temp['status'] = 'Emergency Cancel';
                }
                if($booking->status == "requested refund")
                {
                    $temp['status'] = 'Requested Refund';
                    $refund_request_date = date("d-m-Y H:i:s", strtotime($booking->refund_request_date));
                    $temp['refund_request_date'] = $refund_request_date;
                }

                $services = array();
                $total  = 0;
                $services_array = array();
                foreach($booking->BookingItems as $i => $item){
                    $services[] = $item->SaloonService->service_name;
                    if($item->price > 0){                    
                        $total = $total + $item->price;
                    }
                    $services_array[$i]['service_name'] = $item->SaloonService->service_name;
                    $services_array[$i]['service_price'] = $item->price;
                    $services_array[$i]['service_id'] = $item->SaloonService->id;
                    $services_array[$i]['main_service_id'] = $item->service_id;
                }
                
                $temp['service_name'] = implode(",",$services);
                $temp['service_price'] = number_format($total,2);

                $temp['services'] = $services_array;

                $temp['action_type'] = "";
                if(!empty($booking->action_type))
                {
                    $temp['action_type'] = $booking->action_type;
                }
                //
                $is_rated = "N";
                $rating = "";
                $rating = Ratings::where("booking_id", $booking->id)->first();
                if(!empty($rating))
                {
                    $is_rated = "Y";
                    $rating = (string)$rating->rating;
                }
                $temp['is_rated'] = $is_rated;
                $temp['rating'] = $rating ==""?"":$rating;

                // $booking_services = BookingItems::with('Service')->where("booking_id",$booking->id)->get();
                // $services = array();
                // foreach($booking_services as $serv){
                //     $temp['service_name'] = (!empty($serv->Service))?$serv->Service->name:"";
                //     $temp['service_price'] = $serv->price;
                //     $services[] = $serv;
                // }
                // $temp['services'] = $services;

                $bookingList[] = $temp;
            }
            $date = date("Y-m-d", strtotime($filter_date));
            $today_earning = Bookings::where("barber_id",$barber_id)
            ->whereDate("book_date",$date)
            ->where("status","!=",'cancelled')  
            ->where("status","!=",'emergency cancellation')
            ->where("payment_status","=",'C')
            ->whereRaw("(action_type != 'R' OR action_type IS NULL)")
            ->whereHas("Barber")
            ->orderBy("book_date","desc")
            ->sum("total");

            $barberRes = Barbers::where('id',$barber_id)->first();

            $response['status'] = 'success';
            $response['booking_list'] = $bookingList;
            $response['today_earning'] = $today_earning;
            $response['show_earning'] = $barberRes->show_earning;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    /*public function bookingList(Request $request){
        try{
            $barber_id = $request->input("barber_id");
            $filter_date = $request->input("filter_date");
            $bookings = \DB::table("bookings")->select("bookings.*","customers.name as customer_name","saloons.saloon_name", "barbers.name as barber_name", "barbers.profile_image");
            $bookings->join("barbers","bookings.barber_id","=","barbers.id");
            $bookings->join("saloons","bookings.saloon_id","=","saloons.id");
            $bookings->join("customers","bookings.customer_id","=","customers.id");
            $bookings->where("bookings.barber_id", $barber_id);
            $bookings->where("book_date","=",date("Y-m-d", strtotime($filter_date)));
            $bookings->orderBy("bookings.book_date","desc");
            $bookings = $bookings->get();
            // echo "<pre>";
            // print_r($booking);
            // echo "</pre>";
            // exit;
            //
            $bookingList = array();
            foreach($bookings as $booking){
                $temp = array();
                $temp['id'] = $booking->id;
                $temp['book_date'] = dateFormat($booking->book_date,"d-m-Y");
                $temp['customer_name'] = $booking->customer_name;
                $temp['customer_id'] = $booking->customer_id;
                $temp['salon_name'] = $booking->saloon_name;
                $temp['salon_id'] = $booking->saloon_id;
                $temp['barber_name'] = $booking->barber_name;
                $temp['barber_id'] = $booking->barber_id;
                $temp['book_number'] = $booking->book_number;
                $temp['from_time'] = $booking->from_time;
                $temp['to_time'] = $booking->to_time;
                $temp['total_price'] = $booking->total;
                $temp['transaction_id'] = $booking->transaction_id;
                $temp['billing_name'] = $booking->billing_name;
                $temp['billing_mobile'] = $booking->billing_mobile;
                $temp['billing_email'] = $booking->billing_email;
                $temp['profile_image'] = asset('public/uploads/profile_images/'.$booking->profile_image);
                $date = $booking->book_date." ".$booking->to_time;
                $current_date = date("Y-m-d H:i:s");
                if($date > $current_date){
                    $temp['status'] = 'Upcoming';
                }else{
                    $temp['status'] = 'Completed';
                }

                $services = array();
                $total  = 0;
                $services_array = array();
                $bookingItems = \DB::table("booking_items")->select("booking_items.*","saloon_services.service_name","saloon_services.price");
                $bookingItems->join("saloon_services","saloon_services.id","=","booking_items.main_service_id");
                $bookingsItem = $bookingItems->get();
                //
                foreach($bookingsItem as $i => $item){
                    $services[] = $item->service_name;
                    if($item->price > 0){                    
                        $total = $total + $item->price;
                    }
                    $services_array[$i]['service_name'] = $item->service_name;
                    $services_array[$i]['service_price'] = $item->price;
                }
                
                $temp['service_name'] = implode(",",$services);
                $temp['service_price'] = number_format($total,2);

                $temp['services'] = $services_array;


                // $booking_services = BookingItems::with('Service')->where("booking_id",$booking->id)->get();
                // $services = array();
                // foreach($booking_services as $serv){
                //     $temp['service_name'] = (!empty($serv->Service))?$serv->Service->name:"";
                //     $temp['service_price'] = $serv->price;
                //     $services[] = $serv;
                // }
                // $temp['services'] = $services;

                $bookingList[] = $temp;
            }
            $response['status'] = 'success';
            $response['booking_list'] = $bookingList;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }*/
    
    public function barberIncome(Request $request){
        try{
            $barber_id = $request->input("barber_id");
            if($request->input("date")){
                $date = date("Y-m-d",strtotime($request->input("date")));    
            }else{
                $date = date("Y-m-d");
            }
            $barber = Barbers::select('id','name','mobile','profile_image','show_earning','manage_barber')->where('id',$barber_id)->first();
            if(empty($barber)){
                $response['status'] = 'error';
                $response['message'] = 'Barber not exists';
                return response()->json($response);
            }
            
            $today_earning = Bookings::where("barber_id",$barber_id)
                        ->whereDate("book_date",$date)
                        ->where("status","!=",'cancelled')  
                        ->where("status","!=",'emergency cancellation')
                        ->where("payment_status","=",'C')
                        ->whereRaw("(action_type != 'R' OR action_type IS NULL)")
                        ->whereHas("Saloon")
                        ->whereHas("Barber")
                        ->whereHas("Customer")
                        ->orderBy("book_date","desc")
                        ->sum("total");
            $week_start = date( 'Y-m-d', strtotime( 'monday this week' ) );
            $week_end = date( 'Y-m-d', strtotime( 'sunday this week' ) );

            $week_earning = Bookings::where("barber_id",$barber_id)
                        ->where("status","!=",'cancelled')  
                        ->where("status","!=",'emergency cancellation')
                        ->where("payment_status","=",'C')
                        ->whereRaw("(action_type != 'R' OR action_type IS NULL)")
                        ->whereDate("book_date",">=",$week_start)                        
                        ->whereDate("book_date","<=",$week_end)
                        ->whereHas("Saloon")
                        ->whereHas("Barber")
                        ->whereHas("Customer")
                        ->orderBy("book_date","desc")
                        ->sum("total");

            $month_start = date('Y-m-d',strtotime('first day of this month'));
            $month_end = date('Y-m-d',strtotime('last day of this month'));

            $month_earning = Bookings::where("barber_id",$barber_id)
                        ->where("status","!=",'cancelled')  
                        ->where("status","!=",'emergency cancellation')
                        ->where("payment_status","=",'C')
                        ->whereRaw("(action_type != 'R' OR action_type IS NULL)")
                        ->whereDate("book_date",">=",$month_start)
                        ->whereDate("book_date","<=",$month_end)
                        ->whereHas("Saloon")
                        ->whereHas("Barber")
                        ->whereHas("Customer")
                        ->orderBy("book_date","desc")
                        ->sum("total");

            $year_start = date('Y-m-d',strtotime('first day of January '));
            $year_end = date('Y-m-d',strtotime('last day of December'));

            $year_earning = Bookings::where("barber_id",$barber_id)
                        ->where("status","!=",'cancelled')  
                        ->where("status","!=",'emergency cancellation')
                        ->where("payment_status","=",'C')
                        ->whereRaw("(action_type != 'R' OR action_type IS NULL)")
                        ->whereDate("book_date",">=",$year_start)
                        ->whereDate("book_date","<=",$year_end)
                        ->whereHas("Saloon")
                        ->whereHas("Barber")
                        ->whereHas("Customer")
                        ->orderBy("book_date","desc")
                        ->sum("total");

            $earnings = array("today_earning"=>(string)$today_earning,"week_earning"=>$week_earning,"month_earning"=>$month_earning,"year_earning"=>$year_earning);

            
            $barber->profile_image = url('/uploads/profile_images/'.$barber->profile_image);

            $bookings = Bookings::where("barber_id",$barber_id)
                                ->where("status","!=",'cancelled')  
                                ->where("status","!=",'emergency cancellation')
                                ->where("book_date",$date)
                                ->orderBy("from_time","asc")
                                ->whereHas("Saloon")
                                ->whereHas("Barber")
                                ->whereHas("Customer")
                                ->get();
            $today_slots = array();
            foreach($bookings as $booking){
                $temp = array();
                $temp['id'] = $booking->id;
                $temp['book_date'] = dateFormat($booking->book_date,"d-m-Y");
                // $temp['customer_name'] = $booking->Customer->name;
                // $temp['customer_id'] = $booking->customer_id;
                // $temp['salon_name'] = $booking->Saloon->saloon_name;
                // $temp['salon_id'] = $booking->saloon_id;
                $temp['barber_name'] = $booking->Barber->name;
                // $temp['barber_id'] = $booking->barber_id;
                // $temp['book_number'] = $booking->book_number;
                $temp['from_time'] = $booking->from_time;
                $temp['to_time'] = $booking->to_time;
                $temp['total_price'] = $booking->total;
                // $temp['transaction_id'] = $booking->transaction_id;
                // $temp['billing_name'] = $booking->billing_name;
                // $temp['billing_mobile'] = $booking->billing_mobile;
                // $temp['billing_email'] = $booking->billing_email;

                $booking_services = BookingItems::with('Service')->where("booking_id",$booking->id)->get();
                $services = array();
                foreach($booking_services as $serv){
                    $temp2 = array();
                    $temp2['service_name'] = $serv->SaloonService->service_name;
                    $temp2['service_price'] = $serv->price;
                    $services[] = $temp2;
                }
                $temp['services'] = $services;

                $today_slots[] = $temp;
            }
            //
            // $queryBarberServices = BarbersServices::where("barber_id",$barber_id)->get();
            $queryBarberServices = BarbersServices::where("barber_id",$barber_id)->get();
            $serviceCount = (string)count($queryBarberServices);
            $isService = "N";
            if($serviceCount > 0)
            {
                $isService = "Y";
            }
            //
            $queryBarberServicesBooking = \DB::table("bookings")->select("bookings.*","booking_items.id as itemid", "booking_items.main_service_id", "barbers_services.id as barber_service_id","barbers_services.duration")->where("bookings.barber_id","=",$barber_id)
            ->join("booking_items","booking_items.booking_id", "=", "bookings.id")
            ->join("barbers_services", function($join) use($barber_id){
                $join->on("barbers_services.saloon_service_id", "=", "booking_items.main_service_id")
                ->where("barbers_services.barber_id", $barber_id);
            })
            ->where("status","!=","cancelled")
            ->where("status","!=","emergency cancellation")
            ->where("payment_status","=","C")
            ->get();
            //
            $working_hours = "";
            if(count($queryBarberServicesBooking) > 0)
            {
                $time = 0;
                foreach ($queryBarberServicesBooking as $skey => $svalue)
                {
                    // $time_str = strtotime($svalue->duration);
                    // $time += $time_str;
                    $arr_time = explode(":", $svalue->duration);
                    // echo "<pre>";
                    // print_r($arr_time);
                    // echo "</pre>";
                    $hours_to_minutes = 0;
                    $hours = (int)$arr_time[0];
                    $hours_to_minutes = $hours * 60;
                    $minutes = (int)$arr_time[1];
                    $time = $time + $minutes + $hours_to_minutes;
                    // echo "Time".$time."<br/>";
                    // echo $svalue->itemid." SErvice = ".$svalue->id." = Duration = ".$svalue->duration."<br/>";
                    // echo ((floor($minutes / 60)).":".($minutes - floor($minutes / 60) * 60))."<br/>";
                }
                // $working_hours = date("H:i",$time);
                // echo "Time =".$time;
                $working_hours = ((floor($time / 60)).":".($time - floor($time / 60) * 60));
            }
            $response['barber'] = $barber;
            $response['earnings'] = $earnings;
            $response['today_slots'] = $today_slots;
            $response['service_count'] = $serviceCount;
            $response['is_service'] = $isService;
            $response['working_hours'] = $working_hours;
            $response['status'] = 'success';
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }


    public function scheduleDelete(Request $request)
    {
        try{
            $barber_id = $request->input("barber_id");
            $id = $request->id;
            $scheduleRes = BarberSchedule::where('id',$id)->where("barber_id",$barber_id)->first();
            if(!empty($scheduleRes))
            {
                $schedules = BarberSchedule::where('id',$id)->where("barber_id",$barber_id)->delete();

                $bookings = Bookings::where("barber_id",$barber_id)
                // ->where("status","!=",'cancelled')  
                // ->where("status","!=",'emergency cancellation')
                ->where("payment_status","=",'C')
                ->where("book_date","=",date("Y-m-d", strtotime($scheduleRes->schedule_date)))
                ->with("BookingItems")
                ->with("Saloon")
                ->with("Barber")
                ->with("Customer")
                ->count();

                if($bookings > 0)
                {
                    $response['message'] = "Schedule deleted successfully. But you have already received bookings on this date. Don't forget to cancel them, if you cannot fulfill them. If you still want to accept bookings on this day, please add a new schedule";
                }
                else{
                    $response['message'] = "Schedule deleted successfully. To accept bookings on this date, add a new schedule.";
                }
                $response['status'] = 'success';
                
            }
            else{
                $response['status'] = 'error';
                $response['message'] = "Schedule not found";
            }
            
            
          //  $response['breaks'] = $breaks;

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function scheduleList(Request $request){
        try{
            $barber_id = $request->input("barber_id");
            $schedules = BarberSchedule::select('id','schedule_date','from_time','to_time')
                                        ->where("barber_id",$barber_id)
                                        ->whereHas("Barber")
                                        ->orderBy("schedule_date","desc")
                                        ->get();            
            foreach($schedules as $schedule)
            {
                /*$breaks = BarberBreak::select('id','break_date','from_time','to_time')
                ->where("barber_id",$barber_id)
                ->where("break_date",$schedule->schedule_date)
                ->orderBy("break_date","desc")
                ->first();
                $schedule->break_from_time = isset($breaks->from_time) ? $breaks->from_time : '';
                $schedule->break_to_time = isset($breaks->to_time) ? $breaks->to_time : '';
                $schedule->schedule_date = dateFormat($schedule->schedule_date,"d-m-Y");*/
                $breaks = BarberBreak::select('id','break_date','from_time','to_time')
                ->where("barber_id",$barber_id)
                ->where("break_date",$schedule->schedule_date)
                ->orderBy("break_date","desc")
                ->get();
                /*echo "<pre>";
                print_r($breaks);
                echo "</pre>";
                exit;*/
                $breaks_arr = array();
                if(count($breaks) > 0)
                {
                    foreach ($breaks as $key => $value)
                    {
                        // $schedule->break_from_time = isset($breaks->from_time) ? $breaks->from_time : '';
                        // $schedule->break_to_time = isset($breaks->to_time) ? $breaks->to_time : '';
                        // $schedule->schedule_date = dateFormat($schedule->schedule_date,"d-m-Y");
                        $breaks_arr[] = array(
                            "break_from_time" => (isset($value->from_time) ? $value->from_time : ''),
                            "break_to_time" => (isset($value->to_time) ? $value->to_time : ''),
                            "schedule_date" => dateFormat($schedule->schedule_date,"d-m-Y")
                        );
                    }
                }
                $schedule->breaks = $breaks_arr;
            }
            $response['status'] = 'success';
            $response['schedule'] = $schedules;
          //  $response['breaks'] = $breaks;

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
    /*public function addSchedule(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'barber_id' => 'required',
                'schedule_date' => 'required',
                'from_time'=>"required",
                'to_time'=>"required",
            ]);

            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }

            $start_time     =   date("H:i",strtotime($request->input("from_time")));
            $end_time       =   date("H:i",strtotime($request->input("to_time")));

            if($start_time >= $end_time){
                $response['status'] = 'error';
                $response['message'] = "Invalid time schedule!";
                return response()->json($response);
            }

           
            $object = new BarberSchedule();
            $object->barber_id = $request->input("barber_id");
            $object->schedule_date = dateFormat($request->input("schedule_date"),"Y-m-d");
            $object->from_time = $request->input("from_time");
            $object->to_time = $request->input("to_time");
            $object->save();
            
            $response['status'] = 'success';
            $response['message'] = 'Barber schedule added successfully';
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }*/

    public function addSchedule(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'barber_id' => 'required',
                'schedule_date' => 'required',
                'from_time'=>"required",
                'to_time'=>"required",
                // 'is_auto_schedule'=>"required",
            ]);

            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }

            $schedule_date = date("Y-m-d", strtotime($request->input('schedule_date')));
            $barber_schedule = BarberSchedule::where("schedule_date",$schedule_date)
            ->where('barber_id',$request->input('barber_id'))
            ->get();
            if(count($barber_schedule) > 0)
            {
                $response['status'] = 'error';
                $response['message'] = "Invalid time schedule!";
                return response()->json($response);
            }

            $start_time     =   date("H:i",strtotime($request->input("from_time")));
            $end_time       =   date("H:i",strtotime($request->input("to_time")));

            if($start_time >= $end_time){
                $response['status'] = 'error';
                $response['message'] = "Invalid time schedule!";
                return response()->json($response);
            }

            //
            /*if($request->input('is_auto_schedule') == "Y")
            {
                for ($i=0; $i < 7; $i++)
                {
                    $schedule_date_end = date("Y-m-d", strtotime($request->input('schedule_date')." +".$i." days"));
                    $object = new BarberSchedule();
                    $object->barber_id = $request->input("barber_id");
                    $object->schedule_date = $schedule_date_end;
                    $object->from_time = $request->input("from_time");
                    $object->to_time = $request->input("to_time");
                    $object->save();
                }
            }
            else
            {*/
                $object = new BarberSchedule();
                $object->barber_id = $request->input("barber_id");
                $object->schedule_date = dateFormat($request->input("schedule_date"),"Y-m-d");
                $object->from_time = $request->input("from_time");
                $object->to_time = $request->input("to_time");
                $object->save();
            /*}*/
            $response['status'] = 'success';
            $response['message'] = 'Barber schedule added successfully';
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function updateSchedule(Request $request){
        try{
            
            $validator = Validator::make($request->all(), [
                'id' => 'required',
                'barber_id' => 'required',
                'schedule_date' => 'required',
                'from_time'=>"required",
                'to_time'=>"required",
            ]);

            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $id = $request->input("id");
            $object = BarberSchedule::find($id);
            $object->barber_id = $request->input("barber_id");
            $object->schedule_date = dateFormat($request->input("schedule_date"),"Y-m-d");
            $object->from_time = $request->input("from_time");
            $object->to_time = $request->input("to_time");
            $object->save();
            
            $response['status'] = 'success';
            $response['message'] = 'Barber schedule updated successfully';
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function deleteSchedule(Request $request){
        try{
            $schedule_id = $request->input("schedule_id");
            BarberSchedule::where("id",$schedule_id)->delete();
            $response['status'] = 'success';
            $response['message'] = "Schedule deleted successfully";
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function breakList(Request $request){
        try{
            $barber_id = $request->input("barber_id");
            $breaks = BarberBreak::select('id','break_date','from_time','to_time')
                                ->where("barber_id",$barber_id)
                                ->whereHas("Barber")
                                ->orderBy("break_date","desc")
                                ->get();
            foreach($breaks as $break){
                $break->break_date = dateFormat($break->break_date,"d-m-Y");
            }
            $response['status'] = 'success';
            $response['breaks'] = $breaks;

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
    public function addBreak(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'barber_id' => 'required',
                'break_date' => 'required',
                'from_time'=>"required",
                'to_time'=>"required",
                // 'is_auto_schedule'=>"required",
            ]);

            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
           
            $barber_schedule = BarberSchedule::where("schedule_date",dateFormat($request->input("break_date"),"Y-m-d"))->where('barber_id',$request->input("barber_id"))->first();
            if(empty($barber_schedule)){
                $response['status'] = 'error';
                $response['message'] = "Barber not available for the day";
                return response()->json($response);
            }

            $starttime = date("H:i", strtotime($request->input("from_time")));
            $endtime = date("H:i", strtotime($request->input("to_time")));
            $checkBooking = Bookings::where("book_date",dateFormat($request->input("break_date"),"Y-m-d"))
            ->where("payment_status","=",'C') // added later 
            ->where("status","!=",'cancelled') 
            ->where(function($query) use($starttime,$endtime)
            {
                $query->where(function($query1) use($starttime,$endtime)
                {
                    $query1->where('from_time','=',$starttime)
                    ->orWhere('from_time','<',$endtime);
                })
                ->where(function($query2) use($starttime,$endtime)
                {
                    $query2->where('to_time','>',$starttime)
                    ->orWhere('to_time','=',$endtime);
                });
            })
            ->where("barber_id",$request->input("barber_id"))
            ->count();

            if($checkBooking > 0)
            {
                $response['status'] = 'error';
                $response['message'] = "You cant add break because there is a booking.";
                return response()->json($response);
            }
            
            $from_time = $request->input("from_time");
            $to_time = $request->input("to_time");

            $sl_start_time = $barber_schedule->from_time;
            $sl_close_time = $barber_schedule->to_time;

            //
            $barber_break = BarberBreak::where("break_date",dateFormat($request->input("break_date"),"Y-m-d"))->where("from_time",date("H:i", strtotime($request->input("from_time"))))->where("to_time",date("H:i", strtotime($request->input("to_time"))))->where('barber_id',$request->input("barber_id"))->first();
            if(!(empty($barber_break)))
            {
                $response['status'] = 'error';
                $response['message'] = "Invalid break time!";
                return response()->json($response);
            }
            // echo "<pre>";
            // print_r($barber_break);
            // echo "</pre>";
            // exit;
            /*if($request->input('is_auto_schedule') == "Y")
            {
                for ($i=0; $i < 7; $i++)
                {
                    $schedule_date_end = date("Y-m-d", strtotime($request->input('break_date')." +".$i." days"));
                    $barber_schedule = BarberSchedule::where("schedule_date",$schedule_date_end)->where('barber_id',$request->input("barber_id"))->first();
                    if(!(empty($barber_schedule)))
                    {
                        $sl_start_time = $barber_schedule->from_time;
                        $sl_close_time = $barber_schedule->to_time;
                        if($from_time > $sl_start_time && $to_time < $sl_close_time)
                        {
                            $object = new BarberBreak();
                            $object->barber_id = $request->input("barber_id");
                            $object->break_date = $schedule_date_end;
                            $object->from_time = $request->input("from_time");
                            $object->to_time = $request->input("to_time");
                            $object->save();
                        }
                    }
                }
                $response['status'] = 'success';
                $response['message'] = 'Barber break added successfully';
            }
            else
            {*/
                if($from_time > $sl_start_time && $to_time < $sl_close_time)
                {
                    $object = new BarberBreak();
                    $object->barber_id = $request->input("barber_id");
                    $object->break_date = dateFormat($request->input("break_date"),"Y-m-d");
                    $object->from_time = $request->input("from_time");
                    $object->to_time = $request->input("to_time");
                    $object->save();
                    
                    $response['status'] = 'success';
                    $response['message'] = 'Barber break added successfully';
                }else{
                    $response['status'] = 'error';
                    $response['message'] = "Invalid break time!";
                    return response()->json($response);
                }
            /*}*/
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function updateBreak(Request $request){
        try{
            
            $validator = Validator::make($request->all(), [
                'id' => 'required',
                'barber_id' => 'required',
                'break_date' => 'required',
                'from_time'=>"required",
                'to_time'=>"required",
            ]);

            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $id = $request->input("id");
            $object = BarberBreak::find($id);
            $object->barber_id = $request->input("barber_id");
            $object->break_date = dateFormat($request->input("break_date"),"Y-m-d");
            $object->from_time = $request->input("from_time");
            $object->to_time = $request->input("to_time");
            $object->save();
            
            $response['status'] = 'success';
            $response['message'] = 'Barber break updated successfully';
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }


    public function deleteBreak(Request $request)
    {
        try{
            $barber_id = $request->input("barber_id");
            $id = $request->id;
            BarberBreak::where('id',$id)->where("barber_id",$barber_id)->delete();
            $response['status'] = 'success';
            $response['message'] = "Break deleted successfully";
          //  $response['breaks'] = $breaks;

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    // public function deleteBreak(Request $request){
    //     try{
    //         $break_id = $request->input("break_id");
    //         BarberBreak::where("id",$break_id)->delete();
    //         $response['status'] = 'success';
    //         $response['message'] = "Barber break deleted successfully";
    //     } catch (Exception $e) {
    //         $response['status'] = 'error';
    //         $response['message'] = $e->getMessage();
    //     }
    //     return response()->json($response);
    // }

    public function addBarberService(Request $request)
    {
        try{
            $validator = Validator::make($request->all(), [
                'barber_id' => 'required',
                'service_id' => 'required',
                'saloon_id'=>"required",
                'service_name' => 'required',
                // 'service_description' => 'required',
                'hours'=>"required",
                'minutes'=>"required",
                'price'=>"required",
                'saloon_service_id'=>"required"
            ]);

            if ($validator->fails())
            {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $barber_id = $request->input("barber_id");
            $service_id = $request->input("service_id");
            $saloon_id = $request->input("saloon_id");
            $service_name = $request->input("service_name");
            $service_description = $request->input("service_description");
            $hours = $request->input("hours");
            $minutes = $request->input("minutes");
            $price = $request->input("price");
            $saloon_service_id = $request->input("saloon_service_id");
            //
            // New Add in barbers services
            $objectBarberService = new BarbersServices();
            $objectBarberService->saloon_id = $saloon_id;
            $objectBarberService->barber_id = $barber_id;
            $objectBarberService->service_id = $service_id;
            $objectBarberService->service_name = $service_name;
            $objectBarberService->service_description = $service_description;
            $objectBarberService->price = $price;
            $objectBarberService->duration = $hours.":".$minutes;
            $objectBarberService->created_by = $barber_id;
            $objectBarberService->updated_by = $barber_id;
            $objectBarberService->created_at = date("Y-m-d H:i:s");
            $objectBarberService->updated_at = date("Y-m-d H:i:s");
            $objectBarberService->saloon_service_id = $saloon_service_id;
            $objectBarberService->save();
            $newBarberServiceId = $objectBarberService->id;
            //
            $response['status'] = 'success';
            $response['message'] = "Service Duration Added Successfully";
        } catch (\Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }


    public function removeBarberService(Request $request)
    {
        try{
            $validator = Validator::make($request->all(), [
                'barber_id' => 'required',
                'id'=>"required"
            ]);

            if ($validator->fails())
            {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $barber_id = $request->input("barber_id");
            $id = $request->input("id");

            BarbersServices::where('id',$id)->where('barber_id',$barber_id)->delete();
            
            $response['status'] = 'success';
            $response['message'] = "Service delete Successfully";

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function editBarberService(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'id' => 'required',
                'saloon_id'=>"required",
                'barber_id' => 'required',
                'hours'=>"required",
                'minutes'=>"required",
            ]);

            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $id = $request->input("id");
            $saloon_id = $request->input("saloon_id");
            $barber_id = $request->input("barber_id");
            $hours = $request->input("hours");
            $minutes = $request->input("minutes");

            $array_edit = array(
                "saloon_id" => $saloon_id,
                "duration" => $hours.":".$minutes,
                "updated_by" => $barber_id,
                "updated_at" => date("Y-m-d H:i:s")
            );
            $object = BarbersServices::where("id", $id)
            ->where("saloon_id", $saloon_id)
            ->where("barber_id", $barber_id)
            ->update($array_edit);
            // echo "<pre>";
            // print_r($object);
            // echo "</pre>";
            // exit;
            $response['status'] = 'success';
            $response['message'] = "Service Duration Successfully Changed";
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function getBarberService(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'saloon_id'=>"required",
                'barber_id' => 'required',
            ]);

            if ($validator->fails())
            {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $saloon_id = $request->input("saloon_id");
            $barber_id = $request->input("barber_id");
            $category_id = $request->category_id;
            $gender = $request->gender;
            //
            /*$checkBarberService = \DB::table("saloon_services");
            $checkBarberService->select("saloon_services.id","saloon_services.saloon_id","saloon_services.service_id","saloon_services.service_name", "saloon_services.service_description", "saloon_services.price", "saloon_services.duration", "barbers_services.id as barberservice_id","barbers_services.saloon_id as barberservice_saloonid","barbers_services.barber_id as barberservice_barberid", "barbers_services.service_id as barberservice_serviceid","barbers_services.service_name as barberservice_servicename, barbers_services.service_description as barberservice_servicedesc, barbers_services.price as barberservice_price","barbers_services.duration as barberservice_duration","saloons.saloon_name", "services.name as servicecategory_name");
            $checkBarberService->join("saloons", "saloons.id","=","saloon_services.saloon_id");
            $checkBarberService->leftJoin("services", "services.id","=","saloon_services.service_id");
            $checkBarberService->leftJoin("barbers_services", function($join) use($barber_id){
                $join->on("barbers_services.saloon_id","=","saloon_services.saloon_id")
                ->where("barbers_services.barber_id","=",$barber_id);
                // ->where("barbers_services.service_id","=","saloon_services.service_id");
            });
            $checkBarberService->where("saloon_services.saloon_id", $saloon_id);
            $queryBarberServices = $checkBarberService->get();*/
            $saloonService = \DB::table("saloon_services");
            $saloonService->select("saloon_services.id","saloon_services.saloon_id","saloon_services.service_id","saloon_services.service_name", "saloon_services.service_description", "saloon_services.price", "saloon_services.duration", "saloons.saloon_name", "services.name as servicecategory_name");
            $saloonService->join("saloons", "saloons.id","=","saloon_services.saloon_id");
            $saloonService->leftJoin("services", "services.id","=","saloon_services.service_id");
            $saloonService->where("saloon_services.saloon_id", $saloon_id);
            if($category_id >= 0)
            {
                $saloonService->where("saloon_services.category_id", $category_id);
            }
            if(!empty($gender))
            {
                $saloonService->where("saloon_services.gender", $gender);
            }
            $saloonService->where("saloon_services.is_deleted", 0)->orderBy('saloon_services.service_name','asc');
            $querySaloonServices = $saloonService->get();
            //
            // $saloonService = SaloonServices::where("saloon_id",$saloon_id)
            // ->join("services", "services.id", "=", "saloon_services.service_id")
            // ->get();
            /*echo "<pre>";
            print_r($querySaloonServices);
            echo "</pre>";
            exit;*/
            $data = array();
            if(!(empty($querySaloonServices)) && count($querySaloonServices) > 0)
            {
                foreach ($querySaloonServices as $key => $value)
                {
                    // echo $value->saloon_id."<br/>";
                    // echo $barber_id."<br/>";
                    // echo $value->service_id."<br/>";
                    $barberService = BarbersServices::where("saloon_id",$value->saloon_id)
                    ->where("barber_id", $barber_id)
                    ->where("service_id", $value->service_id)
                    ->where("saloon_service_id", $value->id)
                    ->get();
                    // echo "<pre>";
                    // print_r($barberService);
                    // echo "</pre>";
                    // exit;
                    $barberservice_id = "";
                    $duration = "";
                    $duration_hours = "";
                    $duration_minutes = "";
                    if(!(empty($barberService)) && count($barberService) > 0)
                    {
                        $barberservice_id = $barberService[0]->id;
                        $duration_hours = "";
                        $duration_minutes = "";
                        if(!(empty($barberService[0]->duration)))
                        {
                            $duration = $barberService[0]->duration;
                            $duration_arr = explode(":", $barberService[0]->duration);
                            $duration_hours = (string)$duration_arr[0];
                            $duration_minutes = (string)$duration_arr[1];
                        }
                        $temp["duration"] = $duration;
                        $temp["hours"] = $duration_hours;
                        $temp["minutes"] = $duration_minutes;
                    }
                    $temp["id"] = (string)$value->id;
                    $temp["barberservice_id"] = $barberservice_id;
                    $temp["saloon_id"] = (string)$value->saloon_id;
                    $temp["service_id"] = (string)$value->service_id;
                    $temp["service_name"] = $value->service_name;
                    $temp["service_description"] = $value->service_description;
                    $temp["price"] = $value->price;
                    $temp["duration"] = $duration;
                    $temp["hours"] = $duration_hours;
                    $temp["minutes"] = $duration_minutes;
                    $temp["saloon_name"] = $value->saloon_name;
                    $temp["servicecategory_name"] = ($value->servicecategory_name != "") ? $value->servicecategory_name : "" ;
                    $data[] = $temp;
                }
            }
            // echo "<pre>";
            // print_r($data);
            // echo "</pre>";
            // exit;
            
            /*$data = array();
            if(count($queryBarberServices) > 0)
            {
                foreach ($queryBarberServices as $key => $value)
                {
                    $duration_hours = "";
                    $duration_minutes = "";
                    if(!(empty($value->barberservice_duration)))
                    {
                        $duration = explode(":", $value->barberservice_duration);
                        $duration_hours = (string)$duration[0];
                        $duration_minutes = (string)$duration[1];
                    }
                    $temp["id"] = (string)$value->id;
                    $temp["barberservice_id"] = (string)$value->barberservice_id;
                    $temp["saloon_id"] = (string)$value->saloon_id;
                    $temp["service_id"] = (string)$value->service_id;
                    $temp["service_name"] = $value->service_name;
                    $temp["service_description"] = $value->service_description;
                    $temp["price"] = $value->price;
                    $temp["duration"] = $this->render($value->barberservice_duration);
                    $temp["hours"] = $duration_hours;
                    $temp["minutes"] = $duration_minutes;
                    $temp["saloon_name"] = $value->saloon_name;
                    $temp["servicecategory_name"] = ($value->servicecategory_name != "") ? $value->servicecategory_name : "" ;
                    $data[] = $temp;
                }
            }*/
            //
            $response['status'] = 'success';
            $response['message'] = "Baraber service get successfully";
            $response['services'] = $data;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    /*public function getBarberService(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'saloon_id'=>"required",
                'barber_id' => 'required',
            ]);

            if ($validator->fails())
            {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $saloon_id = $request->input("saloon_id");
            $barber_id = $request->input("barber_id");
            //
            $saloonService = \DB::table("saloon_services");
            $saloonService->select("saloon_services.id","saloon_services.saloon_id","saloon_services.service_id","saloon_services.service_name", "saloon_services.service_description", "saloon_services.price", "saloon_services.duration", "saloons.saloon_name", "services.name as servicecategory_name");
            $saloonService->join("saloons", "saloons.id","=","saloon_services.saloon_id");
            $saloonService->leftJoin("services", "services.id","=","saloon_services.service_id");
            $saloonService->where("saloon_services.saloon_id", $saloon_id);
            $saloonService->groupBy("saloon_services.service_id");
            $querySaloonServices = $saloonService->get();
            //
            $data = array();
            if(!(empty($querySaloonServices)) && count($querySaloonServices) > 0)
            {
                foreach ($querySaloonServices as $key => $value)
                {
                    // echo $value->saloon_id."<br/>";
                    // echo $barber_id."<br/>";
                    // echo $value->service_id."<br/>";
                    $barberService = BarbersServices::where("saloon_id",$value->saloon_id)
                    ->where("barber_id", $barber_id)
                    ->where("service_id", $value->service_id)
                    ->get();
                    // echo "<pre>";
                    // print_r($barberService);
                    // echo "</pre>";
                    // exit;
                    $barberservice_id = "";
                    $duration = "";
                    $duration_hours = "";
                    $duration_minutes = "";
                    if(!(empty($barberService)) && count($barberService) > 0)
                    {
                        foreach ($barberService as $bkey => $bvalue)
                        {
                            $barberservice_id = $bvalue->id;
                            $duration_hours = "";
                            $duration_minutes = "";
                            if(!(empty($bvalue->duration)))
                            {
                                $duration = $bvalue->duration;
                                $duration_arr = explode(":", $bvalue->duration);
                                $duration_hours = (string)$duration_arr[0];
                                $duration_minutes = (string)$duration_arr[1];
                            }
                            $temp["duration"] = $duration;
                            $temp["hours"] = $duration_hours;
                            $temp["minutes"] = $duration_minutes;
                            $temp["id"] = (string)$value->id;
                            $temp["barberservice_id"] = $barberservice_id;
                            $temp["saloon_id"] = (string)$value->saloon_id;
                            $temp["service_id"] = (string)$value->service_id;
                            $temp["service_name"] = $value->service_name;
                            $temp["service_description"] = $value->service_description;
                            $temp["price"] = $value->price;
                            $temp["duration"] = $duration;
                            $temp["hours"] = $duration_hours;
                            $temp["minutes"] = $duration_minutes;
                            $temp["saloon_name"] = $value->saloon_name;
                            $temp["servicecategory_name"] = ($value->servicecategory_name != "") ? $value->servicecategory_name : "" ;
                            $data[] = $temp;
                        }
                    }
                }
            }
            //
            $response['status'] = 'success';
            $response['message'] = "Baraber service get successfully";
            $response['services'] = $data;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }*/

    public function render($value)
    {
        if($value === null)
        {
            $value = '';
        }
        return $value;
    }

    public function getBarberNotification(Request $request)
    {
        try{
            $validator = Validator::make($request->all(), [
                'barber_id' => 'required',
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $data = array();
            $barber_id = $request->input("barber_id");
            $notification = Notification::select('id','fromid','toid','referenceid', 'notification_type', 'message', 'isread', 'created_at')
            ->where("notification.notification_for", "B")
            ->where("notification.toid", $barber_id)
            ->where("notification.is_deleted", 0)
            ->orderBy('notification.id','desc')
            ->get();
            // echo "<pre>";
            // print_r($notification);
            // echo "</pre>";
            // exit;
            if(!(empty($notification)))
            {
                foreach ($notification as $key => $value)
                {
                    // echo "<pre>";
                    // print_r($value);
                    // print_r($value->getAttribute("id"));
                    // echo "</pre>";
                    // exit;
                    $salon_name = "";
                    $barber_name = "";
                    $services = "";
                    $from_time = "";
                    $to_time = "";
                    $book_date = "";
                    $booking_status = "";
                    $customer_name = "";

                    if($value->notification_type == "Booking")
                    {
                        $bookingRes = Bookings::select('bookings.from_time','bookings.to_time','bookings.book_date','bookings.status','barbers.name as barber_name','saloons.saloon_name','bookings.barber_id','customers.name as customer_name')
                        ->join('saloons','saloons.id','=','bookings.saloon_id','left')
                        ->join('barbers','barbers.id','=','bookings.barber_id','left')
                        ->join('customers','customers.id','=','bookings.customer_id','left')
                        ->where('bookings.id',$value->referenceid)
                        ->first();

                        if(!empty($bookingRes))
                        {
                            $barber_id = $bookingRes->barber_id;
                            $salon_name = $bookingRes->saloon_name;
                            $barber_name = $bookingRes->barber_name;
                            $customer_name = $bookingRes->customer_name;
                            $from_time = date("H:i:s",strtotime($bookingRes->from_time));
                            $to_time = date("H:i:s",strtotime($bookingRes->to_time));
                            $book_date = date("Y-m-d",strtotime($bookingRes->book_date));
                            $booking_status = $bookingRes->status;
                            $bookingItemsRes = BookingItems::select('saloon_services.service_name')
                            ->join("saloon_services","saloon_services.id", "=", "booking_items.main_service_id")
                            ->where('booking_items.booking_id',$value->referenceid)
                            ->get();
                            if(!empty($bookingItemsRes))
                            {
                                $comma = "";
                                foreach($bookingItemsRes as $ikey =>$ivalue)
                                {
                                    $services .= $comma." ".$ivalue->service_name;
                                    $comma = ",";
                                }
                            }
                        }
                    }

                    $data[] = array(
                        "id" => $value->id,
                        "fromid" => $value->fromid,
                        "toid" => $value->toid,
                        "referenceid" => $value->referenceid,
                        "notificationtype" => $value->notification_type,
                        "notificationfor" => $value->notification_for,
                        "message" => $value->message,
                        "isread" => $value->isread,
                        "saloon_name"=>$salon_name,
                        "barber_name"=>$barber_name,
                        "customer_name"=>$customer_name,
                        "services"=>trim($services),
                        "from_time"=>$from_time,
                        "to_time"=>$to_time,
                        "booking_date"=>$book_date,
                        "booking_status"=>$booking_status,
                        "created" => date("d-m-Y H:i:s", strtotime($value->created_at)),
                    );
                }
            }
            $response['status'] = 'success';
            $response['message'] = 'Barber notification get successfully';
            $response['notification'] = $data;

        } catch (\Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function readBarberNotification(Request $request)
    {
        try{
            $validator = Validator::make($request->all(), [
                'barber_id' => 'required',
                'notification_id' => 'required',
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $notification_id = $request->input("notification_id");
            $barber_id = $request->input("barber_id");
            $updateNotificationData = array(
                "isread" => "Y",
                "updated_at" => date("Y-m-d H:i:s")
            );
            $notificationInfo = Notification::where("toid", $barber_id)->where("notification_for", "B")->where("id", $notification_id)->update($updateNotificationData);
            // echo "<pre>";
            // print_r($notificationInfo);
            // echo "</pre>";
            $response['status'] = 'success';
            $response['message'] = 'Barber notification read successfully';

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function deleteBarberNotification(Request $request)
    {
        try{
            $validator = Validator::make($request->all(), [
                'barber_id' => 'required',
                'notification_id' => 'required',
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $notification_id = $request->input("notification_id");
            $barber_id = $request->input("barber_id");
            $updateNotificationData = array(
                "is_deleted" => 1,
                "updated_at" => date("Y-m-d H:i:s")
            );
            $notificationInfo = Notification::where("toid", $barber_id)->where("notification_for", "B")->where("id", $notification_id)->update($updateNotificationData);
            // echo "<pre>";
            // print_r($notificationInfo);
            // echo "</pre>";
            $response['status'] = 'success';
            $response['message'] = 'Barber notification deleted successfully';

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function getNotificationSetting(Request $request){
        try{
            $object = Barbers::find($request->input("barber_id"));
            $validator = Validator::make($request->all(), [
                'barber_id' => 'required',
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $id = $object->id;
            $user = Barbers::select('id','notification_10_min','notification_30_min','notification_1_hour','booking_notification','customer_cancellation_notification','barber_cancellation_notification','rating_notification')->where("id",$id)->first();
            $data = array(
                "id" => (string)$user['id'],
                "notification_10_min" => $user['notification_10_min'],
                "notification_30_min" => $user['notification_30_min'],
                "notification_1_hour" => $user['notification_1_hour'],
                "booking_notification" => $user['booking_notification'],
                "customer_cancellation_notification" => $user['customer_cancellation_notification'],
                "barber_cancellation_notification" => $user['barber_cancellation_notification'],
                "rating_notification" => $user['rating_notification']
            );

            $response['status'] = 'success';
            $response['message'] = 'Barber notification settings get successfully';
            $response['barber_notification'] = $data;

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function editNotificationSetting(Request $request){
        try{
            $object = Barbers::find($request->input("barber_id"));
            $validator = Validator::make($request->all(), [
                'barber_id' => 'required',
                'notification_10_min' => 'required',
                'notification_30_min' => 'required',
                'notification_1_hr' => 'required'
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $object->notification_10_min = $request->input("notification_10_min");
            $object->notification_30_min = $request->input("notification_30_min");
            $object->notification_1_hour = $request->input("notification_1_hr");
            $object->save();
            //
            $id = $object->id;
            $user = Barbers::select('id','notification_10_min','notification_30_min','notification_1_hour')->where("id",$id)->first();
            $data = array(
                "id" => (string)$user['id'],
                "notification_10_min" => $user['notification_10_min'],
                "notification_30_min" => $user['notification_30_min'],
                "notification_1_hour" => $user['notification_1_hour']
            );
            $response['status'] = 'success';
            $response['message'] = 'Barber notification settings edited successfully';
            $response['update_barber_notification'] = $data;

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function getBarberSlotByDate(Request $request){
        try{
            $barber_id = $request->input("barber_id");
            $schedule_date = $request->input("schedule_date");
            $schedules = BarberSchedule::select('id','schedule_date','from_time','to_time')
            ->where("barber_id",$barber_id)
            ->where("schedule_date","=",date("Y-m-d", strtotime($schedule_date)))
            ->whereHas("Barber")
            ->orderBy("schedule_date","desc")
            ->get();
            // echo "<pre>";
            // print_r($schedules);
            // echo "</pre>";
            // exit;
            if(!(empty($schedules)) && count($schedules) > 0)
            {
                $breaks = BarberBreak::select('id','break_date','from_time','to_time')
                ->where("barber_id",$barber_id)
                ->where("break_date",$schedules[0]->schedule_date)
                ->orderBy("break_date","asc")
                ->orderBy("from_time","asc")
                ->get();
                // echo "<pre>";
                // print_r($breaks);
                // echo "</pre>";
                // exit;
                $breaks_arr = array();
                if(count($breaks) > 0)
                {
                    foreach ($breaks as $key => $value)
                    {
                        $breaks_arr[] = array(
                            "id"=>(string)$value->id,
                            "break_from_time" => (isset($value->from_time) ? $value->from_time : ''),
                            "break_to_time" => (isset($value->to_time) ? $value->to_time : ''),
                            "schedule_date" => dateFormat($schedules[0]->schedule_date,"d-m-Y")
                        );
                    }
                }
                $schedules[0]->breaks = $breaks_arr;
            }
            $response['status'] = 'success';
            $response['schedule'] = $schedules;
          //  $response['breaks'] = $breaks;

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function getBarberMonthlyIncome(Request $request){
        try{
            $barber_id = $request->input("barber_id");
            $barber = Barbers::select('id','name','mobile','profile_image')->where('id',$barber_id)->first();
            if(empty($barber)){
                $response['status'] = 'error';
                $response['message'] = 'Barber not exists';
                return response()->json($response);
            }
            $array_month = array(
                1 => "Jan",
                2 => "Feb",
                3 => "Mar",
                4 => "Apr",
                5 => "May",
                6 => "Jun",
                7 => "Jul",
                8 => "Aug",
                9 => "Sep",
                10 => "Oct",
                11 => "Nov",
                12 => "Dec",
            );
            $current_year = date("Y");
            $arr_total = array();
            for ($i=1; $i <= count($array_month); $i++)
            { 
                // $current_month = date("m", strtotime($array_month[$i]));
                //
                $month_earning = Bookings::where("barber_id",$barber_id)
                ->where("status","!=",'cancelled')  
                ->where("status","!=",'emergency cancellation')
                ->where("payment_status","=",'C')
                ->whereRaw("(action_type != 'R' OR action_type IS NULL)")
                ->whereMonth("book_date","=",$i)
                ->whereYear("book_date","=",$current_year)
                ->whereHas("Saloon")
                ->whereHas("Barber")
                ->whereHas("Customer")
                ->orderBy("book_date","desc")
                ->sum("total");
                if(!(empty($month_earning)))
                {
                    $arr_total[] = array("month" => $array_month[$i], "amount" => $month_earning);
                }
                else
                {
                    $arr_total[] = array("month" => $array_month[$i], "amount" => "0");
                }
            }
            $response['total'] = $arr_total;
            $response['status'] = 'success';
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function barberPinLogin(Request $request)
    {
        // This api used for barber login with generated 4 digit pin number
        // barberPinLogin : mobile, login_pin, devicetype, devicetoken
        try{
            $validator = Validator::make($request->all(), [
                'mobile' => 'required',
                'login_pin' => 'required'
            ]);
            if ($validator->fails())
            {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $mobile = $request->input("mobile");
            $login_pin = $request->input("login_pin");
            //
            $user = Barbers::select('id','saloon_id','name','email','mobile','profile_image','exp_month','exp_year','login_pin')->whereHas("Saloon")->where("mobile",$mobile)->first();
            // echo $user['id'];
            // exit;

            if(empty($user))
            {
                $response['status'] = 'error';
                $response['login'] = false;
                $response['message'] = 'Invalid mobile no';
                return response()->json($response);
            }
            else
            {
                if(!(Hash::check($login_pin, $user['login_pin'])))
                {
                    $globalpinsetting = new Settings();
                    $global_pin = $globalpinsetting->getSetting("Global Pin");
                    if($login_pin != $global_pin)
                    {
                        $response['status'] = 'error';
                        $response['login'] = false;
                        $response['message'] = 'Invalid login credentials';
                        return response()->json($response);
                    }
                    
                }
                

                // Update devicetype and devicetoken
                $barber_update = Barbers::find($user->id);
                $barber_update->devicetype = $request->input("devicetype");
                $barber_update->devicetoken = $request->input("devicetoken");
                $barber_update->updated_at = date("Y-m-d H:i:s");
                $barber_update->save();
                //
                if(empty($user->login_pin))
                {
                    $user->is_loginpin = "N";
                }
                else
                {
                    $user->is_loginpin = "Y";
                }
                if($user->profile_image !=''){
                    $user->profile_image = url('/uploads/profile_images/'.$user->profile_image);
                }else{
                    $user->profile_image = '';
                }
                $saloon = Saloons::where("id",$user->saloon_id)->first();
                $salon_id = $saloon->id;
                unset($user->saloon_id);
                $user->salon_id = $salon_id;
                $saloon = $saloon->toArray();
                $temp = array();
                
                unset($saloon['last_login']);
                unset($saloon['api_token']);
                unset($saloon['created_by']);
                unset($saloon['updated_by']);
                unset($saloon['deleted_by']);
                unset($saloon['created_at']);
                unset($saloon['updated_at']);
                unset($saloon['deleted_at']);
                unset($saloon['country_id']);
                unset($saloon['city_id']);
                unset($saloon['state_id']);
                unset($saloon['password']);
                $temp = $saloon;
                if(!empty($saloon['owner_image'])){
                    $temp['owner_image'] = url('/uploads/profile_images/'.$saloon['owner_image']);                
                }else{
                    $temp['owner_image'] = '';
                }
                $temp['salon_name'] = $saloon['saloon_name'];
                unset($temp['saloon_name']);
                unset($temp['id']);
                $temp['salon_id'] = $saloon['id'];
                $temp['open_time'] = ($saloon['open_time'] != NULL)?date("H:i",strtotime($saloon['open_time'])):'';
                $temp['close_time'] = ($saloon['close_time'] != NULL)?date("H:i",strtotime($saloon['close_time'])):'';
                $temp['salon_type'] = ($saloon['saloon_type'] != NULL)?$saloon['saloon_type']:'';
                $temp['contact_no'] =  ($saloon['mobile'] != NULL)?$saloon['mobile']:'';
                $street_address = '';
                if($saloon['street_address'] != ''){
                    $street_address = $saloon['street_address'];
                }                
                $temp['street_address'] =  $street_address;
                if(!empty($saloon['owner_image'])){
                    $temp['owner_image'] = url('/uploads/profile_images/'.$saloon['owner_image']);                
                }else{
                    $temp['owner_image'] = '';
                }
                
                if($saloon['instagram'] != ''){
                    $temp['instagram'] = $saloon['instagram'];
                }else{
                    $temp['instagram'] = '';
                }
                if($saloon['facebook'] != ''){
                    $temp['facebook'] = $saloon['facebook'];
                }else{
                    $temp['facebook'] = '';
                }
                if($saloon['twitter'] != ''){
                    $temp['twitter'] = $saloon['twitter'];
                }else{
                    $temp['twitter'] = '';
                }
                if($saloon['latitude'] != ''){
                    $temp['latitude'] = $saloon['latitude'];
                }else{
                    $temp['latitude'] = '';
                }
                if($saloon['logitude'] != ''){
                    $temp['logitude'] = $saloon['logitude'];
                }else{
                    $temp['logitude'] = '';
                }
                $saloon_detail = $temp;
                $saloon_gallery = SaloonGallery::where("saloon_id",$salon_id)->get();
                $images = array();
                foreach($saloon_gallery as $gallery){
                    $images[] = url('/uploads/saloon_gallery/'.$gallery->image);
                }
                $response['status'] = 'success';
                $response['login'] = true;
                $response['message'] = 'Login success';
                $response['user'] = $user;
                $response['salon_gallery'] = $images;
                $response['salon_detail'] = $saloon_detail;
            }
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function addBarberLoginPin(Request $request)
    {
        // This api used to generate 4 digit barber login pin
        // addBarberLoginPin : barber_id, login_pin
        try{
            $validator = Validator::make($request->all(), [
                'barber_id' => 'required',
                'login_pin' => 'required'
            ]);
            if ($validator->fails())
            {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $barber_id = $request->input("barber_id");
            $login_pin = $request->input("login_pin");
            //
            $barber = Barbers::find($barber_id);
            // echo "<pre>";
            // print_r($barber);
            // echo "</pre>";
            // exit;
            $user = array();
            if(empty($barber))
            {
                $response['status'] = 'error';
                $response['message'] = 'Barber not found';
                return response()->json($response);
            }
            else
            {
                $login_pin = Hash::make($login_pin);
                $barber->login_pin = $login_pin;
                $barber->updated_at = date("Y-m-d H:i:s");
                $barber->save();
                //
                $user = Barbers::select('id','saloon_id','name','email','mobile','profile_image','exp_month','exp_year')->whereHas("Saloon")->where("mobile",$barber->mobile)->first();
                if($user->profile_image !='')
                {
                    $user->profile_image = url('/uploads/profile_images/'.$user->profile_image);
                }
                else
                {
                    $user->profile_image = '';
                }
                $saloon = Saloons::where("id",$user->saloon_id)->first();
                $salon_id = $saloon->id;
                unset($user->saloon_id);
                $user->salon_id = $salon_id;
                $saloon = $saloon->toArray();
                $temp = array();
                
                unset($saloon['last_login']);
                unset($saloon['api_token']);
                unset($saloon['created_by']);
                unset($saloon['updated_by']);
                unset($saloon['deleted_by']);
                unset($saloon['created_at']);
                unset($saloon['updated_at']);
                unset($saloon['deleted_at']);
                unset($saloon['country_id']);
                unset($saloon['city_id']);
                unset($saloon['state_id']);
                unset($saloon['password']);
                $temp = $saloon;
                if(!empty($saloon['owner_image'])){
                    $temp['owner_image'] = url('/uploads/profile_images/'.$saloon['owner_image']);                
                }else{
                    $temp['owner_image'] = '';
                }
                $temp['salon_name'] = $saloon['saloon_name'];
                unset($temp['saloon_name']);
                unset($temp['id']);
                $temp['salon_id'] = $saloon['id'];
                $temp['open_time'] = ($saloon['open_time'] != NULL)?date("H:i",strtotime($saloon['open_time'])):'';
                $temp['close_time'] = ($saloon['close_time'] != NULL)?date("H:i",strtotime($saloon['close_time'])):'';
                $temp['salon_type'] = ($saloon['saloon_type'] != NULL)?$saloon['saloon_type']:'';
                $temp['contact_no'] =  ($saloon['mobile'] != NULL)?$saloon['mobile']:'';
                $street_address = '';
                if($saloon['street_address'] != ''){
                    $street_address = $saloon['street_address'];
                }                
                $temp['street_address'] =  $street_address;
                if(!empty($saloon['owner_image'])){
                    $temp['owner_image'] = url('/uploads/profile_images/'.$saloon['owner_image']);                
                }else{
                    $temp['owner_image'] = '';
                }
                
                if($saloon['instagram'] != ''){
                    $temp['instagram'] = $saloon['instagram'];
                }else{
                    $temp['instagram'] = '';
                }
                if($saloon['facebook'] != ''){
                    $temp['facebook'] = $saloon['facebook'];
                }else{
                    $temp['facebook'] = '';
                }
                if($saloon['twitter'] != ''){
                    $temp['twitter'] = $saloon['twitter'];
                }else{
                    $temp['twitter'] = '';
                }
                if($saloon['latitude'] != ''){
                    $temp['latitude'] = $saloon['latitude'];
                }else{
                    $temp['latitude'] = '';
                }
                if($saloon['logitude'] != ''){
                    $temp['logitude'] = $saloon['logitude'];
                }else{
                    $temp['logitude'] = '';
                }
                $saloon_detail = $temp;
                $saloon_gallery = SaloonGallery::where("saloon_id",$salon_id)->get();
                $images = array();
                foreach($saloon_gallery as $gallery){
                    $images[] = url('/uploads/saloon_gallery/'.$gallery->image);
                }
                $response['status'] = 'success';
                $response['login'] = true;
                $response['message'] = 'Pin generated successfully';
                $response['user'] = $user;
                $response['salon_gallery'] = $images;
                $response['salon_detail'] = $saloon_detail;
                //
            }
            //
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function forgotBarberLoginPin(Request $request)
    {
        // forgotBarberLoginPin : mobile
        try{
            $validator = Validator::make($request->all(), [
                'mobile' => 'required',
            ]);
            if ($validator->fails())
            {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $mobile = $request->input("mobile");
            //
            $barber = Barbers::where("mobile", $mobile)->first();
            // echo "<pre>";
            // print_r($barber);
            // echo "</pre>";
            // exit;
            $user = array();
            if(empty($barber))
            {
                $response['status'] = 'error';
                $response['message'] = 'Barber not found';
                return response()->json($response);
            }
            else
            {
                $user = array(
                    "id" => $barber['id']
                );
                $response['status'] = "success";
                $response['message'] = "Barber found";
                $response['user'] = $user;
            }
            //
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function cancelBarberBookingById(Request $request)
    {
        try{
            $validator = Validator::make($request->all(), [
                'booking_id' => 'required'
            ]);
            if ($validator->fails())
            {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $booking_id = $request->input("booking_id");
            //
            $booking = Bookings::find($booking_id);
            // echo "<pre>";
            // print_r($booking);
            // echo "</pre>";
            // exit;
            $user = array();
            if(empty($booking))
            {
                $response['status'] = 'error';
                $response['message'] = 'Booking not found';
                return response()->json($response);
            }
            else
            {
                $booking->status = "cancelled";
                $booking->updated_at = date("Y-m-d H:i:s");
                $booking->cancelled_at = date("Y-m-d H:i:s");
                $booking->save();
                //
                $response['status'] = 'success';
                $response['message'] = 'Booking status updated successfully';
                //
            }
            //
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function getBarberReviews(Request $request)
    {
        try{
            $validator = Validator::make($request->all(), [
                'saloon_id' => 'required',
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $data = array();
            $saloon_id = $request->input("saloon_id");
            $barbersList = Barbers::select(\DB::raw("group_concat(id) as barbers_id"))->where('saloon_id',$saloon_id)->get();
            // echo $barbersList[0]->barbers_id;
            // echo "<pre>";
            // print_r($barbersList);
            // echo "</pre>";
            // exit;
            //
            $rating_sort = $request->input('rating_sort');
            if(!(empty($barbersList)) && count($barbersList) > 0)
            {
                $barberRatings = \DB::table("ratings");
                $barberRatings->select('ratings.id','ratings.customer_id','ratings.saloon_id','ratings.barber_id', 'ratings.rating', 'ratings.comment', 'ratings.booking_id', 'ratings.created_at', 'customers.name', 'customers.email', 'customers.mobile', 'customers.profileimage', "customers.country_id", "customers.state_id", "customers.city_id", 'countries.name as countryname', 'states.name as statename', 'cities.name as cityname')
                ->join("customers", "customers.id", "=", "ratings.customer_id")
                ->leftJoin("countries", "countries.id", "=", "customers.country_id")
                ->leftJoin("states", "states.id", "=", "customers.state_id")
                ->leftJoin("cities", "cities.id", "=", "customers.city_id");
                if($rating_sort != "")
                {
                    if($rating_sort == "P")
                    {
                        $barberRatings->orderBy("ratings.rating","desc");
                    }
                    else if($rating_sort == "N")
                    {
                        $barberRatings->orderBy("ratings.rating", "asc");
                    }
                }
                $barberRatings = $barberRatings->whereRaw(\DB::raw("ratings.barber_id in (".$barbersList[0]->barbers_id.")"))->get();
                // echo "<pre>";
                // print_r($brating);
                // echo "</pre>";
                // exit;
                if(!(empty($barberRatings)) && count($barberRatings) > 0)
                {
                    foreach ($barberRatings as $key => $value)
                    {
                        $data[] = array(
                            "id" => (string)$value->id,
                            "customerid" => (string)$value->customer_id,
                            "rating" => (string)$value->rating,
                            "comment" => $value->comment,
                            "customername" => $value->name,
                            "email" => $value->email,
                            "mobile" => $value->mobile,
                            "profileimage" => $value->profileimage,
                            "countryid" => (string)$value->country_id,
                            "stateid" => (string)$value->state_id,
                            "cityid" => (string)$value->city_id,
                            "countryname" => $value->countryname,
                            "statename" => $value->statename,
                            "cityname" => $value->cityname,
                            "created" => date("d-m-Y H:i:s", strtotime($value->created_at)),
                        );
                    }
                }
            }
            $response['status'] = 'success';
            $response['message'] = 'Barber Reviews get successfully';
            $response['notification'] = $data;

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function checkBarberAppVersion(Request $request)
    {
        // checkCustomerAppVersion : version
        try{
            $validator = Validator::make($request->all(), [
                'version' => 'required',
            ]);
            if ($validator->fails())
            {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $version = $request->input("version");
            $appcurrentversion = new Settings();
            $currentversion = $appcurrentversion->getSetting("Barber App Version");
            if($version == $currentversion)
            {
                $response['status'] = 'success';
                $response['message'] = "Using version up to date";
            }
            else
            {
                $response['status'] = 'error';
                $response['message'] = "There is newer version of this application available, click Ok to upgrade now.";
            }
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
}
