<?php

namespace App\Http\Controllers\Webservices;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use App\ContactUs;
use App\Customers;
use App\Barbers;
use App\BarbersServices;
use App\Bookings;
use App\BookingItems;
use App\DefaultServices;
use App\SaloonServices;
use App\Saloons;
use App\SaloonGallery;
use App\Services\CommonService;
use App\Services\PhonepayService;
use App\Services\FCMService;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\DB;
use Mail;
use App\Notification;


class CommonController extends Controller
{
    public function update_contact(Request $request)
    {
        $validator = Validator::make($request->all(),[
            'customer_id' => 'required',
            'message'=>'required',
        ]);

         if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $response['message'] = CommonService::getValidationErrorMsg($validator);
                return response()->json($response);
            }
        
            $user_id = $request->input('customer_id');

            $fileName = "";
           $file = $request->file('image');
           if(!empty($file))
           {
                $fileName = time().'-'.str_replace(' ','-',$file->getClientOriginalName());
               $destinationPath = 'uploads/contact/' ;
               $file->move($destinationPath,$fileName);
           }

           if(empty($request->input('type')))
           {
            $type = "C";
           }
           else{
            $type = $request->input('type');
           }
           


           $insertData = array(
                'customer_id'=>$user_id,
                'type'=>$type,
                'message'=>$request->input('message'),
                'image'=>$fileName,
                'created_at'=>date('Y-m-d H:i:s')
           );


            $res = ContactUs::create($insertData);

            $response['status'] = 'success';
            $response['message'] = 'Your query has been successfully received. You will get a reply on your email within 7 days';
            return response()->json($response,200);
        
    }


    public function update_notification_setting(Request $request)
    {
        $validator = Validator::make($request->all(),[
            'customer_id'=>'required',
            'type' => 'required',
            'value'=>'required',
        ]);

         if ($validator->fails()) {
            $response['status'] = 'validation_error';
            $response['message'] = CommonService::getValidationErrorMsg($validator);
            return response()->json($response);
         }

         $updatedata = array();
         $response['message'] = 'Notification update successfully';
         if($request->input('type') == "booking")
         {
            $updatedata['booking_notification'] = $request->input('value');
         }
         else if($request->input('type') == "booking_remainder"){
            $updatedata['booking_remainder_notification'] = $request->input('value');
         }
         else if($request->input('type') == "booking_remainder_minute"){
            $updatedata['booking_remainder_notification_minute'] = $request->input('value');
            $response['message'] = 'Booking Remainder Saved Successfully';
         }
         else if($request->input('type') == "cancellation"){
            $updatedata['cancellation_notification'] = $request->input('value');
         }

         Customers::where('customers.id',$request->input('customer_id'))->update($updatedata);


        $response['status'] = 'success';
        
        return response()->json($response,200);
    }



    public function update_barber_notification_setting(Request $request)
    {
        $validator = Validator::make($request->all(),[
            'barber_id'=>'required',
            'type' => 'required',
            'value'=>'required',
        ]);

         if ($validator->fails()) {
            $response['status'] = 'validation_error';
            $response['message'] = CommonService::getValidationErrorMsg($validator);
            return response()->json($response);
         }

         $updatedata = array();

         if($request->input('type') == "booking")
         {
            $updatedata['booking_notification'] = $request->input('value');
         }
         else if($request->input('type') == "customer_cancellation"){
            $updatedata['customer_cancellation_notification'] = $request->input('value');
         }
         else if($request->input('type') == "barber_cancellation"){
            $updatedata['barber_cancellation_notification'] = $request->input('value');
         }
         else if($request->input('type') == "rating"){
            $updatedata['rating_notification'] = $request->input('value');
         }
         else if($request->input('type') == "notification_10_min"){
            $updatedata['notification_10_min'] = $request->input('value');
         }
         else if($request->input('type') == "notification_30_min"){
            $updatedata['notification_30_min'] = $request->input('value');
         }
         else if($request->input('type') == "notification_1_hour"){
            $updatedata['notification_1_hour'] = $request->input('value');
         }
         
         Barbers::where('barbers.id',$request->input('barber_id'))->update($updatedata);


        $response['status'] = 'success';
        $response['message'] = 'Notification update successfully';
        return response()->json($response,200);
    }


    public function edit_mobile(Request $request)
    {
        try{

            $validator = Validator::make($request->all(), [
                'user_id' => 'required',
                'type' => 'required',
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $response['message'] = CommonService::getValidationErrorMsg($validator);
                return response()->json($response);
            }

            if($request->input('type') == "B")
            {
                $object = Barbers::find($request->input("user_id"));
                if(!empty($object))
                {
                    $validator = Validator::make($request->all(), [
                        'mobile' => 'required|unique:barbers,mobile,'.$object->id,
                    ]);
                    if ($validator->fails()) {
                        $response['status'] = 'validation_error';
                        $response['message'] = CommonService::getValidationErrorMsg($validator);
                        return response()->json($response);
                    }
                    $object->mobile = $request->input("mobile");
                    $object->status = 1;
                    $object->save();
                    $id = $object->id;
                    $user = Barbers::select('id','name','email','mobile')->where("id",$id)
                                    ->first();
                    $response['status'] = 'success';
                    $response['message'] = 'Barbers mobile edited successfully';
                    $response['user'] = $user;
                }
                else{
                    $response['status'] = 'error';
                    $response['message'] = 'Barbers not found';
                }
            }
            else{
                $userobject = Saloons::find($request->input("user_id"));
                if(!empty($userobject))
                {
                    $validator = Validator::make($request->all(), [
                        'mobile' => 'required|unique:saloons,mobile,'.$userobject->id,
                    ]);
                    if ($validator->fails()) {
                        $response['status'] = 'validation_error';
                        $response['message'] = CommonService::getValidationErrorMsg($validator);
                        return response()->json($response);
                    }
                    $userobject->mobile = $request->input("mobile");
                    $userobject->status = 1;
                    $userobject->save();
                    $id = $userobject->id;
                    $user = Saloons::select('id','saloon_name','contact_person','email','mobile')->where("id",$id)
                                    ->first();
                    $response['status'] = 'success';
                    $response['message'] = 'User mobile edited successfully';
                    $response['user'] = $user;
                }
                else{
                    $response['status'] = 'error';
                    $response['message'] = 'User not found';
                }
            }

        } catch (\Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }


    public function editProfile(Request $request){
        try{
            // echo "<pre>";
            // print_r($request->all());
            // echo "</pre>";
            // echo $request->input("salon_id");
            // exit;
            $object = Saloons::find($request->input("salon_id"));
            $validator = Validator::make($request->all(), [
                'contact_person' => 'required',
                'email' => 'nullable|sometimes|email|unique:saloons,email,'.$object->id,
                'mobile' => 'required|unique:saloons,mobile,'.$object->id,
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $response['message'] = CommonService::getValidationErrorMsg($validator);
                return response()->json($response);
            }
            $object->contact_person = $request->input("contact_person");
            $object->email = $request->input("email");
            $object->mobile = $request->input("mobile");
            $object->bank_name = $request->input("bank_name");
            $object->account_number = $request->input("account_number");
            $object->ifsc_code = $request->input("ifsc_code");
            $object->upi_id = $request->input("upi_id");
            
            if($request->input("owner_image")){
                if($object->owner_image != '' && file_exists('uploads/profile_images/'.$object->owner_image)){
                    unlink('uploads/profile_images/'.$object->owner_image);                    
                } 
                $image_64 = base64_decode($request->input("owner_image"));
                $f = finfo_open();
                $mime_type = finfo_buffer($f, $image_64, FILEINFO_MIME_TYPE);  
                $extensions = explode("/",$mime_type);
                $ext = end($extensions);
               
                $ci_fileName= time().'-'.rand(00000,99999).'.'.$ext;
                file_put_contents('uploads/profile_images/'.$ci_fileName,$image_64);    
                $object->owner_image = $ci_fileName;
            }
            $object->save();
            $saloon_id = $object->id;
            
            /*if($request->input('salon_gallery'))
            {
                $sg_images   = $request->input('salon_gallery'); //your base64 encoded data
                for($i=0;$i < count($sg_images);$i++)
                {
                    $image_64 = base64_decode($sg_images[$i]);
                    $f = finfo_open();
                    $mime_type = finfo_buffer($f, $image_64, FILEINFO_MIME_TYPE);  
                    $extensions = explode("/",$mime_type);
                    $ext = end($extensions);
                   
                    $ci_fileName= time().'-'.rand(00000,99999).'.'.$ext;
                    file_put_contents(public_path('uploads/saloon_gallery/').$ci_fileName, $image_64);    
                    $saloon_gallery = new SaloonGallery();
                    $saloon_gallery->saloon_id = $saloon_id;
                    $saloon_gallery->image = $ci_fileName;
                    $saloon_gallery->created_by = $saloon_id;
                    $saloon_gallery->save();
                }
            }*/

            // $temp = array();
            // $temp['salon_id'] = $saloon['id'];
            // $temp['salon_name'] = $saloon['saloon_name'];
            // $temp['open_time'] = ($saloon['open_time'] != NULL)?date("H:i",strtotime($saloon['open_time'])):'';
            // $temp['close_time'] = ($saloon['close_time'] != NULL)?date("H:i",strtotime($saloon['close_time'])):'';
            // $temp['salon_type'] = ($saloon['saloon_type'] != NULL)?$saloon['saloon_type']:'';
            // $temp['contact_no'] =  ($saloon['mobile'] != NULL)?$saloon['mobile']:'';
            // $temp['ratings'] = $ratings;
            // $street_address = '';
            // if($saloon['street_address'] != ''){
            //     $street_address = $saloon['street_address'];
            // }
            // $temp['street_address'] =  $street_address;
            // if(!empty($saloon['owner_image'])){
            //     $temp['owner_image'] = url('/uploads/profile_images/'.$saloon['owner_image']);                
            // }else{
            //     $temp['owner_image'] = '';
            // }
            // if(!empty($saloon['service_low_price'])){
            //     $temp['price'] = $saloon['service_low_price']['price'];                
            // }else{
            //     $temp['price'] = '';
            // }
            // if($saloon['instagram'] != ''){
            //     $temp['instagram'] = $saloon['instagram'];
            // }else{
            //     $temp['instagram'] = '';
            // }
            // if($saloon['facebook'] != ''){
            //     $temp['facebook'] = $saloon['facebook'];
            // }else{
            //     $temp['facebook'] = '';
            // }
            // if($saloon['twitter'] != ''){
            //     $temp['twitter'] = $saloon['twitter'];
            // }else{
            //     $temp['twitter'] = '';
            // }
            // if($saloon['latitude'] != ''){
            //     $temp['latitude'] = $saloon['latitude'];
            // }else{
            //     $temp['latitude'] = '';
            // }
            // if($saloon['logitude'] != ''){
            //     $temp['logitude'] = $saloon['logitude'];
            // }else{
            //     $temp['logitude'] = '';
            // }
            // $saloon_detail = $temp;
            $saloon_detail = $this->salon_data($saloon_id);
            $saloon_gallery = SaloonGallery::where("saloon_id",$saloon_id)->get();
            $images = array();
            /*foreach($saloon_gallery as $gallery){
                $images[] = url('/uploads/saloon_gallery/'.$gallery->image);
            }*/
            foreach($saloon_gallery as $gallery)
            {
                $images[] = array(
                    "salonimageid" => (string)$gallery->id,
                    "salon_image" => url('/uploads/saloon_gallery/'.$gallery->image)
                );
            }
            $response['salon'] = $saloon_detail;
            $response['salon_images'] = $images;
            $response['status'] = 'success';
            $response['message'] = 'Profile Edited Successfully';
        } catch (\Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function salon_data($id){
        // $saloon = Saloons::where("id",$id)->first();
        $saloon = Saloons::where("id",$id)->with("Country", "State", "City")->first();
        $saloon = $saloon->toArray();
        $temp = array();
        
        unset($saloon['last_login']);
        unset($saloon['api_token']);
        unset($saloon['created_by']);
        unset($saloon['updated_by']);
        unset($saloon['deleted_by']);
        unset($saloon['created_at']);
        unset($saloon['updated_at']);
        unset($saloon['deleted_at']);
        // unset($saloon['country_id']);
        // unset($saloon['city_id']);
        // unset($saloon['state_id']);
        unset($saloon['password']);
        $temp = $saloon;
        if(!empty($saloon['owner_image'])){
            $temp['owner_image'] = url('/uploads/profile_images/'.$saloon['owner_image']);                
        }else{
            $temp['owner_image'] = '';
        }
        $temp['salon_name'] = $saloon['saloon_name'];
        unset($temp['saloon_name']);
        unset($temp['id']);
        $temp['salon_id'] = $saloon['id'];
        $temp['open_time'] = ($saloon['open_time'] != NULL)?date("H:i",strtotime($saloon['open_time'])):'';
        $temp['close_time'] = ($saloon['close_time'] != NULL)?date("H:i",strtotime($saloon['close_time'])):'';
        $temp['salon_type'] = ($saloon['saloon_type'] != NULL)?$saloon['saloon_type']:'';
        $temp['contact_no'] =  ($saloon['mobile'] != NULL)?$saloon['mobile']:'';
        $street_address = '';
        if($saloon['street_address'] != ''){
            $street_address = $saloon['street_address'];
        }                
        $temp['street_address'] =  $street_address;
        if(!empty($saloon['owner_image'])){
            $temp['owner_image'] = url('/uploads/profile_images/'.$saloon['owner_image']);                
        }else{
            $temp['owner_image'] = '';
        }
        
        if($saloon['instagram'] != ''){
            $temp['instagram'] = $saloon['instagram'];
        }else{
            $temp['instagram'] = '';
        }
        if($saloon['facebook'] != ''){
            $temp['facebook'] = $saloon['facebook'];
        }else{
            $temp['facebook'] = '';
        }
        if($saloon['twitter'] != ''){
            $temp['twitter'] = $saloon['twitter'];
        }else{
            $temp['twitter'] = '';
        }
        if($saloon['latitude'] != ''){
            $temp['latitude'] = $saloon['latitude'];
        }else{
            $temp['latitude'] = '';
        }
        if($saloon['logitude'] != ''){
            $temp['logitude'] = $saloon['logitude'];
        }else{
            $temp['logitude'] = '';
        }
        $temp['country_id'] = "";
        $temp['country_name'] = "";
        if($saloon['country_id'] != '')
        {
            $temp['country_id'] = $saloon['country_id'];
            $temp['country_name'] = $saloon['country']['name'];
        }
        $temp['state_id'] = "";
        $temp['state_name'] = "";
        if($saloon['state_id'] != '')
        {
            $temp['state_id'] = $saloon['state_id'];
            $temp['state_name'] = $saloon['state']['name'];
        }
        $temp['city_id'] = "";
        $temp['city_name'] = "";
        if($saloon['city_id'] != '')
        {
            $temp['city_id'] = $saloon['city_id'];
            $temp['city_name'] = $saloon['city']['name'];
        }
        $temp['address_line_2'] = "";
        if($saloon['address_line_2'] != '')
        {
            $temp['address_line_2'] = $saloon['address_line_2'];
        }
        $temp['zipcode'] = "";
        if($saloon['zipcode'] != '')
        {
            $temp['zipcode'] = $saloon['zipcode'];
        }
        $temp['youtube_url'] = "";
        if($saloon['youtube_url'] != '')
        {
            $temp['youtube_url'] = $saloon['youtube_url'];
        }
        unset($temp['country']);
        unset($temp['state']);
        unset($temp['city']);
        if(empty($saloon['login_pin']))
        {
            $temp['is_loginpin'] = "N";
        }
        else
        {
            $temp['is_loginpin'] = "Y";
        }
        $saloon_detail = $temp;
        return $saloon_detail;
    }


    public function editSalon(Request $request){
        try{
            // echo "<pre>";
            // print_r($request->all());
            // echo "</pre>";
            // echo $request->input("salon_id");
            // exit;
            $object = Saloons::find($request->input("salon_id"));
            $validator = Validator::make($request->all(), [
                'salon_name' => 'required',
                'street_address' => 'required',
                'owner_image' => 'required',
                'open_time' => 'required',
                'close_time' => 'required',
            ]);
            $object->saloon_name = $request->input("salon_name");
            $object->salon_phone = $request->input("salon_phone");
            // $object->contact_person = $request->input("contact_person");
            $object->street_address = $request->input("street_address");
            $object->open_time = $request->input("open_time");
            $object->close_time = $request->input("close_time");
            // $object->bank_name = $request->input("bank_name");
            // $object->account_number = $request->input("account_number");
            // $object->ifsc_code = $request->input("ifsc_code");
            // $object->upi_id = $request->input("upi_id");
            // $object->saloon_type = $request->input("salon_type");
            if($request->input("latitude")){
                $object->latitude = $request->input("latitude");
            }
            if($request->input("logitude")){
                $object->logitude = $request->input("logitude");
            }
            if($request->input("instagram")){
                $object->instagram = $request->input("instagram");
            }
            if($request->input("facebook")){
                $object->facebook = $request->input("facebook");
            }
            if($request->input("twitter")){
                $object->twitter = $request->input("twitter");
            }
            if($request->input("owner_image")){
                if($object->owner_image != '' && file_exists('uploads/profile_images/'.$object->owner_image)){
                    unlink('uploads/profile_images/'.$object->owner_image);                    
                } 
                $image_64 = base64_decode($request->input("owner_image"));
                $f = finfo_open();
                $mime_type = finfo_buffer($f, $image_64, FILEINFO_MIME_TYPE);  
                $extensions = explode("/",$mime_type);
                $ext = end($extensions);
               
                $ci_fileName= time().'-'.rand(00000,99999).'.'.$ext;
                file_put_contents('uploads/profile_images/'.$ci_fileName,$image_64);    
                $object->owner_image = $ci_fileName;
            }
            if($request->input("country_id"))
            {
                $object->country_id = $request->input("country_id");
            }
            if($request->input("state_id"))
            {
                $object->state_id = $request->input("state_id");
            }
            if($request->input("city_id"))
            {
                $object->city_id = $request->input("city_id");
            }
            $object->address_line_2 = $request->input("address_line_2");
            $object->zipcode = $request->input("zipcode");
            $object->youtube_url = $request->input("youtube_url");
            $object->save();
            $saloon_id = $object->id;
            // $image_id_one = $request->input("image_id_1");
            // $image_id_two = $request->input("image_id_2");
            // $image_id_three = $request->input("image_id_3");
            if($request->input("salon_gallery_1"))
            {
                $image_64 = base64_decode($request->input("salon_gallery_1"));
                $f = finfo_open();
                $mime_type = finfo_buffer($f, $image_64, FILEINFO_MIME_TYPE);  
                $extensions = explode("/",$mime_type);
                $ext = end($extensions);
               
                $ci_fileName= time().'-'.rand(00000,99999).'.'.$ext;
                file_put_contents('uploads/saloon_gallery/'.$ci_fileName, $image_64);
                if(!(empty($request->input("image_id_1"))))
                {
                    // update image
                    $arr_update_image = array(
                        "image" => $ci_fileName,
                        "updated_at" => date("Y-m-d H:i:s")
                    );
                    SaloonGallery::where("id",$request->input("image_id_1"))->update($arr_update_image);
                }
                else
                {
                    $saloon_gallery = new SaloonGallery();
                    $saloon_gallery->saloon_id = $saloon_id;
                    $saloon_gallery->image = $ci_fileName;
                    $saloon_gallery->created_by = $saloon_id;
                    $saloon_gallery->save();
                }
            }
            if($request->input("salon_gallery_2"))
            {
                $image_64 = base64_decode($request->input("salon_gallery_2"));
                $f = finfo_open();
                $mime_type = finfo_buffer($f, $image_64, FILEINFO_MIME_TYPE);  
                $extensions = explode("/",$mime_type);
                $ext = end($extensions);
               
                $ci_fileName= time().'-'.rand(00000,99999).'.'.$ext;
                file_put_contents('uploads/saloon_gallery/'.$ci_fileName, $image_64);
                if(!(empty($request->input("image_id_2"))))
                {
                    // update image
                    $arr_update_image = array(
                        "image" => $ci_fileName,
                        "updated_at" => date("Y-m-d H:i:s")
                    );
                    SaloonGallery::where("id",$request->input("image_id_2"))->update($arr_update_image);
                }
                else
                {
                    $saloon_gallery = new SaloonGallery();
                    $saloon_gallery->saloon_id = $saloon_id;
                    $saloon_gallery->image = $ci_fileName;
                    $saloon_gallery->created_by = $saloon_id;
                    $saloon_gallery->save();
                }
            }
            if($request->input("salon_gallery_3"))
            {
                $image_64 = base64_decode($request->input("salon_gallery_3"));
                $f = finfo_open();
                $mime_type = finfo_buffer($f, $image_64, FILEINFO_MIME_TYPE);  
                $extensions = explode("/",$mime_type);
                $ext = end($extensions);
               
                $ci_fileName= time().'-'.rand(00000,99999).'.'.$ext;
                file_put_contents('uploads/saloon_gallery/'.$ci_fileName, $image_64);
                if(!(empty($request->input("image_id_3"))))
                {
                    // update image
                    $arr_update_image = array(
                        "image" => $ci_fileName,
                        "updated_at" => date("Y-m-d H:i:s")
                    );
                    SaloonGallery::where("id",$request->input("image_id_3"))->update($arr_update_image);
                }
                else
                {
                    $saloon_gallery = new SaloonGallery();
                    $saloon_gallery->saloon_id = $saloon_id;
                    $saloon_gallery->image = $ci_fileName;
                    $saloon_gallery->created_by = $saloon_id;
                    $saloon_gallery->save();
                }
            }
            /*if($request->input('salon_gallery'))
            {
                $sg_images   = $request->input('salon_gallery'); //your base64 encoded data
                for($i=0;$i < count($sg_images);$i++)
                {
                    $image_64 = base64_decode($sg_images[$i]);
                    $f = finfo_open();
                    $mime_type = finfo_buffer($f, $image_64, FILEINFO_MIME_TYPE);  
                    $extensions = explode("/",$mime_type);
                    $ext = end($extensions);
                   
                    $ci_fileName= time().'-'.rand(00000,99999).'.'.$ext;
                    file_put_contents(public_path('uploads/saloon_gallery/').$ci_fileName, $image_64);    
                    $saloon_gallery = new SaloonGallery();
                    $saloon_gallery->saloon_id = $saloon_id;
                    $saloon_gallery->image = $ci_fileName;
                    $saloon_gallery->created_by = $saloon_id;
                    $saloon_gallery->save();
                }
            }*/
            $saloon = Saloons::with(['FirstImage','Country','Ratings','State','City','ServiceLowPrice'])->where("id",$saloon_id)->first();
            if(count($saloon->Ratings) > 0){
                $ratings = $saloon->Ratings->avg("rating");
            }else{
                $ratings = 0;
            }
            $saloon = $saloon->toArray();
            // $temp = array();
            // $temp['salon_id'] = $saloon['id'];
            // $temp['salon_name'] = $saloon['saloon_name'];
            // $temp['open_time'] = ($saloon['open_time'] != NULL)?date("H:i",strtotime($saloon['open_time'])):'';
            // $temp['close_time'] = ($saloon['close_time'] != NULL)?date("H:i",strtotime($saloon['close_time'])):'';
            // $temp['salon_type'] = ($saloon['saloon_type'] != NULL)?$saloon['saloon_type']:'';
            // $temp['contact_no'] =  ($saloon['mobile'] != NULL)?$saloon['mobile']:'';
            // $temp['ratings'] = $ratings;
            // $street_address = '';
            // if($saloon['street_address'] != ''){
            //     $street_address = $saloon['street_address'];
            // }
            // $temp['street_address'] =  $street_address;
            // if(!empty($saloon['owner_image'])){
            //     $temp['owner_image'] = url('/uploads/profile_images/'.$saloon['owner_image']);                
            // }else{
            //     $temp['owner_image'] = '';
            // }
            // if(!empty($saloon['service_low_price'])){
            //     $temp['price'] = $saloon['service_low_price']['price'];                
            // }else{
            //     $temp['price'] = '';
            // }
            // if($saloon['instagram'] != ''){
            //     $temp['instagram'] = $saloon['instagram'];
            // }else{
            //     $temp['instagram'] = '';
            // }
            // if($saloon['facebook'] != ''){
            //     $temp['facebook'] = $saloon['facebook'];
            // }else{
            //     $temp['facebook'] = '';
            // }
            // if($saloon['twitter'] != ''){
            //     $temp['twitter'] = $saloon['twitter'];
            // }else{
            //     $temp['twitter'] = '';
            // }
            // if($saloon['latitude'] != ''){
            //     $temp['latitude'] = $saloon['latitude'];
            // }else{
            //     $temp['latitude'] = '';
            // }
            // if($saloon['logitude'] != ''){
            //     $temp['logitude'] = $saloon['logitude'];
            // }else{
            //     $temp['logitude'] = '';
            // }
            // $saloon_detail = $temp;
            $saloon_detail = $this->salon_data($saloon['id']);
            $saloon_gallery = SaloonGallery::where("saloon_id",$saloon_id)->get();
            $images = array();
            /*foreach($saloon_gallery as $gallery){
                $images[] = url('/uploads/saloon_gallery/'.$gallery->image);
            }*/
            foreach($saloon_gallery as $gallery)
            {
                $images[] = array(
                    "salonimageid" => (string)$gallery->id,
                    "salon_image" => url('/uploads/saloon_gallery/'.$gallery->image)
                );
            }
            $response['salon'] = $saloon_detail;
            // $response['salon_gallery'] = $images;
            $response['salon_images'] = $images;
            $response['status'] = 'success';
            $response['message'] = 'Salon edited successfully';
        } catch (\Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }


    // default services 


    public function getDefaultServices(Request $request)
    {
        try{
            $serviceRes = DefaultServices::where('is_active',1)->where('is_deleted',0)->orderBy('name','asc')->get();
            if(count($serviceRes) > 0)
            {
                $data = array();
                foreach($serviceRes as $key =>$value)
                {
                    $data[] = array(
                        'id'=>$value->id,
                        'service_name'=>$value->name,
                        'service_description'=>$value->description,
                        'price'=>number_format($value->price,2,'.',''),
                        'date'=>date('Y-m-d H:i:s',strtotime($value->created_at)),
                        'hours'=>$value->duration==null?"":date('H',strtotime($value->duration)),
                        'minutes'=>$value->duration==null?"":date('i',strtotime($value->duration)),
                    );
                }
                $response['data'] = $data;
                $response['status'] = 'success';
                $response['message'] = 'Success';
            }
            else{
                $response['status'] = 'error';
                $response['message'] = "No default services";
            }
        } catch (\Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }

        return response()->json($response);
    }


    public function addDefaultService(Request $request)
    {
        try{
            $validator = Validator::make($request->all(), [
                // 'service_id' => 'required',
                // 'saloon_id'=>"required",
                'service_name' => 'required',
                // 'service_description' => 'required',
                'price'=>"required"
            ]);

            if ($validator->fails())
            {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }

            $service_name = $request->input("service_name");
            $service_description = $request->input("service_description");
            $price = $request->input("price");
            $hours = $request->input('hours');
            $minutes = $request->input('minutes');
            //
            // New Add in barbers services
            $objectSaloonService = new DefaultServices();

            $objectSaloonService->name = $service_name;
            $objectSaloonService->description = $service_description;
            $objectSaloonService->price = $price;
            $objectSaloonService->created_at = date("Y-m-d H:i:s");
            $objectSaloonService->updated_at = date("Y-m-d H:i:s");
            $objectSaloonService->duration = $hours.":".$minutes.":00";
            $objectSaloonService->save();
            $newSaloonServiceId = $objectSaloonService->id;
            //
            $response['status'] = 'success';
            $response['message'] = "Default Service added successfully";
            $response['new_service_id'] = $newSaloonServiceId;
        } catch (\Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }


    public function addMultipleSaloonService(Request $request)
    {

        try{
            // $validator = Validator::make($request->all(), [
            //     'services'=>"required",
            // ]);

            // if ($validator->fails())
            // {
            //     $response['status'] = 'validation_error';
            //     $error = $validator->errors()->toArray();
            //     $errMsg = array();
            //     foreach($error as $key => $err){
            //         $errMsg[$key] = $err[0];
            //     }
            //     $response['message'] = $errMsg;
            //     return response()->json($response);
            // }
            $allData = $request->all();

            $services = $allData['services'];

            $servicesIds = array();

            if(!empty($services))
            {
                foreach($services as $key =>$value)
                {
                    $service_id = $value["service_id"];
                    $saloon_id = $value["saloon_id"];
                    $service_name = $value["service_name"];
                    $category_id = $value['category_id'];
                    $gender = $value['gender'];
                    $hours = $value['hours'];
                    $minutes = $value['minutes'];
                    if(isset($value["service_description"]))
                    {
                        $service_description = $value["service_description"];
                    }
                    else{
                        $service_description = "";
                    }
                    
                    $price = $value["price"];
                    //
                    // New Add in barbers services
                    $objectSaloonService = new SaloonServices();
                    $objectSaloonService->saloon_id = $saloon_id;
                    $objectSaloonService->service_id = $service_id;
                    $objectSaloonService->service_name = $service_name;
                    $objectSaloonService->service_description = $service_description;
                    $objectSaloonService->price = $price;
                    $objectSaloonService->category_id = $category_id;
                    $objectSaloonService->gender = $gender;
                    $objectSaloonService->duration = $hours.":".$minutes.":00";
                    $objectSaloonService->created_by = $saloon_id;
                    $objectSaloonService->updated_by = $saloon_id;
                    $objectSaloonService->created_at = date("Y-m-d H:i:s");
                    $objectSaloonService->updated_at = date("Y-m-d H:i:s");
                    $objectSaloonService->save();
                    $servicesIds[] = $objectSaloonService->id;

                    $barberRes = Barbers::select('id')->where('saloon_id',$saloon_id)->where('is_deleted',0)->get();
                    if(count($barberRes) > 0)
                    {
                        foreach($barberRes as $barber)
                        {

                            $object = new BarbersServices();

                            $object->saloon_id = $saloon_id;

                            $object->barber_id = $barber->id;

                            $object->service_id = $service_id;

                            $object->saloon_service_id = $objectSaloonService->id;

                            $object->service_name = $service_name;

                            $object->service_description = $service_description;

                            $object->price = $price;

                            $object->duration = $hours.":".$minutes.":00";

                            $object->created_by = $saloon_id;

                            $object->save();
                            
                        }
                    }
                }
            }
            
            
            //
            $response['status'] = 'success';
            $response['message'] = "Salon Service added successfully";
            $response['new_service_ids'] = $servicesIds;
        } catch (\Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }


    public function update_show_earning(Request $request)
    {
        $validator = Validator::make($request->all(),[
            'barber_id'=>'required',
            'value'=>'required',
        ]);

         if ($validator->fails()) {
            $response['status'] = 'validation_error';
            $response['message'] = CommonService::getValidationErrorMsg($validator);
            return response()->json($response);
         }

         $updatedata = array();

            $updatedata['show_earning'] = $request->input('value');
            Barbers::where('barbers.id',$request->input('barber_id'))->update($updatedata);


        $response['status'] = 'success';
        $response['message'] = 'Updated successfully';
        return response()->json($response,200);
    }


    public function update_manage_barber(Request $request)
    {
        $validator = Validator::make($request->all(),[
            'barber_id'=>'required',
            'value'=>'required',
        ]);

         if ($validator->fails()) {
            $response['status'] = 'validation_error';
            $response['message'] = CommonService::getValidationErrorMsg($validator);
            return response()->json($response);
         }

         $updatedata = array();

            $updatedata['manage_barber'] = $request->input('value');
            Barbers::where('barbers.id',$request->input('barber_id'))->update($updatedata);


        $response['status'] = 'success';
        $response['message'] = 'Updated successfully';
        return response()->json($response,200);
    }



    public function update_visibility(Request $request)
    {
        $validator = Validator::make($request->all(),[
            'barber_id'=>'required',
            'value'=>'required',
        ]);

         if ($validator->fails()) {
            $response['status'] = 'validation_error';
            $response['message'] = CommonService::getValidationErrorMsg($validator);
            return response()->json($response);
         }

         $updatedata = array();

            $updatedata['is_visible'] = $request->input('value');
            Barbers::where('barbers.id',$request->input('barber_id'))->update($updatedata);


        $response['status'] = 'success';
        $response['message'] = 'Updated successfully';
        return response()->json($response,200);
    }




    public function getBarberWeeklyIncome(Request $request){
        try{

            $validator = Validator::make($request->all(), [
                // 'service_id' => 'required',
                // 'saloon_id'=>"required",
                'month' => 'required',
                // 'service_description' => 'required',
                'barber_id'=>"required"
            ]);

            if ($validator->fails())
            {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            //format string
            $f = 'Y-m-d';
            $year = date('Y');
            $month = $request->input('month');


            //if you want to record time as well, then replace today() with now()
            //and remove startOfDay()

            $today = Carbon::createFromDate($year,$month,1);
            $date = $today->copy()->firstOfMonth()->startOfDay();
            $eom = $today->copy()->endOfMonth()->startOfDay();
            $date1 = Carbon::createFromDate($year,$month,1);
            
        
            $dates = [];

            // for($i = 1; $date->lte($eom); $i++){
                
            //     //record start date 
            //     $startDate = $date->copy();
                
            //     //loop to end of the week while not crossing the last date of month
            //     while($date->dayOfWeek != Carbon::SUNDAY && $date->lte($eom)){
            //             $date->addDay(); 
            //         }
                
            //     $dates[] = array('title'=>'Week '.$i,'start_date'=>$startDate->format($f),'end_date'=>$date->format($f));
            //     $date->addDay();
            // }

            $week = 1;

            for($i = 1; $date->lte($eom); $i++){

                if($date->startOfWeek(Carbon::MONDAY)->format('m') == $date1->format('m'))
                {

                    $dates[] = array('title'=>'Week '.$week,'start_date'=>$date->startOfWeek(Carbon::MONDAY)->format($f),'end_date'=>$date->endOfWeek(Carbon::SUNDAY)->format($f));
                    $week = $week+1;
    
                }
                $start = $date->startOfWeek(Carbon::MONDAY);
                $end = $date->endOfWeek(Carbon::SUNDAY);
    
                $date->addDays(1);
            }
            $barber_id = $request->input("barber_id");
            $barber = Barbers::select('id','name','mobile','profile_image','created_at')->where('id',$barber_id)->first();
            if(empty($barber)){
                $response['status'] = 'error';
                $response['message'] = 'Barber not exists';
                return response()->json($response);
            }

            $current_year = date("Y");
            $arr_total = array();
            foreach($dates as $key => $date)
            { 
                // $current_month = date("m", strtotime($array_month[$i]));
                //
                $month_earning = Bookings::where("barber_id",$barber_id)
                ->where("status","!=",'cancelled')  
                ->where("status","!=",'emergency cancellation')
                ->where("payment_status","=",'C')
                ->whereRaw("(action_type != 'R' OR action_type IS NULL)")
                ->where(function($q) use($date,$key,$dates){
                    // if($key != (count($dates)-1))
                    // {
                        // $q->whereBetween('book_date',[date('Y-m-d H:i:s',strtotime($date['start_date'])),date('Y-m-d H:i:s',strtotime($date['end_date']))]);
                        $q->where(DB::raw('DATE_FORMAT(book_date, "%Y-%m-%d")'),'>=',date('Y-m-d',strtotime($date['start_date'])))
                        ->where(DB::raw('DATE_FORMAT(book_date, "%Y-%m-%d")'),'<=',date('Y-m-d',strtotime($date['end_date'])));
                    // }
                    // else{
                    //     $q->where(DB::raw('DATE_FORMAT(book_date, "%Y-%m-%d")'),'>=',date('Y-m-d',strtotime($date['start_date'])))
                    //     ->where(DB::raw('DATE_FORMAT(book_date, "%Y-%m-%d")'),'<',date('Y-m-d',strtotime($date['end_date'])));
                    // }
                    
                })
                // ->whereMonth('book_date', $todayek)
                ->whereHas("Saloon")
                ->whereHas("Barber")
                ->whereHas("Customer")
                // ->orderBy("book_date","desc")
                ->sum("total");
                // $arr_total[] = $month_earning;
                if(!(empty($month_earning)))
                {
                    // if($key != (count($dates)-1))
                    // {
                        $arr_total[] = array("week" => $date['title'],'start_date'=>date('d M Y',strtotime($date['start_date'])),'end_date'=>date('d M Y',strtotime($date['end_date'])),'start_day'=>date('D',strtotime($date['start_date'])),'end_day'=>date('D',strtotime($date['end_date'])), "amount" => $month_earning);
                    // }
                    // else{
                    //     $arr_total[] = array("week" => $date['title'],'start_date'=>date('d M Y',strtotime($date['start_date'])),'end_date'=>date('d M Y',strtotime($date['end_date'] .'-1 day')),'start_day'=>date('D',strtotime($date['start_date'])),'end_day'=>date('D',strtotime($date['end_date'])), "amount" => $month_earning);
                    // }
                    
                }
                else
                {
                    // if($key != (count($dates)-1))
                    // {
                        $arr_total[] = array("week" => $date['title'],'start_date'=>date('d M Y',strtotime($date['start_date'])),'end_date'=>date('d M Y',strtotime($date['end_date'])),'start_day'=>date('D',strtotime($date['start_date'])),'end_day'=>date('D',strtotime($date['end_date'])), "amount" => "0");
                    // }
                    // else{
                    //     $arr_total[] = array("week" => $date['title'],'start_date'=>date('d M Y',strtotime($date['start_date'])),'end_date'=>date('d M Y',strtotime($date['end_date'] .'-1 day')),'start_day'=>date('D',strtotime($date['start_date'])),'end_day'=>date('D',strtotime($date['end_date'])), "amount" => "0");
                    // }
                }
            }
            $response['total'] = $arr_total;
            $response['status'] = 'success';
            $response['barber_register_date'] = date('Y-m-d',strtotime($barber->created_at));
        } catch (\Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function getSaloonWeeklyIncome(Request $request)
    {
        try
        {
            $validator = Validator::make($request->all(), [
                // 'service_id' => 'required',
                // 'saloon_id'=>"required",
                'month' => 'required',
                // 'service_description' => 'required',
                'saloon_id'=>"required"
            ]);

            if ($validator->fails())
            {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }

            //format string
            $f = 'Y-m-d';
            $year = date('Y');
            $month = $request->input('month');


            //if you want to record time as well, then replace today() with now()
            //and remove startOfDay()
            $today = Carbon::createFromDate($year,$month,1);
            $date = $today->copy()->firstOfMonth()->startOfDay();
            $eom = $today->copy()->endOfMonth()->startOfDay();
            $date1 = Carbon::createFromDate($year,$month,1);

            $dates = [];

            $week = 1;

            for($i = 1; $date->lte($eom); $i++){
                
                if($date->startOfWeek(Carbon::MONDAY)->format('m') == $date1->format('m'))
                {

                    $dates[] = array('title'=>'Week '.$week,'start_date'=>$date->startOfWeek(Carbon::MONDAY)->format($f),'end_date'=>$date->endOfWeek(Carbon::SUNDAY)->format($f));
                    $week = $week+1;
    
                }
                $start = $date->startOfWeek(Carbon::MONDAY);
                $end = $date->endOfWeek(Carbon::SUNDAY);
    
                $date->addDays(1);
            }


            $saloon_id = $request->input("saloon_id");
            $salon = Saloons::where("id",$saloon_id)->first();
            if(empty($salon)){
                $response['status'] = 'error';
                $response['message'] = 'Salon not exists';
            
                return response()->json($response);
            }
    
            $current_year = date("Y");
            $arr_total = array();
            foreach($dates as $key => $date)
            {
                //
                $month_earning = Bookings::where("saloon_id",$saloon_id)
                ->where("status","!=",'cancelled') 
                ->where("status","!=",'emergency cancellation') 
                ->where("payment_status","=",'C')
                ->whereRaw("(action_type != 'R' OR action_type IS NULL)")
                ->where(function($q) use($date,$key,$dates){
                    // if($key != (count($dates)-1))
                    // {
                        // $q->whereBetween('book_date',[date('Y-m-d H:i:s',strtotime($date['start_date'])),date('Y-m-d H:i:s',strtotime($date['end_date']))]);
                        $q->where(DB::raw('DATE_FORMAT(book_date, "%Y-%m-%d")'),'>=',date('Y-m-d',strtotime($date['start_date'])))
                        ->where(DB::raw('DATE_FORMAT(book_date, "%Y-%m-%d")'),'<=',date('Y-m-d',strtotime($date['end_date'])));
                    // }
                    // else{
                    //     $q->where(DB::raw('DATE_FORMAT(book_date, "%Y-%m-%d")'),'>=',date('Y-m-d',strtotime($date['start_date'])))
                    //     ->where(DB::raw('DATE_FORMAT(book_date, "%Y-%m-%d")'),'<',date('Y-m-d',strtotime($date['end_date'])));
                    // }
                    
                })
                ->whereHas("Saloon")
                ->whereHas("Barber")
                ->whereHas("Customer")
                ->orderBy("book_date","desc")
                ->sum("total");
                if(!(empty($month_earning)))
                {
                    // if($key != (count($dates)-1))
                    // {
                        $arr_total[] = array("week" => $date['title'],'start_date'=>date('d M Y',strtotime($date['start_date'])),'end_date'=>date('d M Y',strtotime($date['end_date'])),'start_day'=>date('D',strtotime($date['start_date'])),'end_day'=>date('D',strtotime($date['end_date'])), "amount" => $month_earning);
                    // }
                    // else{
                    //     $arr_total[] = array("week" => $date['title'],'start_date'=>date('d M Y',strtotime($date['start_date'])),'end_date'=>date('d M Y',strtotime($date['end_date'] .'-1 day')),'start_day'=>date('D',strtotime($date['start_date'])),'end_day'=>date('D',strtotime($date['end_date'] .'-1 day')), "amount" => $month_earning);
                    // }
                    
                }
                else
                {
                    // if($key != (count($dates)-1))
                    // {
                        $arr_total[] = array("week" => $date['title'],'start_date'=>date('d M Y',strtotime($date['start_date'])),'end_date'=>date('d M Y',strtotime($date['end_date'])),'start_day'=>date('D',strtotime($date['start_date'])),'end_day'=>date('D',strtotime($date['end_date'])), "amount" => "0");
                    // }
                    // else{
                    //     $arr_total[] = array("week" => $date['title'],'start_date'=>date('d M Y',strtotime($date['start_date'])),'end_date'=>date('d M Y',strtotime($date['end_date'] .'-1 day')),'start_day'=>date('D',strtotime($date['start_date'])),'end_day'=>date('D',strtotime($date['end_date'] .'-1 day')), "amount" => "0");
                    // }
                }
            }
            $response['total'] = $arr_total;
            $response['status'] = 'success';
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function phonepay_webhook(Request $request)
    {
       
        $data = $request->all();
        DB::table('phonepay_logs')->insert(['response'=>json_encode($data)]);
        $decodeRes = base64_decode(json_encode($data['response']));

        $json = json_decode($decodeRes);

        if($json->success)
        {
            if($json->code == "PAYMENT_SUCCESS")
            {
                $object = Bookings::find((int)$json->data->merchantTransactionId);
                $object->payment_status = "C";
                $object->payment_mode = $json->data->paymentInstrument->type;
                $object->transaction_id = $json->data->transactionId;
                $object->updated_at = date("Y-m-d H:i:s");
                $object->save();
                // For Sending notification
                $booking_services = BookingItems::with('Service')->with('SaloonService')->where("booking_id",$object->id)->get();
                $servicesname = array();
                foreach($booking_services as $serv)
                {
                    $servicesname[] = ((!empty($serv->SaloonService->service_name))?$serv->SaloonService->service_name:'');
                }
                //
                $barber = Barbers::where("id", $object->barber_id)->first();
                $customer = Customers::where("id",$object->customer_id)->first();
                $saloon = Saloons::where("id",$object->saloon_id)->first();

                $saloon_name = $saloon->saloon_name;
                $arr_email = array();
                $arr_sms = array();
                $arr_push = array();
                if(!(empty($customer)))
                {
                    // Get read unread notifiction count
                    $notificationReadInfo = Notification::select('id','fromid','toid','referenceid', 'notification_type', 'message', 'isread', 'created_at')
                    ->where("notification.toid", $customer['id'])
                    ->where("notification.notification_for", "C")
                    ->where("notification.isread", "N")
                    ->where("notification.is_deleted", 0)
                    ->get();
                    $readCount = $notificationReadInfo->count();
                    $notificationUnreadInfo = Notification::select('id','fromid','toid','referenceid', 'notification_type', 'message', 'isread', 'created_at')
                    ->where("notification.toid", $customer['id'])
                    ->where("notification.notification_for", "C")
                    ->where("notification.isread", "N")
                    ->where("notification.is_deleted", 0)
                    ->get();
                    $unreadCount = $notificationUnreadInfo->count();
                    //
                    $book_id = $object->id;
                    $date = date("d-m-Y",strtotime($object->book_date));
                    $startTime = date("h:i A",strtotime($object->from_time));
                    $endTime = $object->to_time;
                    $serviceName = implode(",", $servicesname);
                    $message = "Booking successful for ".$serviceName." at ".$saloon_name." on ".$date." ".$startTime;
                    
                    // echo $message; exit;
                    $arr_push = array();
                    $android_recepient = array();
                    $android_recepient[] = $customer['devicetoken'];         
                    $additionalData = array(
                        'notificationType' => 'booking',
                        'customerid' => $customer['id'],
                        'read' => $readCount,
                        'unread' => $unreadCount,
                    );
                    $arr_push = array(
                        "devicetype" => $customer['devicetype'], 
                        "registatoin_ids" => $android_recepient,
                        "message" => $message,
                        "additionalData" => $additionalData
                    );
                    // echo "<br/>Push<pre>";
                    // print_r($arr_push);
                    // echo "</pre>";
                    // exit;
                    if($customer['booking_notification'] == "Y")
                    {
                        $notification = new Notification();
                        $notification->sendAllNotification($arr_email, $arr_sms, $arr_push);
                    }
                    
                    //
                    $notificationsave = new Notification();
                    $notificationsave->fromid = $saloon['id'];
                    $notificationsave->toid = $customer['id'];
                    $notificationsave->referenceid = $book_id;
                    $notificationsave->notification_type = "Booking";
                    $notificationsave->message = $message;
                    $notificationsave->isread = "N";
                    $notificationsave->created_at = date("Y-m-d H:i:s");
                    $notificationsave->notification_for = "C";
                    $notificationsave->save();
                    $notificationId = $notificationsave->id;
                    // echo "<br/>Id = ".$notificationId;
                }

                if(!(empty($barber)))
                {
                    // Barber Notification
                    $book_id = $object->id;
                    $date = date("d-m-Y",strtotime($object->book_date));
                    $startTime = date("h:i A",strtotime($object->from_time));
                    $endTime = $object->to_time;
                    $serviceName = implode(",", $servicesname);
                    if($object->book_date == date('Y-m-d'))
                    {
                        $date = "Today";
                    }
                    else if($object->book_date == date('Y-m-d',strtotime('+1 day')))
                    {
                        $date = "Tomorrow";
                    }
                    else
                    {
                        $date = date('jS M l',strtotime($object->book_date));
                    }
                    $barberMessage = "You recieved a booking for ".$serviceName." at ".$startTime." ".$date;
                    $arr_email = array();
                    $arr_sms = array();
                    $arr_push = array();
                    // Get barber read unread notifiction count
                    $notificationReadInfo = Notification::select('id','fromid','toid','referenceid', 'notification_type', 'message', 'isread', 'created_at')
                    ->where("notification.toid", $barber['id'])
                    ->where("notification.notification_for", "B")
                    ->where("notification.isread", "N")
                    ->where("notification.is_deleted", 0)
                    ->get();
                    $readCount = $notificationReadInfo->count();
                    $notificationUnreadInfo = Notification::select('id','fromid','toid','referenceid', 'notification_type', 'message', 'isread', 'created_at')
                    ->where("notification.toid", $barber['id'])
                    ->where("notification.notification_for", "B")
                    ->where("notification.isread", "N")
                    ->where("notification.is_deleted", 0)
                    ->get();
                    $unreadCount = $notificationUnreadInfo->count();
                    //
                    $arr_push = array();
                    $android_recepient = array();
                    $android_recepient[] = $barber['devicetoken'];         
                    $additionalData = array(
                        'notificationType' => 'booking',
                        'barberid' => $barber['id'],
                        'read' => $readCount,
                        'unread' => $unreadCount,
                    );
                    $arr_push = array(
                        "devicetype" => $barber['devicetype'], 
                        "registatoin_ids" => $android_recepient,
                        "message" => $barberMessage,
                        "additionalData" => $additionalData
                    );
                    // echo "<br/>Push<pre>";
                    // print_r($arr_push);
                    // echo "</pre>";
                    // exit;
                    $notification = new Notification();
                    $notification->sendAllBarberNotification($arr_email, $arr_sms, $arr_push);
                    //
                    $barbernotificationsave = new Notification();
                    $barbernotificationsave->fromid = $saloon['id'];
                    $barbernotificationsave->toid = $barber['id'];
                    $barbernotificationsave->referenceid = $book_id;
                    $barbernotificationsave->notification_type = "Booking";
                    $barbernotificationsave->message = $barberMessage;
                    $barbernotificationsave->isread = "N";
                    $barbernotificationsave->created_at = date("Y-m-d H:i:s");
                    $barbernotificationsave->notification_for = "B";
                    $barbernotificationsave->save();
                    
                    //
                }
            }
            else if($json->code == "PAYMENT_ERROR")
            {
                $booking = Bookings::find((int)$json->data->merchantTransactionId);
                $booking->status = "cancelled";
                $booking->updated_at = date("Y-m-d H:i:s");
                $booking->cancelled_at = date("Y-m-d H:i:s");
                $booking->save();
            }
        }
    }

    public function phonepay_test_api(Request $request)
    {
        $data = array(
            'mobile'=>'919923142516',
            'amount'=>5,
            'order_id'=>time(),
            'user_id'=>'1001',
            'target_app'=>$request->target_app
        );

        $phonepayRes = PhonepayService::create_phonepay_testpayment_url($data);

        if($phonepayRes['status'] == "S")
        {
            $response['status'] = "success";
            $response['payment_url']=$phonepayRes['url'];
            $response['merchant_id']=$phonepayRes['merchant_id'];
        }
        else{
            $response['status'] = "error";
        }

        return response()->json($response,200);
    }


    public function logoutBarber(Request $request)
    {
        try
        {
            $validator = Validator::make($request->all(), [
                'barber_id'=>"required"
            ]);

            if ($validator->fails())
            {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }

            Barbers::where('id',$request->barber_id)->update(['devicetoken'=>'']);

            $response['status'] = 'success';
            $response['message'] = "Successfully logout barber";

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }


    public function test_notification(Request $request)
    {
        $arr_push = array();
        $android_recepient = array();
        $android_recepient[] = $request->devicetoken;
        $additionalData = array(
            'notificationType' => 'Test',
        );
        $arr_push = array(
            "devicetype" => "A", 
            "registatoin_ids" => $android_recepient,
            "message" => "Test notification hghgh",
            "additionalData" => $additionalData
        );

        $fcmservice = new FCMService();
        
        $response = $fcmservice->sendNotification($request->devicetoken,"Test notification", "Test Notification using goolge client", $additionalData);

        print_r($response);
    }

    public function test_message(Request $request)
    {
        $res = CommonService::send_msg($request->mobile,$request->message);

        print_r($res);
    }

}
