<?php

namespace App\Http\Controllers\Webservices;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Validator;

use App\Customers;
use App\Saloons;
use App\SaloonServices;
use App\Services;
use App\Barbers;
use App\Bookings;
use App\BookingItems;
use App\Ratings;
use App\BarberSchedule;
use App\BarberBreak;
use App\ApiRequest;
use App\Notification;

class CustomersController extends Controller
{
    public function __construct()
    {
        header('Access-Control-Allow-Origin: *');
        header('Access-Control-Allow-Methods: GET, PUT, POST, DELETE, OPTIONS');
        header("Content-Type: application/json");
    }

    public function loginAsCustomer(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'mobile' => 'required',
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $response['login'] = false;
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $mobile = $request->input("mobile");
            // $user = Customers::select('id','name','email','mobile')->where("mobile",$mobile)->first();
            $user = Customers::where('mobile',$mobile)->first();
            $readCount = 0;
            $unreadCount = 0;
            if(!(empty($user)))
            {
                // Get read unread notifiction count
                $notificationReadInfo = Notification::select('id','fromid','toid','referenceid', 'notification_type', 'message', 'isread', 'created_at')
                ->where("notification.toid", $user->id)
                ->where("notification.isread", "Y")
                ->where("notification.is_deleted", 0)
                ->get();
                $readCount = $notificationReadInfo->count();
                $notificationUnreadInfo = Notification::select('id','fromid','toid','referenceid', 'notification_type', 'message', 'isread', 'created_at')
                ->where("notification.toid", $user->id)
                ->where("notification.isread", "N")
                ->where("notification.is_deleted", 0)
                ->get();
                $unreadCount = $notificationUnreadInfo->count();
                //
                $data = Customers::find($user->id);
                $data->devicetype = $request->input("devicetype");
                $data->devicetoken = $request->input("devicetoken");
                $data->save();
                //
                $user = Customers::select('id', 'name', 'email', 'mobile', 'profileimage', 'devicetype', 'devicetoken')->where("id",$user->id)->first();
                if(!(empty($user)))
                {
                    $user = array(
                        "id" => $user['id'],
                        "name" => $user['name'],
                        "email" => $user['email'],
                        "mobile" => $user['mobile'],
                        "profileimage" => $user['profileimage'],
                        "devicetype" => $this->render($user['devicetype']),
                        "devicetoken" => $this->render($user['devicetoken']),
                        "unread" => $unreadCount
                    );
                }
            }
            // echo "<pre>";
            // print_r($user);
            // echo "</pre>";
            // exit;
            if(empty($user)){
                $response['status'] = 'error';
                $response['login'] = false;
                $response['message'] = 'Invalid mobile no';
                return response()->json($response);
            }else{                
                $response['status'] = 'success';
                $response['login'] = true;
                $response['message'] = 'Login success';
                $response['user'] = $user;
            }
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function customerRegister(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'name' => 'required',
                'email' => 'required|email|unique:customers',
                'mobile' => 'required|unique:customers'
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }

            $object = new Customers();
            $object->name = $request->input("name");
            $object->email = $request->input("email");
            $object->mobile = $request->input("mobile");
            $object->status = 1;
            $object->devicetype = $request->input("devicetype");
            $object->devicetoken = $request->input("devicetoken");
            $object->save();
            $id = $object->id;
            $user = Customers::select('id', 'name', 'email', 'mobile', 'profileimage')->where("id",$id)
                            ->first();
            $response['status'] = 'success';
            $response['message'] = 'Register success';
            $response['user'] = $user;

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
    
    /*public function editProfile(Request $request){
        try{
            $object = Customers::find($request->input("customer_id"));
            $validator = Validator::make($request->all(), [
                'customer_id' => 'required',
                'name' => 'required',
                'email' => 'required|email|unique:customers,email,'.$object->id,
                'mobile' => 'required|unique:customers,mobile,'.$object->id,
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }

            
            $object->name = $request->input("name");
            $object->email = $request->input("email");
            $object->mobile = $request->input("mobile");
            $object->status = 1;
            $object->save();
            $id = $object->id;
            $user = Customers::select('id','name','email','mobile')->where("id",$id)
                            ->first();
            $response['status'] = 'success';
            $response['message'] = 'Customer profile edited successfully';
            $response['user'] = $user;

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }*/
    
    public function getTimeSlot(Request $request){
        try{
            
            // $requestData  = json_encode($request->all());
            // $object = new ApiRequest();
            // $object->request_data = $requestData;
            // $object->save();

            $saloon_id = $request->input("saloon_id"); // updated by mustak
            $barber_id = $request->input("barber_id");
            $date = $request->input("book_date");
            $service_ids = $request->input("services");
            $service_time = SaloonServices::whereIn("id",$service_ids)->sum(\DB::raw("TIME_TO_SEC(duration)"));
            $service_time = (int)$service_time;
            $saloon = Saloons::where("id",$saloon_id)->first();
            // $sl_start_time = $saloon->open_time;
            // $sl_close_time = $saloon->close_time;

            $barber_schedule = BarberSchedule::where("schedule_date",$date)->where('barber_id',$barber_id)->first();
            if(empty($barber_schedule)){
                $response['status'] = 'error';
                $response['message'] = "Barber not available for the day";
                return response()->json($response);
            }            
            $sl_start_time = $barber_schedule->from_time;
            $sl_close_time = $barber_schedule->to_time;

            $minutes = $service_time/60;
            $starttime = date("Y-m-d H:i",strtotime($date." ".$sl_start_time));
            $endtime = date("Y-m-d H:i",strtotime($date." ".$sl_close_time));
           
            $array_of_time = array ();
            $start_time    = strtotime ($starttime); //change to strtotime
            $end_time      = strtotime ($endtime); //change to strtotime

            $add_mins  = $minutes * 60;
            // echo $add_mins;
            $bookings = Bookings::where("book_date",$date)
                                    ->whereHas("Saloon")
                                   ->whereHas("Barber")
                                   ->where("saloon_id",$saloon_id)
                                   ->where("barber_id",$barber_id)
                                   ->where("status","!=",'cancelled')                                   
                                   ->orderBy("from_time","asc")
                                   ->get(); 
            // pre($booked_slot->toArray());
            $available_time = array();
            $times = array();
            $prev_endtime = array();
            // pre($sl_start_time);
            // pre($sl_close_time);
            // echo "<hr>";
            $booked_slot = array();
            foreach($bookings as $slot){
                $temp = new \stdClass();
                $temp->from_time = $slot->from_time;
                $temp->to_time = $slot->to_time;
                $booked_slot[] = $temp;
            }

            $barber_break = BarberBreak::where("break_date",$date)->where('barber_id',$barber_id)->get();
            foreach($barber_break as $slot){
                $temp = new \stdClass();
                $temp->from_time = $slot->from_time;
                $temp->to_time = $slot->to_time;
                $booked_slot[] = $temp;
            }
            asort($booked_slot);
        
            $booked_slot = array_values($booked_slot);
            foreach($booked_slot as $key => $slot){
                // echo "<pre>";
                // print_r($slot);
                // echo "</pre>";
                if($key == 0){
                    $start_time = date("Y-m-d H:i",strtotime($date." ".$sl_start_time));
                    // echo "<br/>Start". $start_time."<br/>";
                    $end_time = date("Y-m-d H:i",strtotime($date." ".$slot->from_time));
                    // echo "<br/>End". $end_time."<br/>";
                    $prev_endtime[$key] = $slot->to_time;
                    // echo "<pre>";
                    // print_r($prev_endtime);
                    // echo "</pre>";
                    $starttime = strtotime($start_time);
                    $endtime = strtotime($end_time);
                    $valid = 1;
                    
                    $time_slots = $this->timeSlot($starttime,$endtime,$add_mins);
                    $array_of_time = array_merge($array_of_time,$time_slots);
                    // echo "<pre>";
                    // print_r($array_of_time);
                    // echo "</pre>";
                    // exit;                    
                }else{
                    
                    $start_time = date("Y-m-d H:i",strtotime($date." ".$prev_endtime[$key-1]));
                    $end_time = date("Y-m-d H:i",strtotime($date." ".$slot->from_time));

                    $prev_endtime[$key] = $slot->to_time;

                    $starttime = strtotime($start_time);
                    $endtime = strtotime($end_time);

                    $time_slots = $this->timeSlot($starttime,$endtime,$add_mins);
                    $array_of_time = array_merge($array_of_time,$time_slots);
                    
                }
            }
            if(count($booked_slot) > 0){
                $start_time = date("Y-m-d H:i",strtotime($date." ".end($prev_endtime)));
                $end_time = date("Y-m-d H:i",strtotime($date." ".$sl_close_time));
            }else{
                $start_time = date("Y-m-d H:i",strtotime($date." ".$sl_start_time));
                $end_time = date("Y-m-d H:i",strtotime($date." ".$sl_close_time));
            }
            // echo $start_time." - ".$end_time;
            // exit;
            $starttime = strtotime($start_time);
            $endtime = strtotime($end_time);

            $time_slots = $this->timeSlot($starttime,$endtime,$add_mins);
            // echo "<pre>";
            // print_r($time_slots);
            // echo "</pre>";
            // exit; 
            $array_of_time = array_merge($array_of_time,$time_slots);
            // echo "<pre>";
            // print_r($array_of_time);
            // echo "</pre>";
            // exit; 
            $array_of_time = array_values(array_unique($array_of_time));
            // echo "<pre>";
            // print_r($array_of_time);
            // echo "</pre>";
            // exit; 
            $available_time = array();
            for($i=0;$i < count($array_of_time);$i++){
                if(isset($array_of_time[$i+1])){
                    $to_time=strtotime($array_of_time[$i+1]);
                    // echo $array_of_time[$i]." to ".$array_of_time[$i+1]."<Br>";
                    $from_time=strtotime($array_of_time[$i]); 
                    $time = array("start_time"=>$array_of_time[$i],"end_time"=>$array_of_time[$i+1]);
                  
                    $checkTime = Bookings::where("saloon_id",$saloon_id)
                                   ->where("barber_id",$barber_id)
                                   ->whereDate("book_date",$date)
                                   ->where("status","!=",'cancelled') 
                                   ->whereHas("Saloon")
                                   ->whereHas("Barber")
                                   ->orderBy("from_time","asc")
                                   ->get(); 
                    // echo "<Br>".$checkTime;
                    // echo "<pre>";
                    // print_r($checkTime);
                    // echo "</pre>";
                    // exit;
                    $is_valid = 1;
                    foreach($checkTime as $ctime){
                         $f_time =strtotime($ctime->from_time);
                         $t_time =strtotime($ctime->to_time);
                         // echo $to_time."<br/>";
                         // echo $f_time."<br/>";
                         // echo $t_time."<br/>";
                         if($to_time > $f_time && $to_time <= $t_time){
                            $is_valid = 0;
                         }
                    }
                    // echo $is_valid;
                    // exit;
                    // if($checkTime > 0){
                    //     $is_valid = 0;
                    // }

                    $checkTime = BarberBreak::where("barber_id",$barber_id)
                                   ->whereDate("break_date",$date)
                                   ->get(); 
                    // echo "<pre>";
                    // print_r($checkTime);
                    // echo "</pre>";
                    // exit;
                    foreach($checkTime as $ctime){
                         $f_time =strtotime($ctime->from_time);
                         $t_time =strtotime($ctime->to_time);
                         if($to_time > $f_time && $to_time < $t_time){
                            $is_valid = 0;
                         }
                    }
                    // if($checkTime > 0){
                    //     $is_valid = 0;
                    // }
                    if($is_valid == 1){
                        $diff = round(abs($to_time - $from_time) / 60,2);
                        if($diff == $minutes){
                            $available_time[] = array("start_time"=>$array_of_time[$i],"end_time"=>$array_of_time[$i+1]);
                        }
                    }
                    
                }
            }
            $response['status'] = 'success';
            $response['minutes'] = $minutes;
            $response['available_time'] = $available_time;

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function timeSlot($start_time,$end_time,$add_mins){
        $array_of_time = array();
        // echo $start_time."<br/>";
        // echo $end_time;
        while ($start_time <= $end_time) // loop between time
        {
           $array_of_time[] = date("H:i", $start_time);
           $start_time += $add_mins; // to check endtie=me
        }
        // echo "<pre>";
        // print_r($start_time);
        // print_r($end_time);
        // print_r($add_mins);
        // print_r($array_of_time);
        // echo "</pre>";
        // exit;
        return $array_of_time;

    }

    public function bookService(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'salon_id' => 'required',
                'barber_id' => 'required',
                'customer_id' => 'required',
                'book_date' => 'required',
                'services' => 'required',
                'booked_time' => 'required'
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $saloon_id = $request->input("salon_id");
            $barber_id = $request->input("barber_id");
            $customer_id = $request->input("customer_id");
            $date = $request->input("book_date");
            $service_ids = $request->input("services");
            $booked_time = $request->input("booked_time");
            //
            $checkBooking = Bookings::where("book_date",$date)
            ->where("status","!=",'cancelled') 
            ->where("from_time",">=",$booked_time['start_time'])
            ->where("to_time","<=",$booked_time['end_time'])
            ->where("barber_id",$barber_id)
            ->count();
            // echo "<pre>";
            // print_r($checkBooking);
            // echo "</pre>";
            // exit;
            if($checkBooking > 0){
                $response['status'] = 'error';
                $response['message'] = 'Time Slot already booked';
                return response()->json($response);
            }
            $customer = Customers::where("id",$customer_id)->first();
            $total_price = SaloonServices::whereIn("id",$service_ids)->sum("price");
            $services = SaloonServices::whereIn("id",$service_ids)->get();

            $object = new Bookings();
            $object->saloon_id = $saloon_id;
            $object->barber_id = $barber_id;
            $object->customer_id = $customer_id;
            $object->book_date = $date;
            $object->total = $total_price;
            $object->from_time = $booked_time['start_time'];
            $object->to_time = $booked_time['end_time'];
            $object->book_number = mt_rand(100000,999999);
            $object->transaction_id = mt_rand(100000,999999);
            $object->billing_name = $customer->name;
            $object->billing_mobile = $customer->mobile;
            $object->billing_email = $customer->email;
            $object->created_by = $customer_id;
            $object->save();
            $book_id  = $object->id;
            foreach($services as $service){
                $newobj = new BookingItems();
                $newobj->booking_id = $book_id;
                $newobj->service_id = $service->service_id;
                $newobj->main_service_id = $service->id;
                $newobj->price = $service->price;
                $newobj->save();
            } 
            $booking = Bookings::select("id","book_number","book_date","from_time","to_time","total","billing_name","billing_email","billing_mobile")
                            ->where("id",$book_id)
                            ->first();
            // echo "<pre>";
            // print_r($booking);
            // echo "</pre>";
            // exit;
            $booking_services = BookingItems::with('Service')->where("booking_id",$book_id)->get();
            $services = array();
            $servicesname = array();
            foreach($booking_services as $serv){
                $temp['service_name'] = (!empty($serv->Service->name))?$serv->Service->name:'';
                $temp['service_price'] = $serv->price;
                $services[] = $temp;
                //
                $servicesname[] = ((!empty($serv->Service->name))?$serv->Service->name:'');
            }
            $saloon = Saloons::where("id",$saloon_id)->first();
            //
            $arr_email = array();
            $arr_sms = array();
            $arr_push = array();
            //
            if(!(empty($customer)))
            {
                // Get read unread notifiction count
                $notificationReadInfo = Notification::select('id','fromid','toid','referenceid', 'notification_type', 'message', 'isread', 'created_at')
                ->where("notification.toid", $customer['id'])
                ->where("notification.isread", "Y")
                ->where("notification.is_deleted", 0)
                ->get();
                $readCount = $notificationReadInfo->count();
                $notificationUnreadInfo = Notification::select('id','fromid','toid','referenceid', 'notification_type', 'message', 'isread', 'created_at')
                ->where("notification.toid", $customer['id'])
                ->where("notification.isread", "N")
                ->where("notification.is_deleted", 0)
                ->get();
                $unreadCount = $notificationUnreadInfo->count();
                //
                $serviceName = implode(",", $servicesname);
                $message = "Your booking for ".$serviceName." on ".$date." at ".$booked_time['start_time']."-".$booked_time['end_time']." for salooon ".$saloon['saloon_name']." booked successfully.";
                // echo $message; exit;
                $arr_push = array();
                $android_recepient = array();
                $android_recepient[] = $customer['devicetoken'];         
                $additionalData = array(
                    'notificationType' => 'booking',
                    'customerid' => $customer['id'],
                    'read' => $readCount,
                    'unread' => $unreadCount,
                );
                $arr_push = array(
                    "devicetype" => $customer['devicetype'], 
                    "registatoin_ids" => $android_recepient,
                    "message" => $message,
                    "additionalData" => $additionalData
                );
                // echo "<br/>Push<pre>";
                // print_r($arr_push);
                // echo "</pre>";
                // exit;
                $notification = new Notification();
                $notification->sendAllNotification($arr_email, $arr_sms, $arr_push);
                //
                $notificationsave = new Notification();
                $notificationsave->fromid = $saloon_id;
                $notificationsave->toid = $customer['id'];
                $notificationsave->referenceid = $book_id;
                $notificationsave->notification_type = "Booking";
                $notificationsave->message = $message;
                $notificationsave->isread = "N";
                $notificationsave->created_at = date("Y-m-d H:i:s");
                $notificationsave->save();
                $notificationId = $notificationsave->id;
                // echo "<br/>Id = ".$notificationId;
            }
            $response['status'] = "success";
            $response['booking'] = $booking;
            $response['services'] = $services;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function customerBookings(Request $request){
        try{
            $customer_id = $request->input("customer_id");
            $bookings = Bookings::where("customer_id",$customer_id)
                                ->whereHas("Saloon")
                                ->whereHas("Barber")
                                ->orderBy("book_date","desc")->get();
            $bookingList = array();
            foreach($bookings as $booking){
                $temp = array();
                $temp['id'] = $booking->id;
                $temp['book_date'] = dateFormat($booking->book_date,"d-m-Y");
                $temp['salon_name'] = $booking->Saloon->saloon_name;
                $temp['salon_id'] = $booking->saloon_id;
                $temp['barber_name'] = $booking->Barber->name;
                $temp['barber_id'] = $booking->barber_id;
                $temp['book_number'] = $booking->book_number;
                $temp['from_time'] = $booking->from_time;
                $temp['to_time'] = $booking->to_time;
                $temp['total_price'] = $booking->total;
                $temp['transaction_id'] = $booking->transaction_id;
                $temp['billing_name'] = $booking->billing_name;
                $temp['billing_mobile'] = $booking->billing_mobile;
                $temp['billing_email'] = $booking->billing_email;
                $date = $booking->book_date." ".$booking->to_time;
                $current_date = date("Y-m-d H:i:s");

                if($date > $current_date){
                    $temp['status'] = 'Upcoming';
                }else{
                    $temp['status'] = 'Completed';
                }

                if($booking->status == 'cancelled'){
                    $temp['status'] = 'Cancelled';
                }

                $booking_services = BookingItems::with('Service')->where("booking_id",$booking->id)->get();
                $services = array();
                foreach($booking_services as $serv){
                    $temp['service_name'] = $serv->SaloonService->service_name;
                    $temp['service_price'] = $serv->price;
                    $services[] = $temp;
                }
                $temp['services'] = $services;

                $bookingList[] = $temp;
            }
            $response['status'] = 'success';
            $response['booking_list'] = $bookingList;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
    
    public function barberRating(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'barber_id' => 'required',
                'rating' => 'required'
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $barber_id = $request->input("barber_id");
            $barber = Barbers::where("id",$barber_id)->first();
            $object = new Ratings();
            $object->barber_id = $barber_id;
            $object->saloon_id = $barber->saloon_id;
            $object->rating = $request->input("rating");
            $object->customer_id = $request->input("customer_id");
            $object->save();

            $response['status'] = 'success';
            $response['message'] = 'Barber rated successfully';

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    // Added New functions

    public function render($value)
    {
        if($value === null)
        {
            $value = '';
        }
        return $value;
    }

    public function customerSocialRegister(Request $request)
    {
        try{
            $validator = Validator::make($request->all(), [
                'logintype' => 'required',
                'socialmediaid' => 'required'
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            else
            {
                $logintype = $request->input("logintype");
                $socialmediaid = $request->input("socialmediaid");
                $email = $request->input("email");
                $newUse = "Y";
                $isRecordExists = Customers::select('id','logintype', 'profileimage')
                ->where("logintype", $logintype)
                ->where("socialmediaid", $socialmediaid)
                ->first();
                $memberid = 0;
                if(!(empty($isRecordExists)))
                {
                    $newUse = "N";
                    $memberid = $isRecordExists['id'];
                    $isEmailExists = Customers::select('id','logintype')
                    ->where("id", "!=" ,$memberid)
                    ->where("email", $email)
                    ->get();
                    // echo "<pre>";
                    // print_r($isEmailExists);
                    // echo "</pre>";
                    // exit;
                    if(count($isEmailExists) > 0)
                    {
                        $response['status'] = 'error';
                        $response['message'] = "Account with same email already exists. Try again.";
                        return response()->json($response);
                    }
                    else
                    {
                        // update existing record
                        // echo $isRecordExists['id'];
                        // echo "<pre>";
                        // print_r($isRecordExists);
                        // echo "</pre>";
                        // exit;
                        $profileimage = $request->input('profileimage');
                        if(!(empty($isRecordExists['profileimage'])))
                        {
                            $profileimage = $isRecordExists['profileimage'];
                        }
                        $updateMemberData = array(
                            'username' => $request->input('username'),
                            'logintype' => $request->input('logintype'),
                            'profileimage' => $profileimage,
                            'socialmediaid' => $request->input('socialmediaid'),
                            'gender' => $request->input('gender'),
                            'ipaddress' => $_SERVER['REMOTE_ADDR'],
                            'devicetype' => $request->input('devicetype'),
                            'devicetoken' => $request->input('devicetoken'),
                            'updated_by' => $isRecordExists['id'],
                            'updated_at' => date('Y-m-d H:i:s')
                        );
                        Customers::where("id", $isRecordExists['id'])
                        ->update($updateMemberData);
                    }
                }
                else
                {
                    $isEmailExists = Customers::select("id", "logintype")
                    ->where("email", $email)->get();
                    // echo "<pre>";
                    // print_r($isEmailExists);
                    // echo "</pre>";
                    // exit;
                    if(count($isEmailExists) > 0)
                    {
                        $response['status'] = 'error';
                        $response['message'] = "Account with same email already exists. Try again.";
                        // echo json_encode($response);
                    }
                    else
                    {
                        //
                        $newUse = "Y";
                        
                        $name = $request->input('name');
                        if(empty($name))
                        {
                            $name = "";
                        }
                        $email = $request->input('email');
                        if(empty($name))
                        {
                            $email = "";
                        }
                        
                        // insert new record
                        $customerObj = new Customers();
                        $customerObj->name = $name;
                        $customerObj->username = $request->input('username');
                        $customerObj->email = $email;
                        $customerObj->logintype = $request->input('logintype');
                        $customerObj->profileimage = $request->input('profileimage');
                        $customerObj->socialmediaid = $request->input('socialmediaid');
                        $customerObj->gender = $request->input('gender');
                        $customerObj->ipaddress = $_SERVER['REMOTE_ADDR'];
                        $customerObj->devicetype = $request->input('devicetype');
                        $customerObj->devicetoken = $request->input('devicetoken');
                        $customerObj->created_at = date('Y-m-d H:i:s');
                        $customerObj->updated_at = date('Y-m-d H:i:s');
                        $customerObj->save();
                        $memberId = $customerObj->id;
                        // Updating token in table for new signup user
                        $updateMemberData = array(
                        'created_by' => $memberId,
                        'updated_by' => $memberId,
                        );
                        Customers::where("id", $memberId)
                        ->update($updateMemberData);
                        $memberid = $memberId;
                        // Registration welcome email
                        // $keyvalues = array(
                        // "{{username}}" => $firstname." ".$lastname
                        // );
                        // $templateslug = "email_welcome";
                        // $toemail = $email;
                        // $arr_email = $this->notification_model->getEmailTemplate($keyvalues, $templateslug, $toemail, $tocc=null, $tobcc=null);
                        // //
                        // $this->notification_model->sendAllNotification($arr_email,array(), array());
                    }
                }

                $arr_data = array();
                if($memberid > 0)
                {
                    $userData = Customers::select("id", "name", "email", "mobile", "logintype", "profileimage", "socialmediaid", "gender", "devicetype", "devicetoken")
                    ->where("id", $memberid)
                    ->get();
                    // echo "<pre>";
                    // print_r($userData);
                    // echo "</pre>";
                    // exit;
                    if (!(empty($userData)))
                    {
                        $arr_data[] = array(
                            'id' => (string)$memberid,
                            'name' => $this->render($userData[0]['name']),
                            'email' => $userData[0]['email'],
                            'mobile' => $userData[0]['mobile'],
                            'logintype' => $userData[0]['logintype'],
                            'profileimage' => $this->render($userData[0]['profileimage']),
                            'socialmediaid' => $userData[0]['socialmediaid'],
                            'gender' => $userData[0]['gender'],
                            'devicetype' => $this->render($userData[0]['devicetype']),
                            'devicetoken' => $this->render($userData[0]['devicetoken']),
                            'newuse' => $newUse
                        );
                        $response['status'] = 'success';
                        $response['message'] = "You have successfully registered.";
                        $response['data'] = $arr_data;
                        return response()->json($response);
                    }
                    else
                    {
                        $response['status'] = 'error';
                        $response['message'] = "Invalid user.";
                        $response['data'] = $arr_data;
                        // echo json_encode($response);
                    }
                }
            }

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function customerChecklogin(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'socialmediaid' => 'required',
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $arr_data = array();
            $userInfo = Customers::select("id", "name", "username", "email", "mobile", "logintype", "profileimage", "socialmediaid", "ipaddress", "gender", "devicetype", "devicetoken")
                ->where("customers.socialmediaid", $request->input('socialmediaid'))
                ->get();
            if (!(empty($userInfo)))
            {
                $arr_data[] = array(
                    'id' => (string)$userInfo[0]['id'],
                    'name' => $userInfo[0]['name'],
                    'email' => $userInfo[0]['email'],
                    'mobile' => $userInfo[0]['mobile'],
                    'logintype' => $userInfo[0]['logintype'],
                    'profileimage' => $this->render($userInfo[0]['profileimage']),
                    'socialmediaid' => $userInfo[0]['socialmediaid'],
                    'gender' => $userInfo[0]['gender'],
                    'devicetype' => $this->render($userInfo[0]['devicetype']),
                    'devicetoken' => $this->render($userInfo[0]['devicetoken']),
                );
                $response['status'] = 'success';
                $response['message'] = "Record found successfully.";
                $response['data'] = $arr_data;
                // echo json_encode($response);
            }
            else
            {
                $response['status']='error';
                $response['message']="Record not found.";
                // echo json_encode($response);
            }

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function editProfile(Request $request){
        try{
            $object = Customers::find($request->input("customer_id"));
            $validator = Validator::make($request->all(), [
                'customer_id' => 'required',
                'name' => 'required',
                'email' => 'required|email|unique:customers,email,'.$object->id,
                // 'photo' => 'required',
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }

            
            $object->name = $request->input("name");
            $object->email = $request->input("email");
            if($request->hasFile("photo"))
            {
                $path = $request->file('photo')->storeAs('customer_profileimage',$request->file('photo')->getClientOriginalName(),'uploadscustomer');
                $object->profileimage = url('public/uploads/customer_profileimage/'.$request->file('photo')->getClientOriginalName());
            }
            $object->status = 1;
            $object->save();
            $id = $object->id;
            $user = Customers::select('id','name','email','profileimage')->where("id",$id)
            ->first();
            //
            // $user['profileimage'] = url('public/uploads/customer_profileimage/'.$user['profileimage']);
            $response['status'] = 'success';
            $response['message'] = 'Customer profile edited successfully';
            $response['user'] = $user;

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function editMobile(Request $request){
        try{
            $object = Customers::find($request->input("customer_id"));
            $validator = Validator::make($request->all(), [
                'customer_id' => 'required',
                'mobile' => 'required|unique:customers,mobile,'.$object->id,
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $object->mobile = $request->input("mobile");
            $object->status = 1;
            $object->save();
            $id = $object->id;
            $user = Customers::select('id','name','email','mobile')->where("id",$id)
                            ->first();
            $response['status'] = 'success';
            $response['message'] = 'Customer mobile edited successfully';
            $response['user'] = $user;

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function getNotificationSetting(Request $request){
        try{
            $object = Customers::find($request->input("customer_id"));
            $validator = Validator::make($request->all(), [
                'customer_id' => 'required',
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $id = $object->id;
            $user = Customers::select('id','notification_10_min','notification_30_min','notification_1_hour')->where("id",$id)->first();
            $data = array(
                "id" => (string)$user['id'],
                "notification_10_min" => $user['notification_10_min'],
                "notification_30_min" => $user['notification_30_min'],
                "notification_1_hour" => $user['notification_1_hour']
            );
            $response['status'] = 'success';
            $response['message'] = 'Customer notification settings get successfully';
            $response['user'] = $data;

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function editNotificationSetting(Request $request){
        try{
            $object = Customers::find($request->input("customer_id"));
            $validator = Validator::make($request->all(), [
                'customer_id' => 'required',
                'notification_10_min' => 'required',
                'notification_30_min' => 'required',
                'notification_1_hr' => 'required'
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $object->notification_10_min = $request->input("notification_10_min");
            $object->notification_30_min = $request->input("notification_30_min");
            $object->notification_1_hour = $request->input("notification_1_hr");
            $object->save();
            $response['status'] = 'success';
            $response['message'] = 'Customer notification settings edited successfully';

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function getCustomerNotification(Request $request)
    {
        try{
            $validator = Validator::make($request->all(), [
                'customer_id' => 'required',
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $data = array();
            $customer_id = $request->input("customer_id");
            $notification = Notification::select('id','fromid','toid','referenceid', 'notification_type', 'message', 'isread', 'created_at')
            ->where("notification.toid", $customer_id)
            ->where("notification.is_deleted", 0)
            ->get();
            // echo "<pre>";
            // print_r($notification);
            // echo "</pre>";
            // exit;
            if(!(empty($notification)))
            {
                foreach ($notification as $key => $value)
                {
                    // echo "<pre>";
                    // print_r($value);
                    // print_r($value->getAttribute("id"));
                    // echo "</pre>";
                    // exit;
                    $data[] = array(
                        "id" => $value->id,
                        "fromid" => $value->fromid,
                        "toid" => $value->toid,
                        "referenceid" => $value->referenceid,
                        "notificationtype" => $value->notification_type,
                        "message" => $value->message,
                        "isread" => $value->isread,
                        "created" => date("d-m-Y H:i:s", strtotime($value->created_at)),
                    );
                }
            }
            $response['status'] = 'success';
            $response['message'] = 'Customer notification get successfully';
            $response['notification'] = $data;

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function readCustomerNotification(Request $request)
    {
        try{
            $validator = Validator::make($request->all(), [
                'customer_id' => 'required',
                'notification_id' => 'required',
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $notification_id = $request->input("notification_id");
            $customer_id = $request->input("customer_id");
            $updateNotificationData = array(
                "isread" => "Y",
                "updated_at" => date("Y-m-d H:i:s")
            );
            $notificationInfo = Notification::where("toid", $customer_id)->where("id", $notification_id)->update($updateNotificationData);
            // echo "<pre>";
            // print_r($notificationInfo);
            // echo "</pre>";
            $response['status'] = 'success';
            $response['message'] = 'Customer notification read successfully';

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function deleteCustomerNotification(Request $request)
    {
        try{
            $validator = Validator::make($request->all(), [
                'customer_id' => 'required',
                'notification_id' => 'required',
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $notification_id = $request->input("notification_id");
            $customer_id = $request->input("customer_id");
            $updateNotificationData = array(
                "is_deleted" => 1,
                "updated_at" => date("Y-m-d H:i:s")
            );
            $notificationInfo = Notification::where("toid", $customer_id)->where("id", $notification_id)->update($updateNotificationData);
            // echo "<pre>";
            // print_r($notificationInfo);
            // echo "</pre>";
            $response['status'] = 'success';
            $response['message'] = 'Customer notification deleted successfully';

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
}
