<?php

namespace App\Http\Controllers\Webservices;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Validator;

use App\Saloons;
use App\SaloonServices;
use App\Services;
use App\Countries;
use App\States;
use App\Cities;
use App\Barbers;
use App\BarbersServices;
use App\SaloonGallery;
use App\Bookings;
use App\BookingItems;
use App\Settings;
use App\SaloonFavourites;
use DB;

class SaloonController extends Controller
{
    public function __construct()
    {
        header('Access-Control-Allow-Origin: *');
        header('Access-Control-Allow-Methods: GET, PUT, POST, DELETE, OPTIONS');
        header("Content-Type: application/json");
    }

    public function saloonRegister(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'salon_name' => 'required',
                'contact_person' => 'required',
                'email' => 'required|email|unique:saloons',
                'mobile' => 'required|unique:saloons',
                'street_address' => 'required',
                'salon_type' => 'required',
                'owner_image' => 'required',
                // 'open_time' => 'required',
                // 'close_time' => 'required',
                'bank_name' => 'required',
                'account_number' => 'required',
                'ifsc_code' => 'required',
                'upi_id' => 'required',
                // 'close_time' => 'required',
                'barbers' => 'required',
                'services'=>'required'
                // 'country_id' => 'required',
                // 'state_id' => 'required',
                // 'city_id' => 'required',
                
                // 'password' => 'required',
                
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $open_time = $request->input("open_time");
            $close_time = $request->input("close_time");
            if(strtotime($close_time) < strtotime($open_time)){
                $errMsg = 'Close time should be greater then open time';
                $response['status'] = 'validation_error';
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $barbers = $request->input('barbers');
            $errMsg = '';
            $is_exists = 0;
            foreach($barbers as $barber){
                $checkBarber = Barbers::where("email",$barber['email'])->count();
                
                if($checkBarber > 0){
                    $is_exists = 1;
                    $errMsg .=" ".$barber['email']." email already taken by barber";
                }
                $checkBarber = Barbers::where("mobile",$barber['mobile'])->count();
                if($checkBarber > 0){
                    $is_exists = 1;
                    $errMsg .=" ".$barber['mobile']." mobile no already taken by barber";
                }
            }
            if($is_exists == 1){
                $response['status'] = 'validation_error';
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $object = new Saloons();
            $object->saloon_name = $request->input("salon_name");
            $object->contact_person = $request->input("contact_person");
            $object->email = $request->input("email");
            $object->mobile = $request->input("mobile");
            $object->street_address = $request->input("street_address");
            $object->open_time = $request->input("open_time");
            $object->close_time = $request->input("close_time");
            $object->bank_name = $request->input("bank_name");
            $object->account_number = $request->input("account_number");
            $object->ifsc_code = $request->input("ifsc_code");
            $object->upi_id = $request->input("upi_id");
            $object->saloon_type = $request->input("salon_type");
            if($request->input("latitude")){
                $object->latitude = $request->input("latitude");
            }
            if($request->input("logitude")){
                $object->logitude = $request->input("logitude");
            }
            if($request->input("instagram")){
                $object->instagram = $request->input("instagram");
            }
            if($request->input("facebook")){
                $object->facebook = $request->input("facebook");
            }
            if($request->input("twitter")){
                $object->twitter = $request->input("twitter");
            }
            if($request->input("owner_image")){
                $image_64 = base64_decode($request->input("owner_image"));
                $f = finfo_open();
                $mime_type = finfo_buffer($f, $image_64, FILEINFO_MIME_TYPE);  
                $extensions = explode("/",$mime_type);
                $ext = end($extensions);
               
                $ci_fileName= time().'-'.rand(00000,99999).'.'.$ext;
                file_put_contents(public_path('uploads/profile_images/').$ci_fileName,$image_64);    
                $object->owner_image = $ci_fileName;
            }
            $object->status = 1;   
            $object->created_by = 0;
            $object->save();
            $saloon_id = $object->id;
            $services = $request->input("services");
            foreach($services as $service){
                $object = new SaloonServices();
                $object->saloon_id = $saloon_id;
                $object->service_name = $service['service_name'];
                $object->service_description = $service['service_description'];
                $object->service_id = $service['service_id'];
                // $object->duration = $service['hours'].":".$service['minutes'];
                if(isset($service['hours']) && isset($service['minutes']))
                {
                    $object->duration = $service['hours'].":".$service['minutes'];
                }
                $object->price = $service['price'];
                $object->created_by = $saloon_id;
                $object->save();
            }
            if(count($barbers) > 0){
                foreach($barbers as $barber){
                    
                    $object = new Barbers();
                    $object->name = $barber['name'];
                    $object->email = $barber['email'];
                    $object->mobile = $barber['mobile'];
                    $object->exp_year = $barber['exp_year'];
                    $object->exp_month = $barber['exp_month'];
                    $object->saloon_id = $saloon_id;
                    $object->status = 1;    
                    $object->created_by = $saloon_id;
                    if(isset($barber['barber_profile'])){
                        $image_64 = base64_decode($barber['barber_profile']);
                        $f = finfo_open();
                        $mime_type = finfo_buffer($f, $image_64, FILEINFO_MIME_TYPE);  
                        $extensions = explode("/",$mime_type);
                        $ext = end($extensions);
                       
                        $ci_fileName= time().'-'.rand(00000,99999).'.'.$ext;
                        file_put_contents(public_path('uploads/profile_images/').$ci_fileName,$image_64);    
                        $object->profile_image = $ci_fileName;
                    }

                    $object->save();
                    $barber_id = $object->id;
                    // $services = $barber['services'];
                    // foreach($services as $service){
                    //     $object = new BarbersServices();
                    //     $object->saloon_id = $saloon_id;
                    //     $object->barber_id = $barber_id;
                    //     $object->service_name = $service['service_name'];
                    //     $object->service_description = $service['service_description'];
                    //     $object->service_id = $service['service_id'];
                    //     $object->duration = $service['hours'].":".$service['minutes'];
                    //     $object->price = $service['price'];
                    //     $object->created_by = $saloon_id;
                    //     $object->save();
                    // }
                }
            }
            if($request->input('salon_gallery')) {   
                $sg_images   = $request->input('salon_gallery'); //your base64 encoded data
                for($i=0;$i < count($sg_images);$i++){
                    $image_64 = base64_decode($sg_images[$i]);
                    $f = finfo_open();
                    $mime_type = finfo_buffer($f, $image_64, FILEINFO_MIME_TYPE);  
                    $extensions = explode("/",$mime_type);
                    $ext = end($extensions);
                   
                    $ci_fileName= time().'-'.rand(00000,99999).'.'.$ext;
                    file_put_contents(public_path('uploads/saloon_gallery/').$ci_fileName, $image_64);    
                    $saloon_gallery = new SaloonGallery();
                    $saloon_gallery->saloon_id = $saloon_id;
                    $saloon_gallery->image = $ci_fileName;
                    $saloon_gallery->created_by = $saloon_id;
                    $saloon_gallery->save();
                }
                
            } 

            $saloon_barbers = Barbers::select('id','name','mobile','profile_image','exp_year','exp_month')->where('saloon_id',$saloon_id)->get();
            foreach($saloon_barbers as $barber){
                $barber->profile_image = asset('public/uploads/profile_images/'.$barber->profile_image);
                if(!empty($barber->Ratings)){
                    $ratings = $barber->Ratings->avg("rating");
                }else{
                    $ratings = 0;
                }
                $barber->ratings = $ratings;
            }
            $services = SaloonServices::where("saloon_id",$saloon_id)
                                        ->distinct("service_id")
                                        ->orderBy("price","asc")
                                        ->get();
            if(count($services) > 0){
                foreach($services as $service){
                    $temp = array();
                    $temp['service_id'] = $service->id;
                    $temp['main_service_id'] = $service->service_id;
                    $temp['name'] = ($service->service_name != NULL)?$service->service_name:'';
                    $temp['price'] = ($service->price != NULL)?$service->price:'';
                    $saloon_services[] = $temp;
                }
            }else{
                $saloon_services = array();
            }

            $saloon = Saloons::with(['FirstImage','Country','Ratings','State','City','ServiceLowPrice'])->where("id",$saloon_id)->first();
            if(count($saloon->Ratings) > 0){
                $ratings = $saloon->Ratings->avg("rating");
            }else{
                $ratings = 0;
            }
            $saloon = $saloon->toArray();
            $temp = array();
            $temp['salon_id'] = $saloon['id'];
            $temp['salon_name'] = $saloon['saloon_name'];
            $temp['open_time'] = ($saloon['open_time'] != NULL)?date("H:i",strtotime($saloon['open_time'])):'';
            $temp['close_time'] = ($saloon['close_time'] != NULL)?date("H:i",strtotime($saloon['close_time'])):'';
            $temp['salon_type'] = ($saloon['saloon_type'] != NULL)?$saloon['saloon_type']:'';
            $temp['contact_no'] =  ($saloon['mobile'] != NULL)?$saloon['mobile']:'';
            $temp['ratings'] = $ratings;
            $street_address = '';
            if($saloon['street_address'] != ''){
                $street_address = $saloon['street_address'];
            }
            $temp['street_address'] =  $street_address;
            if(!empty($saloon['owner_image'])){
                $temp['owner_image'] = asset('public/uploads/profile_images/'.$saloon['owner_image']);                
            }else{
                $temp['owner_image'] = '';
            }
            if(!empty($saloon['service_low_price'])){
                $temp['price'] = $saloon['service_low_price']['price'];                
            }else{
                $temp['price'] = '';
            }
            if($saloon['instagram'] != ''){
                $temp['instagram'] = $saloon['instagram'];
            }else{
                $temp['instagram'] = '';
            }
            if($saloon['facebook'] != ''){
                $temp['facebook'] = $saloon['facebook'];
            }else{
                $temp['facebook'] = '';
            }
            if($saloon['twitter'] != ''){
                $temp['twitter'] = $saloon['twitter'];
            }else{
                $temp['twitter'] = '';
            }
            if($saloon['latitude'] != ''){
                $temp['latitude'] = $saloon['latitude'];
            }else{
                $temp['latitude'] = '';
            }
            if($saloon['logitude'] != ''){
                $temp['logitude'] = $saloon['logitude'];
            }else{
                $temp['logitude'] = '';
            }
            $saloon_detail = $temp;

            $saloon_gallery = SaloonGallery::where("saloon_id",$saloon_id)->get();
            $images = array();
            foreach($saloon_gallery as $gallery){
                $images[] = asset('public/uploads/saloon_gallery/'.$gallery->image);
            }   

            $response['barbers'] = $saloon_barbers;
            $response['services'] = $saloon_services;
            $response['salon'] = $saloon_detail;
            $response['salon_gallery'] = $images;
            $response['status'] = 'success';
            $response['message'] = 'Salon added successfully';
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function editProfile(Request $request){
        try{
            $object = Saloons::find($request->input("salon_id"));
            $validator = Validator::make($request->all(), [
                'salon_name' => 'required',
                'contact_person' => 'required',
                'email' => 'required|email|unique:saloons,email,'.$object->id,
                'mobile' => 'required|unique:saloons,mobile,'.$object->mobile,
                'street_address' => 'required',
                'salon_type' => 'required',
                'owner_image' => 'required',
                'open_time' => 'required',
                'close_time' => 'required',
                'bank_name' => 'required',
                'account_number' => 'required',
                'ifsc_code' => 'required',
                'upi_id' => 'required',
                'close_time' => 'required',
            ]);
            $object->saloon_name = $request->input("salon_name");
            $object->contact_person = $request->input("contact_person");
            $object->email = $request->input("email");
            $object->mobile = $request->input("mobile");
            $object->street_address = $request->input("street_address");
            $object->open_time = $request->input("open_time");
            $object->close_time = $request->input("close_time");
            $object->bank_name = $request->input("bank_name");
            $object->account_number = $request->input("account_number");
            $object->ifsc_code = $request->input("ifsc_code");
            $object->upi_id = $request->input("upi_id");
            $object->saloon_type = $request->input("salon_type");
            if($request->input("latitude")){
                $object->latitude = $request->input("latitude");
            }
            if($request->input("logitude")){
                $object->logitude = $request->input("logitude");
            }
            if($request->input("instagram")){
                $object->instagram = $request->input("instagram");
            }
            if($request->input("facebook")){
                $object->facebook = $request->input("facebook");
            }
            if($request->input("twitter")){
                $object->twitter = $request->input("twitter");
            }
            if($request->input("owner_image")){
                if($object->owner_image != '' && file_exists(public_path('uploads/profile_images/'.$object->owner_image))){
                    unlink(public_path('uploads/profile_images/'.$object->owner_image));                    
                } 
                $image_64 = base64_decode($request->input("owner_image"));
                $f = finfo_open();
                $mime_type = finfo_buffer($f, $image_64, FILEINFO_MIME_TYPE);  
                $extensions = explode("/",$mime_type);
                $ext = end($extensions);
               
                $ci_fileName= time().'-'.rand(00000,99999).'.'.$ext;
                file_put_contents(public_path('uploads/profile_images/').$ci_fileName,$image_64);    
                $object->owner_image = $ci_fileName;
            }
            $object->save();
            $saloon_id = $object->id;
            if($request->input('salon_gallery')) {   
                $sg_images   = $request->input('salon_gallery'); //your base64 encoded data
                for($i=0;$i < count($sg_images);$i++){
                    $image_64 = base64_decode($sg_images[$i]);
                    $f = finfo_open();
                    $mime_type = finfo_buffer($f, $image_64, FILEINFO_MIME_TYPE);  
                    $extensions = explode("/",$mime_type);
                    $ext = end($extensions);
                   
                    $ci_fileName= time().'-'.rand(00000,99999).'.'.$ext;
                    file_put_contents(public_path('uploads/saloon_gallery/').$ci_fileName, $image_64);    
                    $saloon_gallery = new SaloonGallery();
                    $saloon_gallery->saloon_id = $saloon_id;
                    $saloon_gallery->image = $ci_fileName;
                    $saloon_gallery->created_by = $saloon_id;
                    $saloon_gallery->save();
                }
            }
            $saloon = Saloons::with(['FirstImage','Country','Ratings','State','City','ServiceLowPrice'])->where("id",$saloon_id)->first();
            if(count($saloon->Ratings) > 0){
                $ratings = $saloon->Ratings->avg("rating");
            }else{
                $ratings = 0;
            }
            $saloon = $saloon->toArray();
            // $temp = array();
            // $temp['salon_id'] = $saloon['id'];
            // $temp['salon_name'] = $saloon['saloon_name'];
            // $temp['open_time'] = ($saloon['open_time'] != NULL)?date("H:i",strtotime($saloon['open_time'])):'';
            // $temp['close_time'] = ($saloon['close_time'] != NULL)?date("H:i",strtotime($saloon['close_time'])):'';
            // $temp['salon_type'] = ($saloon['saloon_type'] != NULL)?$saloon['saloon_type']:'';
            // $temp['contact_no'] =  ($saloon['mobile'] != NULL)?$saloon['mobile']:'';
            // $temp['ratings'] = $ratings;
            // $street_address = '';
            // if($saloon['street_address'] != ''){
            //     $street_address = $saloon['street_address'];
            // }
            // $temp['street_address'] =  $street_address;
            // if(!empty($saloon['owner_image'])){
            //     $temp['owner_image'] = asset('public/uploads/profile_images/'.$saloon['owner_image']);                
            // }else{
            //     $temp['owner_image'] = '';
            // }
            // if(!empty($saloon['service_low_price'])){
            //     $temp['price'] = $saloon['service_low_price']['price'];                
            // }else{
            //     $temp['price'] = '';
            // }
            // if($saloon['instagram'] != ''){
            //     $temp['instagram'] = $saloon['instagram'];
            // }else{
            //     $temp['instagram'] = '';
            // }
            // if($saloon['facebook'] != ''){
            //     $temp['facebook'] = $saloon['facebook'];
            // }else{
            //     $temp['facebook'] = '';
            // }
            // if($saloon['twitter'] != ''){
            //     $temp['twitter'] = $saloon['twitter'];
            // }else{
            //     $temp['twitter'] = '';
            // }
            // if($saloon['latitude'] != ''){
            //     $temp['latitude'] = $saloon['latitude'];
            // }else{
            //     $temp['latitude'] = '';
            // }
            // if($saloon['logitude'] != ''){
            //     $temp['logitude'] = $saloon['logitude'];
            // }else{
            //     $temp['logitude'] = '';
            // }
            // $saloon_detail = $temp;
            $saloon_detail = $this->salon_data($saloon['id']);
            $saloon_gallery = SaloonGallery::where("saloon_id",$saloon_id)->get();
            $images = array();
            foreach($saloon_gallery as $gallery){
                $images[] = asset('public/uploads/saloon_gallery/'.$gallery->image);
            }   
            $response['salon'] = $saloon_detail;
            $response['salon_gallery'] = $images;
            $response['status'] = 'success';
            $response['message'] = 'Salon edited successfully';
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
    public function loginAsSaloon(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'mobile' => 'required'
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $response['login'] = false;
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $mobile = $request->input("mobile");
            $saloon = Saloons::where("mobile",$mobile)->first();
            
            if(empty($saloon)){
                $response['status'] = 'error';
                $response['login'] = false;
                $response['message'] = 'Invalid mobile no';
                return response()->json($response);
            }else{
            // if (\Auth::guard('saloon')->attempt(['email' => $request->email, 'password' => $request->password], $request->remember)) {
                $saloon = $saloon->toArray();
                // $temp = array();
                // $temp['salon_id'] = $saloon['id'];
                // $temp['salon_name'] = $saloon['saloon_name'];
                // $temp['open_time'] = ($saloon['open_time'] != NULL)?date("H:i",strtotime($saloon['open_time'])):'';
                // $temp['close_time'] = ($saloon['close_time'] != NULL)?date("H:i",strtotime($saloon['close_time'])):'';
                // $temp['salon_type'] = ($saloon['saloon_type'] != NULL)?$saloon['saloon_type']:'';
                // $temp['contact_no'] =  ($saloon['mobile'] != NULL)?$saloon['mobile']:'';
                // $street_address = '';
                // if($saloon['street_address'] != ''){
                //     $street_address = $saloon['street_address'];
                // }                
                // $temp['street_address'] =  $street_address;
                // if(!empty($saloon['owner_image'])){
                //     $temp['owner_image'] = asset('public/uploads/profile_images/'.$saloon['owner_image']);                
                // }else{
                //     $temp['owner_image'] = '';
                // }
                
                // if($saloon['instagram'] != ''){
                //     $temp['instagram'] = $saloon['instagram'];
                // }else{
                //     $temp['instagram'] = '';
                // }
                // if($saloon['facebook'] != ''){
                //     $temp['facebook'] = $saloon['facebook'];
                // }else{
                //     $temp['facebook'] = '';
                // }
                // if($saloon['twitter'] != ''){
                //     $temp['twitter'] = $saloon['twitter'];
                // }else{
                //     $temp['twitter'] = '';
                // }
                // if($saloon['latitude'] != ''){
                //     $temp['latitude'] = $saloon['latitude'];
                // }else{
                //     $temp['latitude'] = '';
                // }
                // if($saloon['logitude'] != ''){
                //     $temp['logitude'] = $saloon['logitude'];
                // }else{
                //     $temp['logitude'] = '';
                // }
                // $saloon_detail = $temp;
                $saloon_detail = $this->salon_data($saloon['id']);
                $response['status'] = 'success';
                $response['login'] = true;
                $response['message'] = 'Login success';
                $response['user'] = $saloon_detail;
                // $response['token'] = $user->generateToken();
            }
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
    public function salon_data($id){
        $saloon = Saloons::where("id",$id)->first();
        $saloon = $saloon->toArray();
        $temp = array();
        
        unset($saloon['last_login']);
        unset($saloon['api_token']);
        unset($saloon['created_by']);
        unset($saloon['updated_by']);
        unset($saloon['deleted_by']);
        unset($saloon['created_at']);
        unset($saloon['updated_at']);
        unset($saloon['deleted_at']);
        unset($saloon['country_id']);
        unset($saloon['city_id']);
        unset($saloon['state_id']);
        unset($saloon['password']);
        $temp = $saloon;
        if(!empty($saloon['owner_image'])){
            $temp['owner_image'] = asset('public/uploads/profile_images/'.$saloon['owner_image']);                
        }else{
            $temp['owner_image'] = '';
        }
        $temp['salon_name'] = $saloon['saloon_name'];
        unset($temp['saloon_name']);
        unset($temp['id']);
        $temp['salon_id'] = $saloon['id'];
        $temp['open_time'] = ($saloon['open_time'] != NULL)?date("H:i",strtotime($saloon['open_time'])):'';
        $temp['close_time'] = ($saloon['close_time'] != NULL)?date("H:i",strtotime($saloon['close_time'])):'';
        $temp['salon_type'] = ($saloon['saloon_type'] != NULL)?$saloon['saloon_type']:'';
        $temp['contact_no'] =  ($saloon['mobile'] != NULL)?$saloon['mobile']:'';
        $street_address = '';
        if($saloon['street_address'] != ''){
            $street_address = $saloon['street_address'];
        }                
        $temp['street_address'] =  $street_address;
        if(!empty($saloon['owner_image'])){
            $temp['owner_image'] = asset('public/uploads/profile_images/'.$saloon['owner_image']);                
        }else{
            $temp['owner_image'] = '';
        }
        
        if($saloon['instagram'] != ''){
            $temp['instagram'] = $saloon['instagram'];
        }else{
            $temp['instagram'] = '';
        }
        if($saloon['facebook'] != ''){
            $temp['facebook'] = $saloon['facebook'];
        }else{
            $temp['facebook'] = '';
        }
        if($saloon['twitter'] != ''){
            $temp['twitter'] = $saloon['twitter'];
        }else{
            $temp['twitter'] = '';
        }
        if($saloon['latitude'] != ''){
            $temp['latitude'] = $saloon['latitude'];
        }else{
            $temp['latitude'] = '';
        }
        if($saloon['logitude'] != ''){
            $temp['logitude'] = $saloon['logitude'];
        }else{
            $temp['logitude'] = '';
        }
        $saloon_detail = $temp;
        return $saloon_detail;
    }
    public function getAllServices(Request $request){
        try{
            $services = Services::select('id','name')->where("status","1")->get();
            $response['status'] = 'success';
            $response['services'] = $services;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }


    public function getSaloonByService(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'service_id' => 'required',
                'customer_id' => 'required'
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $sort_by = '';
            if($request->input("sort_by")){
                $sort_by = $request->input("sort_by");
            }
            $rating = array();
            if($request->input("rating")){
                $rating = $request->input("rating");
            }
            $valid_for = array();
            if($request->input("valid_for")){
                $valid_for = $request->input("valid_for");
            }
            $price_filter = array();
            if($request->input("price_filter")){
                $price_filter = $request->input("price_filter");
                $price = array();
                for($i=0;$i < count($price_filter);$i++){
                    $t = explode("-",$price_filter[$i]);
                    $price[] = $t[0];
                    $price[] = $t[1];
                }
                $price = array_unique($price);
                $max_price = max($price);
                $min_price = min($price);
                $price_filter = array();
                $price_filter[] = $min_price;
                $price_filter[] = $max_price;
            }
            $service_id = $request->input("service_id");
            $saloon_ids = SaloonServices::with('Saloon')
                                        ->where("service_id",$service_id)
                                        ->where(function($query) use($price_filter,$valid_for){
                                            if(count($price_filter) > 0){
                                                $query->where("price",">=",$price_filter[0]);
                                                $query->where("price","<=",$price_filter[1]);
                                            }
                                            if(count($valid_for) > 0){
                                                $query->whereHas("Saloon",function($query2) use($valid_for){
                                                    $query2->where("status",1);
                                                    if(count($valid_for) > 0){
                                                        $query2->whereIn("saloon_type",$valid_for);
                                                    }
                                                });
                                            }
                                        })
                                        ->whereHas("Saloon")
                                        ->groupBy("saloon_id")
                                        ->pluck('saloon_id');

            if(count($saloon_ids) > 0){ 
                $saloon_ids = $saloon_ids->toArray();
            }else{
                $saloon_ids = array();
            }

            $keyword = "";
            $where_and = "";
            if($request->input("keyword")){
                $keyword = $request->input("keyword");
                $where_and = " (saloon_name like '%".$keyword."%' OR saloons.street_address like '%".$keyword."%')";
            }
            $keylatitude = "";
            $keylongitude = "";
            $whereHaving = "";
            $islatlng = "";
            if($request->input("keylat") != "" && $request->input("keylng") != ""){
                $keylatitude = $request->input("keylat");
                $keylongitude = $request->input("keylng");
                $where_and = ", (3959*acos(cos(radians('".$keylatitude."'))*cos(radians(saloons.latitude))*cos(radians(saloons.logitude)-radians('".$keylongitude."'))+sin(radians('".$keylatitude."'))*sin(radians(saloons.latitude)))) AS distance";
                $whereHaving = " distance <= ?";
                $islatlng = "Y";
            }
            $saloonsList = Saloons::select(DB::raw("*, (3959*acos(cos(radians('".$keylatitude."'))*cos(radians(saloons.latitude))*cos(radians(saloons.logitude)-radians('".$keylongitude."'))+sin(radians('".$keylatitude."'))*sin(radians(saloons.latitude)))) AS distance"))->with(['Country'=>function($query){
                $query->select('id','name');
            }])
            ->with(['State'=>function($query){
                $query->select('id','name');
            }])
            ->with(['City'=>function($query){
                $query->select('id','name');
            }])
            ->with(['FirstImage','ServiceLowPrice','Country','State','City','Ratings'])
            ->whereIn("id",$saloon_ids)
            ->where("status",'1')
            ->where(function($query) use ($rating) {
                if(count($rating) > 0){
                    $query->whereHas('Ratings',function($q) use($rating){
                      $q->whereIn("rating",$rating);  
                    });
                }
            })
            ->where(function($query) use ($where_and, $keyword) {
                if($keyword != ""){
                    $query->whereRaw($where_and, false);
                }
            });
            if($islatlng == "Y")
            {
                $saloonsList = $saloonsList->havingRaw(" distance <= ?", [10]);
            }
            $saloonsList = $saloonsList->get();
            // echo "<pre>";
            // print_r($saloonsList);
            // echo "</pre>";
            // exit;

            $saloons = array();
            foreach($saloonsList  as $saloon){
                if(count($saloon->Ratings) > 0){
                    $ratings = $saloon->Ratings->avg("rating");
                }else{
                    $ratings = 0;
                }
                $saloon = $saloon->toArray();
                $temp['salon_id'] = $saloon['id'];
                $temp['salon_name'] = $saloon['saloon_name'];
                $temp['open_time'] = ($saloon['open_time'] != NULL)?date("H:i",strtotime($saloon['open_time'])):'';
                $temp['close_time'] = ($saloon['close_time'] != NULL)?date("H:i",strtotime($saloon['close_time'])):'';
                $temp['salon_type'] = ($saloon['saloon_type'] != NULL)?$saloon['saloon_type']:'';
                $temp['ratings'] = $ratings;
                $temp['latitude'] = ($saloon['latitude'] != NULL)?$saloon['latitude']:'';
                $temp['logitude'] = ($saloon['logitude'] != NULL)?$saloon['logitude']:'';
                $temp['distance'] = ($saloon['distance'] != NULL)?$saloon['distance']:'';
                $street_address = '';
                if($saloon['street_address'] != ''){
                    $street_address = $saloon['street_address'];
                }
                // if(!empty($saloon['city'])){
                //     $street_address .= " ".$saloon['city']['name'];
                // }
                // if(!empty($saloon['state'])){
                //     $street_address .= " ".$saloon['state']['name'];
                // }
                // if(!empty($saloon['country'])){
                //     $street_address .= " ".$saloon['country']['name'];
                // }
                $temp['street_address'] =  $street_address;
                if(!empty($saloon['first_image'])){
                    $temp['image'] = asset('public/uploads/saloon_gallery/'.$saloon['first_image']['image']);                
                }else{
                    $temp['image'] = '';
                }
                if(!empty($saloon['service_low_price'])){
                    $temp['price'] = $saloon['service_low_price']['price'];                
                }else{
                    $temp['price'] = '';
                }
                //
                $is_fav = "N";
                $customer_id = $request->input("customer_id");
                $saloon_is_fav = \DB::table("saloon_favourite")->select("id")->where("customer_id", $customer_id)->where("saloon_id", $saloon['id'])->get();
                if(count($saloon_is_fav) > 0)
                {
                    $is_fav = "Y";
                }
                $temp['is_saloon_fav'] = $is_fav;
                //
                $saloons[] = $temp;
            }
            if($sort_by != ''){
                $price = array();
                foreach ($saloons as $key => $row)
                {
                    $price[$key] = $row['price'];
                }
                if($sort_by == 'price_low_high'){
                    array_multisort($price, SORT_ASC, $saloons);
                }else{
                    array_multisort($price, SORT_DESC, $saloons);    
                }
                
            }
            $response['status'] = 'success';
            $response['salons'] = $saloons;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
    public function getSaloonServices(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'salon_id' => 'required'
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $saloon_id = $request->input("salon_id");
            $services = BarbersServices::where("saloon_id",$saloon_id)
                                        ->distinct("service_id")
                                        ->orderBy("price","asc")
                                        ->get();
            if(count($services) > 0){
                foreach($services as $service){
                    $temp['service_id'] = $service->id;
                    $temp['name'] = $service->service_name;
                    $temp['price'] = $service->price;
                    $saloon_services[] = $temp;
                }
            }else{
                $saloon_services = array();
            }
            
            $response['status'] = 'success';
            $response['salon_services'] = $saloon_services;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function getSaloonBarbers(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'salon_id' => 'required'
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $saloon_id = $request->input("salon_id");
            $barbersList = Barbers::select('id','name','mobile','profile_image','exp_year','exp_month', 'email')->where('saloon_id',$saloon_id)->get();
            $barbers = array();
            foreach($barbersList as $barber){
                if(count($barber->Ratings) > 0){
                    $ratings = $barber->Ratings->avg("rating");
                }else{
                    $ratings = 0;
                }
                
                $temp = $barber->toArray();
                $temp['profile_image'] = asset('public/uploads/profile_images/'.$barber->profile_image);
                // $today_earning = Bookings::where("barber_id",$barber->id)
                //         ->whereDate("book_date",$date)
                //         ->orderBy("book_date","desc")
                //         ->sum("total");
                // $temp['today_earning'] = $today_earning;

                // $month_earning = Bookings::where("barber_id",$barber->id)
                //         ->whereDate("book_date",">=",$month_start)
                //         ->whereDate("book_date","<=",$month_end)
                //         ->orderBy("book_date","desc")
                //         ->sum("total");
                // $temp['month_earning'] = $month_earning;
                $temp['ratings'] = $ratings;
                $temp['email'] = $this->render($barber->email);
                $temp['totalhours'] = "100";
                $barbers[] = $temp;
            }

            $response['status'] = 'success';
            $response['barbers'] = $barbers;
            $response['profile_image_path'] = asset('public/uploads/profile_images');

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
    public function Countries(Request $request){
        try{
            $countries = Countries::get();
            $response['status'] = 'success';
            $response['countries'] = $countries;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function States(Request $request){
        try{
            $country_id = $request->input("country_id");
            $states = States::where("country_id",$country_id)->get();
            $response['status'] = 'success';
            $response['states'] = $states;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function getSaloonDetails(Request $request){
        try{
            $saloon_id = $request->input("salon_id");
            $saloon = Saloons::with(['FirstImage','Country','Ratings','State','City','ServiceLowPrice'])->where("id",$saloon_id)->first();
            if(empty($saloon)){
                $response['status'] = 'error';
                $response['message'] = 'Salon not found';
        
                return response()->json($response);
            }
            if(count($saloon->Ratings) > 0){
                $ratings = $saloon->Ratings->avg("rating");
            }else{
                $ratings = 0;
            }
            $saloon = $saloon->toArray();
            $temp = array();
            $temp['salon_id'] = $saloon['id'];
            $temp['salon_name'] = $saloon['saloon_name'];
            $temp['open_time'] = ($saloon['open_time'] != NULL)?date("H:i",strtotime($saloon['open_time'])):'';
            $temp['close_time'] = ($saloon['close_time'] != NULL)?date("H:i",strtotime($saloon['close_time'])):'';
            $temp['salon_type'] = ($saloon['saloon_type'] != NULL)?$saloon['saloon_type']:'';
            $temp['contact_no'] =  ($saloon['mobile'] != NULL)?$saloon['mobile']:'';
            $temp['contact_person'] =  ($saloon['contact_person'] != NULL)?$saloon['contact_person']:'';
            $temp['email'] =  ($saloon['email'] != NULL)?$saloon['email']:'';
            $temp['mobile'] =  ($saloon['mobile'] != NULL)?$saloon['mobile']:'';
            $temp['street_address'] =  ($saloon['street_address'] != NULL)?$saloon['street_address']:'';
            $temp['saloon_type'] =  ($saloon['saloon_type'] != NULL)?$saloon['saloon_type']:'';
            $temp['bank_name'] =  ($saloon['bank_name'] != NULL)?$saloon['bank_name']:'';
            $temp['account_number'] =  ($saloon['account_number'] != NULL)?$saloon['account_number']:'';
            $temp['ifsc_code'] =  ($saloon['ifsc_code'] != NULL)?$saloon['ifsc_code']:'';
            $temp['upi_id'] =  ($saloon['upi_id'] != NULL)?$saloon['upi_id']:'';
            //
            $is_fav = "N";
            $customer_id = $request->input("customer_id");
            $saloon_is_fav = \DB::table("saloon_favourite")->select("id")->where("customer_id", $customer_id)->where("saloon_id", $saloon['id'])->get();
            if(count($saloon_is_fav) > 0)
            {
                $is_fav = "Y";
            }
            $temp['is_saloon_fav'] = $is_fav;           

            $temp['ratings'] = $ratings;
            $street_address = '';
            if($saloon['street_address'] != ''){
                $street_address = $saloon['street_address'];
            }
            
            $temp['street_address'] =  $street_address;
            if(!empty($saloon['owner_image'])){
                $temp['owner_image'] = asset('public/uploads/profile_images/'.$saloon['owner_image']);                
            }else{
                $temp['owner_image'] = '';
            }
            if(!empty($saloon['service_low_price'])){
                $temp['price'] = $saloon['service_low_price']['price'];
                if($temp['price'] > 0)
                {
                    $objSetting = new Settings();
                    $commission = $objSetting->getSetting("Commission");
                    $nprice = ($temp['price'] * $commission) / 100;
                    $nprice = $temp['price'] + $nprice;
                    $temp['price'] = $nprice;
                }
            }else{
                $temp['price'] = '';
            }
            if($saloon['instagram'] != ''){
                $temp['instagram'] = $saloon['instagram'];
            }else{
                $temp['instagram'] = '';
            }
            if($saloon['facebook'] != ''){
                $temp['facebook'] = $saloon['facebook'];
            }else{
                $temp['facebook'] = '';
            }
            if($saloon['twitter'] != ''){
                $temp['twitter'] = $saloon['twitter'];
            }else{
                $temp['twitter'] = '';
            }
            if($saloon['latitude'] != ''){
                $temp['latitude'] = $saloon['latitude'];
            }else{
                $temp['latitude'] = '';
            }
            if($saloon['logitude'] != ''){
                $temp['logitude'] = $saloon['logitude'];
            }else{
                $temp['logitude'] = '';
            }
            $saloon_detail = $temp;

            $saloon_gallery = SaloonGallery::where("saloon_id",$saloon_id)->get();
            $images = array();
            foreach($saloon_gallery as $gallery){
                $images[] = asset('public/uploads/saloon_gallery/'.$gallery->image);
            }   
            
            $saloon_id = $request->input("salon_id");
            $services = SaloonServices::where("saloon_id",$saloon_id)
                                        ->distinct("service_id")
                                        ->whereHas("Saloon")
                                        ->orderBy("price","asc")
                                        ->get();
            if(count($services) > 0){
                foreach($services as $service){
                    $temp = array();
                    $temp['service_id'] = $service->id;
                    $temp['main_service_id'] = $service->service_id;
                    $temp['name'] = ($service->service_name != NULL)?$service->service_name:'';
                    // $temp['price'] = ($service->price != NULL)?$service->price:'';
                    if($service->price != NULL && $service->price > 0)
                    {
                        $objSetting = new Settings();
                        $commission = $objSetting->getSetting("Commission");
                        $nprice = ($service->price * $commission) / 100;
                        $nprice = $service->price + $nprice;
                        $service->price = $nprice;
                    }
                    $temp['price'] = ($service->price != NULL)?$service->price:'';
                    $temp['main_service_id'] = $service->service_id;
                    $temp['service_description'] = $service->service_description;
                    $temp['duration'] = $service->duration;
                    $saloon_services[] = $temp;
                }
            }else{
                $saloon_services = array();
            }
            $response['status'] = 'success';
            $response['salon'] = $saloon_detail;
            $response['salon_services'] = $saloon_services;
            $response['salon_gallery'] = $images;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function Cities(Request $request){
        try{
            $state_id = $request->input("state_id");
            $cities = Cities::where("state_id",$state_id)->get();
            $response['status'] = 'success';
            $response['cities'] = $cities;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
    public function fetchBarber(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'barber_id' => 'required',
            ]);

            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $barber_id = $request->input("barber_id");
            $barber = Barbers::select('id','saloon_id','name','mobile','profile_image','exp_year','exp_month')
                            ->where("id",$barber_id)
                            ->first();
            $barber->profile_image = asset('public/uploads/profile_images/'.$barber->profile_image);
            $response['barber'] = $barber;
            $response['status'] = 'success';

        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
    public function saveBarber(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'salon_id' => 'required',
                'name' => 'required',
                'email' => 'required|email|unique:barbers',
                'mobile' => 'required|unique:barbers',
                'exp_year'=>"required",
                'exp_month'=>"required",
                'profile_image' =>'required',
            ]);

            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
           
            $object = new Barbers();
            $object->name = $request->input("name");
            $object->email = $request->input("email");
            $object->mobile = $request->input("mobile");
            $object->exp_year = $request->input("exp_year");
            $object->exp_month = $request->input("exp_month");
            $object->saloon_id = $request->input("salon_id");
            
            if($request->input('profile_image')){
                $image_64   = base64_decode($request->input('profile_image'));
                $f          = finfo_open();
                $mime_type  = finfo_buffer($f, $image_64, FILEINFO_MIME_TYPE);  
                $extensions = explode("/",$mime_type);
                $ext        = end($extensions);
               
                $ci_fileName= time().'-'.rand(00000,99999).'.'.$ext;
                file_put_contents(public_path('uploads/profile_images/').$ci_fileName,$image_64);    
                $object->profile_image = $ci_fileName;
            }
            $object->status = 1;    
            $object->created_by = $request->input("salon_id");
            $object->save();
            
            $response['status'] = 'success';
            $response['message'] = 'Barber added successfully';
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function updateBarber(Request $request){
        try{
            $id = $request->input("barber_id");
            $user = Barbers::find($id);
            $validator = Validator::make($request->all(), [
                'barber_id' => 'required',
                'salon_id' => 'required',
                'name' => 'required',
                'email' => 'required|email|unique:barbers,email,'.$user->id,
                'mobile' => 'required|unique:barbers,mobile,'.$user->id,
                'exp_year'=>"required",
                'exp_month'=>"required",
            ]);

            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
           
            $object = Barbers::find($id);
            $object->name = $request->input("name");
            $object->email = $request->input("email");
            $object->mobile = $request->input("mobile");
            $object->exp_year = $request->input("exp_year");
            $object->exp_month = $request->input("exp_month");
            $object->saloon_id = $request->input("salon_id");
            
            if($request->file("profile_image")){
                $image_64 = base64_decode($barber['barber_profile']);
                $f = finfo_open();
                $mime_type = finfo_buffer($f, $image_64, FILEINFO_MIME_TYPE);  
                $extensions = explode("/",$mime_type);
                $ext = end($extensions);
               
                $ci_fileName= time().'-'.rand(00000,99999).'.'.$ext;
                file_put_contents(public_path('uploads/profile_images/').$ci_fileName,$image_64);    
                $object->profile_image = $ci_fileName;
            }
            $object->updated_by = $request->input("salon_id");
            $object->save();
            
            $response['status'] = 'success';
            $response['message'] = 'Barber updated successfully';
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function deleteBarber(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'barber_id' => 'required',
                'salon_id' => 'required'
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            
            $barber_id = $request->input("barber_id");
            $saloon_id = $request->input("salon_id");
            $exists = Barbers::where("id",$barber_id)->count();
            if($exists == 0){
                $response['status'] = 'validation_error';
                $response['message'] = "Barber not exists";
                return response()->json($response);   
            }
            Barbers::where("id",$barber_id)->update(['deleted_by'=>$saloon_id]);
            Barbers::where("id",$barber_id)->delete();

            $response['status'] = 'success';
            $response['message'] = 'Barber deleted successfully';
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function filterOptions(Request $request){
        try{
            $service_id = $request->input("service_id");
            $budgets = BarbersServices::select(\DB::raw('min(price) as min_price,max(price) as max_price'))
                                    ->where("service_id",$service_id)
                                    ->first();
            $price_range = array();
            // $rating = array("1.0","2.0","3.0","4.0","5.0");
            $rating = array();
            $rating[] = array("name"=>"1");
            $rating[] = array("name"=>"2");
            $rating[] = array("name"=>"3");
            $rating[] = array("name"=>"4");
            $rating[] = array("name"=>"5");
            if(!empty($budgets)){
                $min_price = $budgets->min_price;
                $max_price = $budgets->max_price;
                if($max_price > 30){
                    $length = ceil($max_price/30);
                    $start_price = 0;
                    $end_price = 0;
                    for($i=0;$i < $length;$i++){
                        if($i == 0){
                            $start_price = round($min_price);
                            $end_price = $min_price + 30;
                        }else{
                            $start_price += 30;
                            $end_price = $start_price + 30;
                        }
                        $price_range[] = array(
                            "name" => $start_price."-".$end_price
                       );
                    }
                }
            }
            $saloon_types = Saloons::where("saloon_type","!=","")
                            ->groupBy("saloon_type")
                            ->pluck("saloon_type");
            if(!empty($saloon_types)){
                $saloon_types = $saloon_types->toArray();
                foreach($saloon_types as $type){
                    $valid_for[] = array("name"=>$type);
                }
            }else{
                $saloon_types = array();
            }
            $j = 0;
            for($i=0;$i < 10;$i++){
                $s = $j+50;
                $p = $j."-".$s;
                $j = $j+50;
                $tenp_price[] = array("name"=>$p);
            }
            $response['price_range'] = $tenp_price;
            $response['rating'] = $rating;
            $response['valid_for'] = $valid_for;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function bookingList(Request $request){
        try{
            $saloon_id = $request->input("salon_id");
            $bookings = Bookings::where("saloon_id",$saloon_id)
                                ->whereHas("Saloon")
                                ->whereHas("Barber")
                                ->whereHas("Customer")
                                ->orderBy("book_date","desc")
                                ->get();
            $bookingList = array();
            foreach($bookings as $booking){
                $temp = array();
                $temp['id'] = $booking->id;
                $temp['book_date'] = dateFormat($booking->book_date,"d-m-Y");
                $temp['customer_name'] = $booking->Customer->name;
                $temp['customer_id'] = $booking->customer_id;
                $temp['salon_name'] = $booking->Saloon->saloon_name;
                $temp['salon_id'] = $booking->saloon_id;
                $temp['barber_name'] = $booking->Barber->name;
                $temp['barber_id'] = $booking->barber_id;
                $temp['book_number'] = $booking->book_number;
                $temp['total_price'] = $booking->total;
                $temp['from_time'] = $booking->from_time;
                $temp['to_time'] = $booking->to_time;
                $temp['transaction_id'] = $booking->transaction_id;
                $temp['billing_name'] = $booking->billing_name;
                $temp['billing_mobile'] = $booking->billing_mobile;
                $temp['billing_email'] = $booking->billing_email;
                $date = $booking->book_date." ".$booking->to_time;
                $current_date = date("Y-m-d H:i:s");
                /*if($date > $current_date){
                    $temp['status'] = 'Upcoming';
                }else{
                    $temp['status'] = 'Completed';
                }*/

                if($date > $current_date)
                {
                    $temp['status'] = 'Upcoming';
                }
                else if($booking->payment_status == "C")
                {
                    $temp['status'] = 'Completed';
                }

                if($booking->status == 'cancelled'){
                    $temp['status'] = 'Cancelled';
                }


                $services = array();
                $total  = 0;
                $services_array = array();
                foreach($booking->BookingItems as $i => $item){
                    $services[] = $item->SaloonService->service_name;
                    if($item->price > 0){                    
                        $total = $total + $item->price;
                    }
                    $services_array[$i]['service_name'] = $item->SaloonService->service_name;
                    $services_array[$i]['service_price'] = $item->price;
                }
                
                $temp['service_name'] = implode(",",$services);
                $temp['service_price'] = number_format($total,2);
                
                $temp['services'] = $services_array;
                
                // $booking_services = BookingItems::with('Service')->where("booking_id",$booking->id)->get();
                // $services = array();
                // foreach($booking_services as $serv){
                //     $temp['service_name'] = $serv->Service->name;
                //     $temp['service_price'] = $serv->price;
                //     $services[] = $temp;
                // }
                // $temp['services'] = $services;

                $bookingList[] = $temp;
            }
            $response['status'] = 'success';
            $response['booking_list'] = $bookingList;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }


    public function salooonIncome(Request $request){
        try{
            $saloon_id = $request->input("salon_id");
            if($request->input("date")){
                $date = date("Y-m-d",strtotime($request->input("date")));    
            }else{
                $date = date("Y-m-d");
            }
            $salon = Saloons::where("id",$saloon_id)->first();
            if(empty($salon)){
                $response['status'] = 'error';
                $response['message'] = 'Salon not exists';
            
                return response()->json($response);
            }
            $today_earning = Bookings::where("saloon_id",$saloon_id)
                        ->where("status","!=",'cancelled')  
                        ->whereDate("book_date",$date)
                        ->whereHas("Saloon")
                        ->whereHas("Barber")
                        ->whereHas("Customer")
                        ->orderBy("book_date","desc")
                        ->sum("total");
            $week_start = date( 'Y-m-d', strtotime( 'monday this week' ) );
            $week_end = date( 'Y-m-d', strtotime( 'sunday this week' ) );

            $week_earning = Bookings::where("saloon_id",$saloon_id)
                        ->where("status","!=",'cancelled')  
                        ->whereDate("book_date",">=",$week_start)
                        ->whereDate("book_date","<=",$week_end)
                        ->whereHas("Saloon")
                        ->whereHas("Barber")
                        ->whereHas("Customer")
                        ->orderBy("book_date","desc")
                        ->sum("total");

            $month_start = date('Y-m-d',strtotime('first day of this month'));
            $month_end = date('Y-m-d',strtotime('last day of this month'));

            $month_earning = Bookings::where("saloon_id",$saloon_id)
                        ->where("status","!=",'cancelled')  
                        ->whereDate("book_date",">=",$month_start)
                        ->whereDate("book_date","<=",$month_end)
                        ->whereHas("Saloon")
                        ->whereHas("Barber")
                        ->whereHas("Customer")
                        ->orderBy("book_date","desc")
                        ->sum("total");

            $year_start = date('Y-m-d',strtotime('first day of January '));
            $year_end = date('Y-m-d',strtotime('last day of December'));

            $year_earning = Bookings::where("saloon_id",$saloon_id)
                        ->where("status","!=",'cancelled')  
                        ->whereDate("book_date",">=",$year_start)
                        ->whereDate("book_date","<=",$year_end)
                        ->whereHas("Saloon")
                        ->whereHas("Barber")
                        ->whereHas("Customer")
                        ->orderBy("book_date","desc")
                        ->sum("total");

            $earnings = array("today_earning"=>$today_earning,"week_earning"=>$week_earning,"month_earning"=>$month_earning,"year_earning"=>$year_earning);

            $barbers = Barbers::select('id','name','mobile','profile_image')->where('saloon_id',$saloon_id)->get();

            $barber_income = array();
            foreach($barbers as $barber){
                if(count($barber->Ratings) > 0){
                    $ratings = $barber->Ratings->avg("rating");
                }else{
                    $ratings = 0;
                }
                
                $temp = $barber->toArray();
                $temp['profile_image'] = asset('public/uploads/profile_images/'.$barber->profile_image);
                $today_earning = Bookings::where("barber_id",$barber->id)
                        ->where("status","!=",'cancelled')  
                        ->whereDate("book_date",$date)
                        ->whereHas("Saloon")
                        ->whereHas("Barber")
                        ->whereHas("Customer")
                        ->orderBy("book_date","desc")
                        ->sum("total");
                $temp['today_earning'] = $today_earning;

                $month_earning = Bookings::where("barber_id",$barber->id)
                        ->where("status","!=",'cancelled')  
                        ->whereDate("book_date",">=",$month_start)
                        ->whereDate("book_date","<=",$month_end)
                        ->whereHas("Saloon")
                        ->whereHas("Barber")
                        ->whereHas("Customer")
                        ->orderBy("book_date","desc")
                        ->sum("total");
                $temp['month_earning'] = $month_earning;
                $temp['ratings'] = $ratings;
                $barber_income[] = $temp;
            }
            $response['earnings'] = $earnings;
            $response['barbers'] = $barber_income;
            $response['status'] = 'success';
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function deleteBooking(Request $request){
        // try{
        //     $booking_id = $request->input("booking_id");
        //     Bookings::where("id",$booking_id)->delete();
        //     BookingItems::where("booking_id",$booking_id)->delete();
        //     $response['status'] = 'success';
        //     $response['message'] = "Booking deleted successfully";
        // } catch (Exception $e) {
        //     $response['status'] = 'error';
        //     $response['message'] = $e->getMessage();
        // }
        // return response()->json($response);

         try{
            $booking_id = $request->input("booking_id");
            $booking = Bookings::where("id",$booking_id)->first();
            $booking_date = $booking->book_date." ".$booking->from_time;
            $start_date = date("Y-m-d H:i:s",strtotime($booking_date));
           
            $current_date = date("Y-m-d H:i:s");
            if($current_date > $start_date){
                $response['status'] = 'error';
                $response['message'] = 'Not allowed to cancel booking';
                return response()->json($response);
            }
            $start = strtotime($current_date);
            $end = strtotime($start_date);
            $mins = ($end - $start) / 60;
            
            if($mins < 120){
                $response['status'] = 'error';
                $response['message'] = 'Cannot cancel booking. Bookings can only be cancelled before 2hrs of booking time';
                return response()->json($response);
            }
            
            Bookings::where("id",$booking_id)->update(['status'=>'cancelled','cancelled_at'=>date("Y-m-d H:i:s")]);
            $response['status'] = 'success';
            $response['message'] = "Booking cancelled successfully";
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function editService(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'id' => 'required',
                'service_name' => 'required',
                'service_description' => 'required',
                'hours'=>"required",
                'minutes'=>"required",
                'price'=>"required",
                'hours'=>"required",
                'minutes'=>"required",
                'salon_id'=>"required",
            ]);

            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = array();
                foreach($error as $key => $err){
                    $errMsg[$key] = $err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $id = $request->input("id");
            $saloon_id = $request->input("salon_id");

            $object= SaloonServices::find($id);
            $object->saloon_id = $saloon_id;
            $object->service_name = $request->input('service_name');
            $object->service_description = $request->input('service_description');
            $object->service_id = $request->input('service_id');
            $object->duration = $request->input('hours').":".$request->input('minutes');
            $object->price = $request->input('price');
            $object->created_by = $saloon_id;
            $object->save();
            $response['status'] = 'success';
            $response['message'] = "Service edited successfully";
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function deleteService(Request $request){
        try{
            $booking_id = $request->input("id");
            SaloonServices::where("id",$booking_id)->delete();
            $response['status'] = 'success';
            $response['message'] = "Service deleted successfully";
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function render($value)
    {
        if($value === null)
        {
            $value = '';
        }
        return $value;
    }

    public function getMyFavouriteSaloon(Request $request){
        try{
            $validator = Validator::make($request->all(), [
                'customer_id' => 'required'
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $customer_id = $request->input("customer_id");
            $saloon_ids = SaloonFavourites::with('Saloon')
            ->where("customer_id",$customer_id)
            ->whereHas("Saloon")
            ->groupBy("saloon_id")
            ->pluck('saloon_id');

            if(count($saloon_ids) > 0){ 
                $saloon_ids = $saloon_ids->toArray();
            }else{
                $saloon_ids = array();
            }
            $rating = array();
            $saloonsList = Saloons::select(DB::raw("*"))
            ->with(["FirstImage","Ratings"])
            ->where(function($query) use ($rating) {
                if(count($rating) > 0){
                    $query->whereHas('Ratings',function($q) use($rating){
                      $q->whereIn("rating",$rating);  
                    });
                }
            })
            ->whereIn("id",$saloon_ids)
            ->where("status",'1')
            ->get();
            //
            // echo "<pre>";
            // print_r($saloonsList[0]->Ratings);
            // echo "</pre>";
            // echo "<pre>";
            // print_r($saloonsList);
            // echo "</pre>";
            // exit;

            $saloons = array();
            foreach($saloonsList  as $saloon){
                $ratings = 0;
                // echo collect($saloon['ratings'])->avg();
                if(count($saloon->Ratings) > 0){
                    $ratings = $saloon->Ratings->avg("rating");
                }else{
                    $ratings = "0";
                }
                // echo $ratings;
                // echo "<pre>";
                // print_r($saloon);
                // echo "</pre>";
                // exit;
                $saloon = $saloon->toArray();
                $temp['salon_id'] = (string)$saloon['id'];
                $temp['salon_name'] = $saloon['saloon_name'];
                $temp['open_time'] = ($saloon['open_time'] != NULL)?date("H:i",strtotime($saloon['open_time'])):'';
                $temp['close_time'] = ($saloon['close_time'] != NULL)?date("H:i",strtotime($saloon['close_time'])):'';
                $temp['salon_type'] = ($saloon['saloon_type'] != NULL)?$saloon['saloon_type']:'';
                $temp['latitude'] = ($saloon['latitude'] != NULL)?$saloon['latitude']:'';
                $temp['logitude'] = ($saloon['logitude'] != NULL)?$saloon['logitude']:'';
                $temp['ratings'] = $ratings;
                $street_address = '';
                if($saloon['street_address'] != ''){
                    $street_address = $saloon['street_address'];
                }
                $temp['street_address'] =  $street_address;
                if(!empty($saloon['first_image'])){
                    $temp['image'] = asset('public/uploads/saloon_gallery/'.$saloon['first_image']['image']);                
                }else{
                    $temp['image'] = '';
                }
                $saloons[] = $temp;
            }
            $response['status'] = 'success';
            $response['salons'] = $saloons;
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }

    public function checkSaloonNumber(Request $request)
    {
        try{
            $validator = Validator::make($request->all(), [
                'mobile' => 'required'
            ]);
            if ($validator->fails()) {
                $response['status'] = 'validation_error';
                $error = $validator->errors()->toArray();
                $errMsg = '';
                foreach($error as $err){
                    $errMsg .= " ".$err[0];
                }
                $response['message'] = $errMsg;
                return response()->json($response);
            }
            $saloon_mobile = $request->input("mobile");
            $saloonsList = Saloons::select("id")
            ->where("mobile", $saloon_mobile)
            ->where("status",'1')
            ->get();
            if(count($saloonsList) > 0)
            {
                $response['status'] = 'error';
                $response['message'] = "Mobile number found";
            }
            else
            {
                $response['status'] = 'success';
                $response['message'] = "Mobile number not found";
            }
        } catch (Exception $e) {
            $response['status'] = 'error';
            $response['message'] = $e->getMessage();
        }
        return response()->json($response);
    }
}
