<?php

namespace App\Services;


class FCMService
{

    function getAccessToken() {
        // Load the service account credentials
        $serviceAccount = json_decode(file_get_contents(__DIR__ . '../../../fcm.json'), true);

        // Set the token URL and expiration time (1 hour max for access tokens)
        $tokenUrl = 'https://oauth2.googleapis.com/token';
        $now = time();
        $exp = $now + 3600; // 1 hour later

        // Create the JWT header
        $header = [
            'alg' => 'RS256',
            'typ' => 'JWT'
        ];

        // Create the JWT payload
        $payload = [
            'iss' => $serviceAccount['client_email'],
            'scope' => 'https://www.googleapis.com/auth/firebase.messaging',
            'aud' => $tokenUrl,
            'iat' => $now,
            'exp' => $exp
        ];

        // Encode the header and payload to Base64Url
        $base64UrlHeader = $this->base64UrlEncode(json_encode($header));
        $base64UrlPayload = $this->base64UrlEncode(json_encode($payload));

        // Create the signature using the private key and RS256
        $signatureInput = $base64UrlHeader . '.' . $base64UrlPayload;
        openssl_sign($signatureInput, $signature, $serviceAccount['private_key'], 'sha256WithRSAEncryption');
        $base64UrlSignature = $this->base64UrlEncode($signature);

        // Create the JWT
        $jwt = $base64UrlHeader . '.' . $base64UrlPayload . '.' . $base64UrlSignature;

        // Prepare the POST request for the OAuth2 token
        $postData = http_build_query([
            'grant_type' => 'urn:ietf:params:oauth:grant-type:jwt-bearer',
            'assertion' => $jwt
        ]);

        // Use cURL to send the request
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $tokenUrl);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $postData);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            'Content-Type: application/x-www-form-urlencoded'
        ]);

        // Execute the request and get the response
        $response = curl_exec($ch);
        curl_close($ch);

        // Decode the response
        $jsonResponse = json_decode($response, true);

        // Check if access_token is available
        if (isset($jsonResponse['access_token'])) {
            return $jsonResponse['access_token'];
        } else {
            return null; // Error or failure in token generation
        }
    }

    // Helper function to encode data in Base64Url
    function base64UrlEncode($data) {
        return rtrim(strtr(base64_encode($data), '+/', '-_'), '=');
    }


    

    public function sendNotification($devicetoken, $title, $body, $data = [])
    {
        $accessToken = $this->getAccessToken(); // Get the OAuth 2.0 token

        if (!$accessToken) {
            return "Error: Unable to get access token.";
        }

        // Your Firebase project ID
        $projectId = "anara-salons"; // Replace with your Firebase project ID

        // FCM URL for sending the notification
        $url = "https://fcm.googleapis.com/v1/projects/{$projectId}/messages:send";

        // The payload for the notification
        $payload = [
            'message' => [
                'token' => $devicetoken,
                'notification' => [
                    'title' => $title,
                    'body' => $body,
                ],
                'data' => $data, // Custom data to send to the app
            ],
        ];

        // Initialize cURL session
        $ch = curl_init();

        // Set cURL options
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            'Authorization: Bearer ' . $accessToken,
            'Content-Type: application/json',
        ]);

        // Encode the payload as JSON
        curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($payload));

        // Execute the cURL request and get the response
        $result = curl_exec($ch);
        curl_close($ch);

        // Decode the response and return it
        return json_decode($result, true);
    }
}
