@extends('layouts.master')

@section('content')
<!-- Content Header (Page header) -->
    <div class="content-header">
      <div class="container-fluid">
        <div class="row mb-2">
          <div class="col-sm-6">
            <h1 class="m-0 text-dark">{{$pageTitle}}</h1>
          </div><!-- /.col -->
          <div class="col-sm-6">
            <ol class="breadcrumb float-sm-right">
              <li class="breadcrumb-item"><a href="{{ url('/admin') }}">Dashboard</a></li>
              <li class="breadcrumb-item active">{{$pageTitle}}</li>
            </ol>
          </div><!-- /.col -->
        </div><!-- /.row -->
      </div><!-- /.container-fluid -->
    </div>
    <!-- /.content-header -->

    <!-- Main content -->
    <section class="content">
      <div class="container-fluid">
        <!-- Small boxes (Stat box) -->
        <div class="row">
          <div class="col-lg-12 col-12">
             <!-- general form elements -->
            <div class="card card-primary">
              <div class="card-header">
                <h3 class="card-title float-left">
                  <span class="mt-1 d-block">Fill form detail</span>
                </h3>
                <div class="float-right">
                  <a href="{{ url('admin/customers') }}" class="btn btn-secondary btn-sm"><i class="fa fa-angle-left"></i> Back</a>
                </div>
                <div  class="clearfix"></div>
              </div>
              <!-- /.card-header -->
              <!-- form start -->
              <form method="post">
                {{csrf_field()}}
                <div class="card-body">
                  <div class="form-group">
                    <label>Name</label>
                    <input type="text" class="form-control @error('name') is-invalid @enderror" name="name" value="{{ old('name') }}" placeholder="Enter Name" required>
                    @error('name')
                        <div class="text-danger mt-2 mb-2" role="alert">
                            <strong>{{ $message }}</strong>
                        </div>
                    @enderror
                  </div>
                  <div class="form-group">
                    <label>Email</label>
                    <input type="email" class="form-control @error('email') is-invalid @enderror" name="email" value="{{ old('email') }}" placeholder="Enter Email" required>
                    @error('email')
                        <div class="error invalid-feedback mt-2 mb-2" role="alert">
                            <strong>{{ $message }}</strong>
                        </div>
                    @enderror
                  </div>
                  <div class="form-group">
                    <label>Phone No</label>
                    <input type="text" class="form-control @error('mobile') is-invalid @enderror" name="mobile" value="{{ old('mobile') }}" placeholder="Enter Phone Number" required>
                    @error('mobile')
                        <div class="error invalid-feedback mt-2 mb-2" role="alert">
                            <strong>{{ $message }}</strong>
                        </div>
                    @enderror
                  </div>
                  <div class="form-group">
                    <label>Address</label>
                    <textarea class="form-control @error('address') is-invalid @enderror" name="address" placeholder="Enter Address" required>{{ old('address') }}</textarea>
                    @error('address')
                        <div class="error invalid-feedback mt-2 mb-2" role="alert">
                            <strong>{{ $message }}</strong>
                        </div>
                    @enderror
                  </div>
                  <div class="form-group">
                    <label>Country</label>
                    <select name="country_id" class="form-control select2" onchange="fetchStates(this.value)">
                        <option value="">Select Country</option>
                        @foreach($countries as $country)
                        <option value="{{ $country->id }}">{{$country->name}}</option>
                        @endforeach
                    </select>
                    @error('country_id')
                        <div class="error invalid-feedback mt-2 mb-2" role="alert">
                            <strong>{{ $message }}</strong>
                        </div>
                    @enderror
                  </div>
                  <div class="form-group">
                    <label>States</label>
                    <select name="state_id" id='states' class="form-control select2" onchange="fetchCities(this.value)"></select>
                    @error('state_id')
                        <div class="error invalid-feedback mt-2 mb-2" role="alert">
                            <strong>{{ $message }}</strong>
                        </div>
                    @enderror
                  </div>
                  <div class="form-group">
                    <label>City</label>
                    <select id="cities" class="form-control select2" name="city_id"></select>
                    <!-- <input type="text" class="form-control @error('city') is-invalid @enderror" name="city" value="{{ old('city') }}" placeholder="Enter City" required> -->
                    @error('city_id')
                        <div class="error invalid-feedback mt-2 mb-2" role="alert">
                            <strong>{{ $message }}</strong>
                        </div>
                    @enderror
                  </div>
                  <div class="form-group">
                    <label>Password</label>
                    <input type="password" id="password" class="form-control @error('password') is-invalid @enderror" name="password" placeholder="Password">
                    @error('password')
                        <div class="error invalid-feedback mt-2 mb-2" role="alert">
                            <strong>{{ $message }}</strong>
                        </div>
                    @enderror
                    <div class="mt-2">
                      <div class="icheck-primary d-inline">
                        <input type="checkbox" id="checkboxPrimary1" onchange="showPassword(this)">
                        <label for="checkboxPrimary1">Show Password</label>
                      </div>
                    </div>
                  </div>
                  <div class="form-group">
                    <label>Status</label>
                    <div>
                      <input type="checkbox" name="status" checked data-bootstrap-switch>
                    </div>
                  </div>
                  
                </div>
                <!-- /.card-body -->

                <div class="card-footer">
                  <button type="submit" class="btn btn-primary">Submit</button>
                </div>
              </form>
            </div>
            <!-- /.card -->
          </div>
        </div>
      </div><!-- /.container-fluid -->
    </section>
    <!-- /.content -->
@endsection

@section('javascript')
<link rel="stylesheet" href="assets/plugins/bs-stepper/css/bs-stepper.min.css">
<script src="assets/plugins/bootstrap-switch/js/bootstrap-switch.min.js"></script>
<script src="assets/plugins/bs-stepper/js/bs-stepper.min.js"></script>
<script type="text/javascript">
$(document).ready(function(){
  $("input[data-bootstrap-switch]").each(function(){
      $(this).bootstrapSwitch({
        onText:"Enable",
        offText:"Disable"
      });
    });
})
function showPassword(e){
  if($(e).is(":checked")){
    $("#password").attr("type","text");
  }else{
    $("#password").attr("type","password");
  }
}

function fetchStates(id){
  $.ajax({
        url:"{{ url('/fetch-states') }}",
        type:"get",
        data:{
            country_id:id
        },
        beforeSend:function(){
            $("#states").html('');
        },
        success:function(response){
          if(response.status == true){
            $("#states").html(response.options);
          }
        }
    })
}

function fetchCities(id){
  $.ajax({
        url:"{{ url('/fetch-cities') }}",
        type:"get",
        data:{
            state_id:id
        },
        beforeSend:function(){
            $("#cities").html('');
        },
        success:function(response){
          if(response.status == true){
            $("#cities").html(response.options);
          }
        }
    })
}
</script>
@endsection