@extends('layouts.master')

@section('content')
<!-- Content Header (Page header) -->
    <div class="content-header">
      <div class="container-fluid">
        <div class="row mb-2">
          <div class="col-sm-6">
            <h1 class="m-0 text-dark">{{$pageTitle}}</h1>
          </div><!-- /.col -->
          <div class="col-sm-6">
            <ol class="breadcrumb float-sm-right">
              <li class="breadcrumb-item"><a href="{{ url('/admin') }}">Dashboard</a></li>
              <li class="breadcrumb-item active">{{$pageTitle}}</li>
            </ol>
          </div><!-- /.col -->
        </div><!-- /.row -->
      </div><!-- /.container-fluid -->
    </div>
    <!-- /.content-header -->

    <!-- Main content -->
    <section class="content">
      <div class="container-fluid">
        <!-- Small boxes (Stat box) -->
        <div class="row">
          <div class="col-lg-12 col-12">
             <!-- general form elements -->
            <div class="card card-primary">
              <div class="card-header">
                <h3 class="card-title float-left">
                  <span class="mt-1 d-block">Fill form detail</span>
                </h3>
                <div class="float-right">
                  <a href="{{ url('admin/barbers') }}" class="btn btn-secondary btn-sm"><i class="fa fa-angle-left"></i> Back</a>
                </div>
                <div  class="clearfix"></div>
              </div>
              <!-- /.card-header -->
              <!-- form start -->
              <form method="post" enctype='multipart/form-data'>
                {{csrf_field()}}
                <div class="card-body">
                  <div class="form-group">
                    <label>Salon</label>
                    <select class="select2 @error('saloon_id') is-invalid @enderror" name="saloon_id" style="width: 100%;" required>
                      <option value="">Select Salon</option>
                      @foreach($saloons as $salon)
                      <option {{ ($salon->id == $record->saloon_id)?'selected':'' }} value="{{ $salon->id }}">{{$salon->saloon_name}}</option>
                      @endforeach
                    </select>
                    @error('saloon_id')
                        <div class="text-danger mt-2 mb-2" role="alert">
                            <strong>{{ $message }}</strong>
                        </div>
                    @enderror
                  </div>
                  <div class="form-group">
                    <label>Name</label>
                    <input type="text" class="form-control @error('name') is-invalid @enderror" name="name" value="{{ $record->name }}" placeholder="Enter Name" required>
                    @error('name')
                        <div class="text-danger mt-2 mb-2" role="alert">
                            <strong>{{ $message }}</strong>
                        </div>
                    @enderror
                  </div>
                  <div class="form-group">
                    <label>Email</label>
                    <input type="email" class="form-control @error('email') is-invalid @enderror" name="email" value="{{ $record->email }}" placeholder="Enter Email" required>
                    @error('email')
                        <div class="error invalid-feedback mt-2 mb-2" role="alert">
                            <strong>{{ $message }}</strong>
                        </div>
                    @enderror
                  </div>
                  <div class="form-group">
                    <label>Mobile</label>
                    <input type="text" class="form-control @error('mobile') is-invalid @enderror" name="mobile" value="{{ $record->mobile }}" placeholder="Enter Mobile Number" required>
                    @error('mobile')
                        <div class="error invalid-feedback mt-2 mb-2" role="alert">
                            <strong>{{ $message }}</strong>
                        </div>
                    @enderror
                  </div>
                  
                  <div class="form-group">
                    <label>Password</label>
                    <input type="password" id="password" class="form-control @error('password') is-invalid @enderror" name="password" placeholder="Password">
                    @error('password')
                        <div class="error invalid-feedback mt-2 mb-2" role="alert">
                            <strong>{{ $message }}</strong>
                        </div>
                    @enderror
                    <div class="mt-2">
                      <div class="icheck-primary d-inline">
                        <input type="checkbox" id="checkboxPrimary1" onchange="showPassword(this)">
                        <label for="checkboxPrimary1">Show Password</label>
                      </div>
                    </div>
                  </div>
                  <div class="form-group">
                    <label for="exampleInputFile">File input</label>
                    <div class="input-group">
                      <div class="custom-file">
                        <input type="file" class="custom-file-input" id="exampleInputFile" name="profile_image">
                        <label class="custom-file-label" for="exampleInputFile">Choose file</label>
                      </div>
                      <div class="input-group-append">
                        <span class="input-group-text">Upload</span>
                      </div>
                    </div>
                    <div class="mt-2">
                      @if($record->profile_image != '' && file_exists(public_path('uploads/profile_images/'.$record->profile_image)))
                       <img src="{{ asset('public/uploads/profile_images/'.$record->profile_image) }}" class="img-circle elevation-2" width="80" height="80" />
                      @endif
                    </div>
                  </div>
                  <!-- <div class="form-group">
                    <label>Services</label>
                    <select id="services" onchange="selectService(this.value)" multiple class="select2 @error('services') is-invalid @enderror" name="services[]" style="width: 100%;" required>
                    
                      @foreach($services as $service)
                      <option {{ (in_array($service->id,$bs_ids))?'selected':'' }} value="{{ $service->id }}">{{$service->name}}</option>
                      @endforeach
                    </select>
                    @error('services')
                        <div class="text-danger mt-2 mb-2" role="alert">
                            <strong>{{ $message }}</strong>
                        </div>
                    @enderror
                  </div> -->
                  <!-- <div class="form-group" id="barber_services"></div> -->
                  <div class="form-group">
                    <label>Status</label>
                    <div>
                      <input type="checkbox" name="status" {{ ($record->status)?'checked':'' }} data-bootstrap-switch>
                    </div>
                  </div>
                  
                </div>
                <!-- /.card-body -->

                <div class="card-footer">
                  <button type="submit" class="btn btn-primary">Submit</button>
                </div>
              </form>
            </div>
            <!-- /.card -->
          </div>
        </div>
      </div><!-- /.container-fluid -->
    </section>
    <!-- /.content -->
@endsection

@section('javascript')
<link rel="stylesheet" href="assets/plugins/bs-stepper/css/bs-stepper.min.css">
<link rel="stylesheet" href="assets/plugins/daterangepicker/daterangepicker.css">

<script src="assets/plugins/bootstrap-switch/js/bootstrap-switch.min.js"></script>
<script src="assets/plugins/bs-stepper/js/bs-stepper.min.js"></script>
<script src="assets/plugins/moment/moment.min.js"></script>
<script src="assets/plugins/daterangepicker/daterangepicker.js"></script>

<script type="text/javascript">
$(document).ready(function(){
    $("input[data-bootstrap-switch]").each(function(){
      $(this).bootstrapSwitch({
        onText:"Enable",
        offText:"Disable"
      });
    });
    $('#open-timepicker').datetimepicker({
      format: 'LT',
    });
    // .onChangeDateTime:function (selected) {
    //     alert(selected);
    //        $('#close-timepicker').datetimepicker("option", "minTime", selected);
    // })

    $('#close-timepicker').datetimepicker({
      format: 'LT',
      minTime:"8:48 PM"
    });
    // $('#timepicker').datetimepicker({
    //   format: 'LT'
    // })
})
function checkTime(){
  var timefrom = $('#open-timepicker input').val();
  var timeto =$('#close-timepicker input').val();

  if(timeto !='' && timefrom != ''){
    if(Date.parse(timeto) < Date.parse(timefrom)){
      errorMessage('Close time should be greater then open time');
      $("#close-timepicker input").val('');
    }
  }
}
function showPassword(e){
  if($(e).is(":checked")){
    $("#password").attr("type","text");
  }else{
    $("#password").attr("type","password");
  }
}
// getServices("{{ $record->saloon_id }}");
function getServices(id){
  $.ajax({
    url:"{{ url('/admin/barbers/saloon-services') }}",
    type:"get",
    dataType:"json",
    data:{
      saloon_id:id,
      barber_id:"{{ $record->id }}"
    },
    beforeSend:function(){
        $("#barber_services").html('');
    },
    success:function(response){
      $("#barber_services").html(response.services);
    },
    error:function(){
    }
  })
}
  // function selectService(value){
  //   $("#services option:selected").each(function(){
      
  //   }); 
  // }
  // function removeService(e,service_id){
  //   $(e).parents("tr").remove();
  //   $("#services option[value="+service_id+"]").prop("selected",false);
  //   var ser_ids = [];

  //   $("#barber_services .service_id").each(function(){
  //     ser_ids.push($(this).val());
  //   })
  //   if(ser_ids.length > 0){
  //     $('#services').select2('val', ser_ids);
  //   }else{
  //     $('#services').val('').trigger("change");
  //   }
  // }
</script>
@endsection