@extends('layouts.master')

@section('content')
<!-- Content Header (Page header) -->
    <div class="content-header">
      <div class="container-fluid">
        <div class="row mb-2">
          <div class="col-sm-6">
            <h1 class="m-0 text-dark">{{$pageTitle}}</h1>
          </div><!-- /.col -->
          <div class="col-sm-6">
            <ol class="breadcrumb float-sm-right">
              <li class="breadcrumb-item"><a href="{{ url('/admin') }}">Dashboard</a></li>
              <li class="breadcrumb-item active">{{$pageTitle}}</li>
            </ol>
          </div><!-- /.col -->
        </div><!-- /.row -->
      </div><!-- /.container-fluid -->
    </div>
    <!-- /.content-header -->

    <!-- Main content -->
    <section class="content">
      <div class="container-fluid">
        <!-- Small boxes (Stat box) -->
        <div class="row">
          <div class="col-lg-12 col-12">
             <div class="card">
              <div class="card-header">
                <h3 class="card-title float-left">Bookings List {{ ($saloon_name != '')?"of Salon ".$saloon_name:'of All Saloons' }}</h3>
                <div class="float-right">
                  <form id="search">
                    <div class="form-group float-left mr-2">
                      <label>Filter by Salon</label>
                      <div>
                        <select class="select2" name="saloon" onchange="return $('#search').submit()">
                          <option value="">All</option>
                          @foreach($saloons as $saloon)
                          <option {{ ($saloon->id == $selected_saloon)?'selected':'' }} value="{{ $saloon->id }}">{{$saloon->saloon_name}}</option>
                          @endforeach
                        </select>
                      </div>
                    </div>
                    <div class="form-group float-left">
                      <label>Filter by Customer</label>
                      <div>
                        <select class="select2" name="customer" onchange="return $('#search').submit()">
                          <option value="">All</option>
                          @foreach($customers as $customer)
                          <option {{ ($customer->id == $selected_customer)?'selected':'' }} value="{{ $customer->id }}">{{$customer->name}}</option>
                          @endforeach
                        </select>
                      </div>
                    </div>

                    <div class="clearfix"></div>
                </form>
                  <div class="clearfix"></div>
                </div>
                <div class="clearfix"></div>
              </div>
              <!-- /.card-header -->
              <div class="card-body">
                <table class="table table-bordered">
                  <thead>
                    <tr>
                      <th style="width: 10px">#</th>
                      <!-- <th>Image</th> -->
                      <th>Customer</th>
                      <th>Salon</th>
                      <th>Barber</th>
                      <th>Time</th>
                      <th>Book Date</th>
                      <th>Services</th>
                      <th>Total Amount</th>
                      <th>Status</th>
                      <th style="width: 40px">Action</th>
                    </tr>
                  </thead>
                  <tbody>
                    @if(count($records) > 0)
                    @foreach($records as $record)
                    <tr>
                      <td>{{ $record->id }}</td>
                      <td>{{ $record->Customer->name }}</td>
                      <td>{{ $record->Saloon->saloon_name }}</td>
                      <td>{{ $record->Barber->name }}</td>
                      <td>{{ $record->from_time }} to {{$record->to_time}}</td>
                      <td>{{ dateFormat($record->book_date) }}</td>
                      <td>
                        @foreach($record->BookingItems as $item)
                          <span class="badge badge-secondary">{{$item->SaloonService->service_name}}</span>
                        @endforeach
                      </td>
                      <td>
                        ₹{{$record->total}}
                      </td>
                      <td>
                        @if($record->status == 'cancelled')      
                            <span class="badge badge-warning">Cancelled</span>
                        @elseif($record->book_date.$record->to_time > date('Y-m-d H:i:s'))
                          <span class="badge badge-success">Upcoming</span>
                        @else
                          <span class="badge badge-danger">Completed</span>
                        @endif
                      </td>
                      <td>
                        <div class="btn-group">
                          <a href="{{ url('admin/bookings/view/'.$record->id) }}" class="btn btn-info mr-2 btn-sm"><i class="fa fa-eye"></i></a>
                        </div>
                      </td>
                    </tr>
                    @endforeach
                    @endif
                  </tbody>
                </table>
                @if(count($records) <= 0)
                  <div class="text-danger text-center mt-1">No records available</div>
                @endif
              </div>
              <!-- /.card-body -->
              <div class="card-footer clearfix">
                <div class="pagination pagination-sm m-0 float-right">
                  {{$records->appends(Request::except('page'))->links()}}
                </div>
              </div>
            </div>
          </div>
         
        </div>
      </div><!-- /.container-fluid -->
    </section>
    <div class="modal fade" id="delete-confirmation">
        <div class="modal-dialog">
          <div class="modal-content">
            
            <div class="modal-header">
              <h4 class="modal-title">Confirm Delete</h4>
              <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                <span aria-hidden="true">&times;</span>
              </button>
            </div>
            <div class="modal-body">
              <p>Are you sure to delete the record?</p>
            </div>
            <div class="modal-footer justify-content-between">
              <button type="button" class="btn btn-default" data-dismiss="modal">Cancel</button>
              <button onclick="deleteUser()" type="button" class="btn btn-danger">Delete</button>
            </div>
          </div>
          <!-- /.modal-content -->
        </div>
        <!-- /.modal-dialog -->
      </div>
    <!-- /.content -->
@endsection

@section("javascript")
<script>
var delete_user ='';
function confirmDelete(id){
  delete_user = id;
  $("#delete-confirmation").modal("show");
}
function deleteUser(){
  if(delete_user != ''){
    var url = "{{ url('admin/barbers/delete') }}/"+delete_user;
    redirect(url);
  }else{
    errorMessage("Invalid record selected");
  }
}
</script>
@endsection